@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -41,8 +41,14 @@ import fnmatch
 
 from autovnv.Parser import Parser
 from autovnv.TexMaker import Report1, Report2
-from autovnv.Drawing import Plotter
-from autovnv.PlotVTK import PlotVTK
+try:
+    from autovnv.Drawing import Plotter
+except Exception:
+    pass
+try:
+    from autovnv.PlotVTK import PlotVTK
+except Exception:
+    pass
 from autovnv.Command import run_autovnv_command
 
 #-------------------------------------------------------------------------------
@@ -134,7 +140,7 @@ class Case(object):
         return exe, pkg
 
 
-    def update(self):
+    def update(self, xmlonly=False):
         """
         Update path for the script in the Repository.
         """
@@ -142,12 +148,17 @@ class Case(object):
         #    with the __backwardCompatibility method.
 
         from Base.XMLengine import Case
+        from Pages.ScriptRunningModel import ScriptRunningModel
+        from cs_exec_environment import \
+            separate_args, get_command_single_value, update_command_single_value, assemble_args, enquote_arg
 
         if self.exe == "code_saturne":
             from Base.XMLinitialize import XMLinit
         elif self.exe == "neptune_cfd":
             from core.XMLinitialize import XMLinit
 
+        n_procs = {}
+
         for fn in os.listdir(os.path.join(self.__repo, self.label, "DATA")):
             fp = os.path.join(self.__repo, self.label, "DATA", fn)
             if os.path.isfile(fp):
@@ -167,12 +178,16 @@ class Case(object):
                     case['xmlfile'] = fp
                     case.xmlCleanAllBlank(case.xmlRootNode())
                     XMLinit(case).initialize()
+                    smdl = ScriptRunningModel(case)
+                    n_procs[str(fn)] = smdl.getString('n_procs')
+                    smdl.setString('n_procs', None)
                     case.xmlSaveDocument()
 
         # 2) Create RESU directory if needed
-        r = os.path.join(self.__repo, self.label, "RESU")
-        if not os.path.isdir(r):
-            os.makedirs(r)
+        if not xmlonly:
+            r = os.path.join(self.__repo, self.label, "RESU")
+            if not os.path.isdir(r):
+                os.makedirs(r)
 
         # 3) Update the GUI script from the Repository
         ref = os.path.join(self.__repo, self.label, "DATA", self.pkg.guiname)
@@ -188,8 +203,15 @@ class Case(object):
 
         for i in range(len(lines)):
             if re.search(r'^prefix=', lines[i]):
-                 lines[i] = "prefix=" + self.pkg.get_dir('prefix') + "\n"
-
+                if xmlonly:
+                    lines[i] = "prefix=\n"
+                else:
+                    lines[i] = "prefix=" + self.pkg.get_dir('prefix') + "\n"
+            if re.search(r'^export PATH=', lines[i]):
+                if xmlonly:
+                    lines[i] = 'export PATH="":$PATH\n'
+                else:
+                    lines[i] = 'export PATH="' + self.pkg.get_dir('bindir') +'":$PATH\n'
         f = file(ref, mode = 'w')
         f.writelines(lines)
         f.close()
@@ -207,8 +229,27 @@ class Case(object):
         f.close()
 
         for i in range(len(lines)):
-            if re.search(r'^export PATH=', lines[i]):
-                 lines[i] = 'export PATH="' + self.pkg.get_dir('bindir') +'":$PATH\n'
+            if lines[i].strip()[0:1] == '#':
+                continue
+            if xmlonly:
+                if re.search(r'^export PATH=', lines[i]):
+                    lines[i] = 'export PATH="":$PATH\n'
+            else:
+                if re.search(r'^export PATH=', lines[i]):
+                    lines[i] = 'export PATH="' + self.pkg.get_dir('bindir') +'":$PATH\n'
+                j = lines[i].find(self.pkg.name)
+                if j > -1:
+                    j = lines[i].find('run')
+                    args = separate_args(lines[i].rstrip())
+                    param = get_command_single_value(args, ('--param', '--param=', '-p'))
+                    try:
+                        if n_procs[param]:
+                            args = update_command_single_value(args,
+                                                               ('--nprocs', '--nprocs=', '-n'),
+                                                               n_procs[param])
+                            lines[i] = assemble_args(args) + '\n'
+                    except Exception:
+                        pass
 
         f = file(ref, mode = 'w')
         f.writelines(lines)
@@ -351,12 +392,15 @@ class Case(object):
         return error
 
 
-    def runCompare(self, studies, r, d, threshold, args):
+    def runCompare(self, studies, r, d, threshold, args, reference=None):
         home = os.getcwd()
 
         node = None
 
-        result = os.path.join(self.__repo, self.label, 'RESU')
+        if reference:
+            result = os.path.join(reference, self.label, 'RESU')
+        else:
+            result = os.path.join(self.__repo, self.label, 'RESU')
         repo = self.check_dir(studies, node, result, r, "repo")
         repo = os.path.join(result, repo, 'checkpoint', 'main')
 
@@ -468,13 +512,16 @@ class Case(object):
             sys.exit(1)
 
 
-    def check_dirs(self, studies, node, repo, dest):
+    def check_dirs(self, studies, node, repo, dest, reference=None):
         """
         Check coherency between xml file of parameters and repository and destination.
         """
         if repo != None:
             # build path to RESU directory with path to study and case label in the repo
-            result = os.path.join(self.__repo, self.label, 'RESU')
+            if reference:
+                result = os.path.join(reference, self.label, 'RESU')
+            else:
+                result = os.path.join(self.__repo, self.label, 'RESU')
             self.check_dir(studies, node, result, repo, "repo")
 
         if dest != None:
@@ -505,7 +552,6 @@ class Study(object):
         """
         # Initialize attributes
         self.__parser   = parser
-        self.__study    = study
         self.__main_exe = exe
         self.__diff     = dif
         self.__log      = rlog
@@ -517,6 +563,8 @@ class Study(object):
             print("Error: the directory %s does not exist" % self.__repo)
             sys.exit(1)
 
+        self.label = study
+
         self.Cases = []
         self.matplotlib_figures = []
         self.vtk_figures = []
@@ -526,12 +574,12 @@ class Study(object):
         if not self.cases:
             print("\n\n\nWarning: no case defined in %s study\n\n\n" % study)
         else:
-            for data in self.__parser.getCasesKeywords(self.__study):
+            for data in self.__parser.getCasesKeywords(self.label):
                 c = Case(pkg,
                          self.__log,
                          self.__diff,
                          self.__parser,
-                         self.__study,
+                         self.label,
                          data,
                          self.__repo,
                          self.__dest)
@@ -625,7 +673,7 @@ class Studies(object):
     """
     Manage all Studies and all Cases described in the files of parameters.
     """
-    def __init__(self, pkg, f, v, r, c, p, exe, dif):
+    def __init__(self, pkg, f, v, x, r, n, c, d, p, exe, dif, log):
         """
         Constructor.
           1. create if necessary the destination directory,
@@ -636,6 +684,8 @@ class Studies(object):
         @param f: xml file of parameters.
         @type v: C{True} or C{False}
         @param v: verbose mode.
+        @type x: C{True} or C{False}
+        @param x: update xml in repo only.
         @type r: C{True} or C{False}
         @param r: have to run the case.
         @type c: C{True} or C{False}
@@ -658,7 +708,11 @@ class Studies(object):
 
         # create if necessary the destination directory
 
-        self.dest = self.getDestination()
+        self.__xmlupdate = x
+        if not self.__xmlupdate:
+            self.dest = self.getDestination()
+        else:
+            self.dest = self.getRepository()
         if not os.path.isdir(self.dest):
             os.makedirs(self.dest)
 
@@ -673,12 +727,18 @@ class Studies(object):
         # create a new parser, which is definitive and the plotter
 
         self.__parser  = Parser(file)
-        self.__plotter = Plotter(self.__parser)
-        self.__plotvtk = PlotVTK(self.__parser)
+        try:
+            self.__plotter = Plotter(self.__parser)
+        except Exception:
+            self.__plotter = None
+        try:
+            self.__plotvtk = PlotVTK(self.__parser)
+        except Exception:
+            self.__plotvtk = None
 
         # build the list of the studies
 
-        doc = os.path.join(self.dest, "auto_vnv.log")
+        doc = os.path.join(self.dest, log)
         self.__log = open(doc, "w")
         self.labels  = self.__parser.getStudiesLabel()
         self.studies = []
@@ -695,7 +755,9 @@ class Studies(object):
 
         self.__verbose = v
         self.__running = r
+        self.__n_iter  = n
         self.__compare = c
+        self.__ref     = d
         self.__postpro = p
 
         # in case of restart
@@ -707,6 +769,9 @@ class Studies(object):
         if not iok:
             self.__running = False
 
+        if self.__xmlupdate:
+            os.remove(file)
+            os.remove(doc)
 
     def reporting(self, msg, screen_only=False):
         """
@@ -754,7 +819,7 @@ class Studies(object):
         return self.__parser.getDestination()
 
 
-    def updateRepository(self):
+    def updateRepository(self, xml_only=False):
         """
         Create all studies and all cases.
         """
@@ -763,7 +828,7 @@ class Studies(object):
             self.reporting('  o Update repository: ' + l)
             for case in s.Cases:
                 self.reporting('    - update  %s' % case.label)
-                case.update()
+                case.update(xml_only)
                 if case.compile(os.path.join(self.repo, l)) == "OK":
                     self.reporting('    - compile %s --> OK' % case.label)
                 else:
@@ -852,6 +917,21 @@ class Studies(object):
                 self.prepro(l, s, case)
                 if self.__running:
                     if case.compute == 'on' and case.is_compil != "KO":
+
+                        if self.__n_iter:
+                            case_dir = os.path.join(self.dest, s.label, case.label, "DATA")
+                            os.chdir(case_dir)
+                            # Create a control_file in each case DATA
+                            if not os.path.exists('control_file'):
+                                control_file = open('control_file','w')
+                                control_file.write(str(self.__n_iter) + "\n")
+                                # Flush to ensure that control_file content is seen
+                                # when control_file is copied to the run directory on all systems
+                                control_file.flush()
+                                control_file.close
+                            else:
+                                print("Warning: there is already a control_file in the DATA directory of case %s." % case.label)
+
                         self.reporting('    - running %s ...' % case.label, True)
                         error = case.run()
                         if not error:
@@ -900,7 +980,10 @@ class Studies(object):
                         dest = ""
                         if destination == False:
                             dest = None
-                        case.check_dirs(self, node, repo, dest)
+                        ref = None
+                        if self.__ref:
+                            ref = os.path.join(self.__ref, s.label)
+                        case.check_dirs(self, node, repo, dest, reference=ref)
 
 
     def compare(self):
@@ -917,7 +1000,7 @@ class Studies(object):
                             for i in range(len(nodes)):
                                 if is_compare[i]:
                                     case.is_compare = "done"
-                                    self.reporting('    - compare %s (%s)' % (case.label, args[i]))
+                                    self.reporting('    - compare %s (with args: %s)' % (case.label, args[i]))
                                     case.diff_value += case.runCompare(self, repo[i], dest[i], t[i], args[i])
                         if not is_compare or case.is_compare != "done":
                             repo = ""
@@ -925,9 +1008,14 @@ class Studies(object):
                             t    = None
                             args = None
                             case.is_compare = "done"
-                            self.reporting('    - compare %s (%s)' % (case.label, args))
-                            case.diff_value += case.runCompare(self, repo, dest, t, args)
-
+                            ref = None
+                            if self.__ref:
+                                ref = os.path.join(self.__ref, s.label)
+                            case.diff_value += case.runCompare(self, repo, dest, t, args, reference=ref)
+                            if case.diff_value:
+                                self.reporting('    - compare %s (default mode) --> DIFFERENCES FOUND' % (case.label))
+                            else:
+                                self.reporting('    - compare %s (default mode) --> NO DIFFERENCES FOUND' % (case.label))
 
 
 
@@ -1028,7 +1116,7 @@ class Studies(object):
                         case.check_dirs(self, node, repo, dest)
 
                     for node in self.__parser.getChilds(case.node, "input"):
-                        file, dest, repo = self.__parser.getInput(node)
+                        file, dest, repo, tex = self.__parser.getInput(node)
                         if destination == False:
                             dest = None
                         case.check_dirs(self, node, repo, dest)
@@ -1038,12 +1126,14 @@ class Studies(object):
         """
         Plot data.
         """
-        for l, s in self.studies:
-            self.reporting('  o Plot study: ' + l)
-            self.__plotter.plot_study(l, s)
+        if self.__plotter:
+            for l, s in self.studies:
+                self.reporting('  o Plot study: ' + l)
+                self.__plotter.plot_study(l, s)
 
-        for l, s in self.studies:
-            self.__plotvtk.plot_study(l, s)
+        if self.__plotvtk:
+            for l, s in self.studies:
+                self.__plotvtk.plot_study(l, s)
 
 
     def build_reports(self, report1, report2):
@@ -1112,7 +1202,7 @@ class Studies(object):
                         if nodes:
                             doc2.appendLine("\\subsection{Results for case %s}" % case.label)
                             for node in nodes:
-                                f, dest, repo = self.__parser.getInput(node)
+                                f, dest, repo, tex = self.__parser.getInput(node)
                                 doc2.appendLine("\\subsubsection{%s}" % f)
 
                                 if dest:
@@ -1129,6 +1219,8 @@ class Studies(object):
 
                                 if not os.path.isfile(ff):
                                     print("\n\nWarning: this file does not exist: %s\n\n" % ff)
+                                elif tex == 'on':
+                                    doc2.addTexInput(ff)
                                 else:
                                     doc2.addInput(ff)
 
@@ -1141,7 +1233,7 @@ class Studies(object):
                             input_nodes = self.__parser.getChilds(nodes[i], "input")
                             if input_nodes:
                                 for node in input_nodes:
-                                    f, dest, repo = self.__parser.getInput(node)
+                                    f, dest, repo, tex = self.__parser.getInput(node)
                                     doc2.appendLine("\\subsubsection{%s}" % f)
 
                                     if dest:
@@ -1158,6 +1250,8 @@ class Studies(object):
 
                                     if not os.path.isfile(ff):
                                         print("\n\nWarning: this file does not exist: %s\n\n" % ff)
+                                    elif tex == 'on':
+                                        doc2.addTexInput(ff)
                                     else:
                                         doc2.addInput(ff)
 
@@ -1167,6 +1261,11 @@ class Studies(object):
 
 
     def logs(self):
+        try:
+            self.reportFile.close()
+        except:
+            pass
+        self.reportFile = open(self.report, mode='r')
         return self.reportFile.read()
 
 
