@@ -5,7 +5,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -85,7 +85,7 @@ def separate_args(s):
                 a += s[i]
                 protected = False
             else:
-                if s[i] == '\\':
+                if s[i] == '\\' and s[i+1:i+1].isalnum():
                     protected = True
                 elif s[i] == '"' or s[i] == "'":
                     if in_quotes == s[i]:
@@ -137,6 +137,147 @@ def enquote_arg(s):
     else:
         return s
 
+#-------------------------------------------------------------------------------
+
+def assemble_args(cmd):
+    """
+    Assemble separate arguments.
+    """
+    l = ''
+    for s in cmd:
+        if (s.find(' ') > -1):
+            l += ' ' + enquote_arg(s)
+        else:
+            l += ' ' + s
+    return l.strip()
+
+#-------------------------------------------------------------------------------
+# Update command line arguments for a given value
+#-------------------------------------------------------------------------------
+
+def update_command_single_value(args, options, value):
+    """
+    Adds, updates, or removes parts of a command to pass a given value.
+    The command is provided as a list, and options defining a value may be
+    defined as a tuple (to allow for multiple variants).
+
+    In all cases, this function assumes the option is followed by a single
+    value argument.
+    Options and values may be defined as separate (successive) arguments,
+    or be separated by a '=' character when the matching option
+    ands with '='. To allow both syntaxes, a given option may be pased
+    both with and without that separator; for example:
+    options = ('--param=', '--param', '-p').
+
+    If no option was previously present and a value is added, the first
+    syntax of the options tuple will be used.
+    """
+
+    i = -1
+
+    # Update first occurence
+
+    if value:
+
+        val_s = str(value)
+
+        for opt in options:
+
+            if opt[-1:] == '=':
+                l = len(opt)
+                for arg in args:
+                    if arg[:l] == opt:
+                        i = args.index(arg)
+                        break
+                if i > -1:
+                    args[i] = prefix + val_s
+
+            else:
+                if args.count(opt) > 0:
+                    i = args.index(opt)
+                    if i+1 < len(args):
+                        args[i+1] = val_s
+                    else:
+                        args.append(val_s)
+                    i = i+1
+
+            if i > -1:
+                i = i + 1
+                break
+
+        # Append if none found
+
+        if i == -1:
+            opt = options[0]
+            if opt[-1:] == '=':
+                args.append(opt + val_s)
+            else:
+                args.append(opt)
+                args.append(val_s)
+            i = len(args)
+
+    # Remove excess occurences
+
+    for opt in options:
+
+        j = i
+
+        if opt[-1:] == '=':
+            l = len(opt)
+            while j < len(args):
+                if args[j][:l] == opt:
+                    args.pop(j)
+                else:
+                    j = j+1
+
+        else:
+            while j < len(args):
+                if args[j] == opt:
+                    args.pop(j)       # option
+                    if j < len(args):
+                        args.pop(j)   # matching value
+                else:
+                    j = j+1
+
+    # Return updated list
+
+    return args
+
+#-------------------------------------------------------------------------------
+# Get a single value from a command line
+#-------------------------------------------------------------------------------
+
+def get_command_single_value(args, options, default=None):
+    """
+    Obtain a value from a command line if availble, or using a default otherwise
+    The command is provided as a list, and options defining a value may be
+    defined as a tuple (to allow for multiple variants).
+
+    In all cases, this function assumes the option is followed by a single
+    value argument.
+    Options and values may be defined as separate (successive) arguments,
+    or be separated by a '=' character when the matching option
+    ands with '='. To allow both syntaxes, a given option may be pased
+    both with and without that separator; for example:
+    options = ('--param=', '--param', '-p').
+    """
+
+    for opt in options:
+
+        if opt[-1:] == '=':
+            l = len(opt)
+            for arg in args:
+                if arg[:l] == opt:
+                    return arg[l:]
+
+        else:
+            if args.count(opt) > 0:
+                i = args.index(opt)
+                if i+1 < len(args):
+                    return args[i+1]
+
+    return default
+
 #---------------------------------------------------------------------------
 
 def get_shell_type():
@@ -715,7 +856,7 @@ class resource_info(batch_info):
         Determine number of processors per node.
         """
 
-        ppn = 1
+        ppn = None
         if self.n_procs != None and  self.n_nodes != None:
             ppn = self.n_procs / self.n_nodes
 
@@ -945,6 +1086,33 @@ class mpi_environment:
 
         self.info_cmds = None
 
+        # Initialize options based on system-wide or user configuration
+
+        config = configparser.ConfigParser()
+        config.read(pkg.get_configfiles())
+
+        if config.has_section('mpi'):
+            for option in config.items('mpi'):
+               k = option[0]
+               v = option[1]
+               if not v:
+                   v = None
+               elif v[0] in ['"', "'"]:
+                   v = v[1:-1]
+               if k == 'mpmd':
+                   self.mpmd = eval('MPI_MPMD_' + v)
+               else:
+                   self.__dict__[k] = v
+
+        # We may have a specific syntax for tasks per node if
+        # a launcher from a resource manager is used:
+
+        if resource_info and self.mpiexec and not self.mpiexec_n_per_node:
+            if os.path.basename(self.mpiexec)[:4] == 'srun':
+                ppn = resource_info.n_procs_per_node()
+                if ppn:
+                    self.mpiexec_n_per_node = ' --ntasks-per-node=' + str(ppn)
+
         # Initialize based on known MPI types, or default.
 
         init_method = self.__init_other__
@@ -956,21 +1124,57 @@ class mpi_environment:
                                'MSMPI':self.__init_msmpi__,
                                'OpenMPI':self.__init_openmpi__,
                                'BullxMPI':self.__init_openmpi__,
-                               'LAM_MPI':self.__init_lam__,
                                'BGP_MPI':self.__init_bgp__,
                                'BGQ_MPI':self.__init_bgq__,
-                               'HP_MPI':self.__init_hp_mpi__,
-                               'MPICH1':self.__init_mpich1__,
+                               'Platform_MPI':self.__init_platform_mpi__,
                                'MPIBULL2':self.__init_mpibull2__}
             if self.type in mpi_env_by_type:
                 init_method = mpi_env_by_type[self.type]
 
         p = os.getenv('PATH').split(':')
         if len(self.bindir) > 0:
-            p.insert(0, self.bindir)
+            p = [self.bindir]
 
         init_method(p, resource_info, wdir)
 
+        # Overwrite options based on system-wide or user configuration
+
+        if config.has_section('mpi'):
+            for option in config.items('mpi'):
+               k = option[0]
+               v = option[1]
+               if not v:
+                   v = None
+               elif v[0] in ['"', "'"]:
+                   v = v[1:-1]
+               if k == 'mpmd':
+                   self.mpmd = eval('MPI_MPMD_' + v)
+               else:
+                   self.__dict__[k] = v
+
+    #---------------------------------------------------------------------------
+
+    def __get_mpiexec_absname__(self, p):
+
+        """
+        Build absolute pathname matching mpiexec command.
+        """
+
+        absname = ''
+
+        if self.mpiexec != None:
+            if os.path.isabs(self.mpiexec):
+                absname = self.mpiexec
+            else:
+                for d in p:
+                    absname = os.path.join(d, self.mpiexec)
+                    if os.path.isfile(absname):
+                        break
+                    else:
+                        absname = ''
+
+        return absname
+
     #---------------------------------------------------------------------------
 
     def __get_mpich2_3_default_pm__(self, mpiexec_path):
@@ -1092,31 +1296,43 @@ class mpi_environment:
         # 'gforker', and 'remshell' are defined by the standard MPICH
         # install and determine the associated launcher.
 
-        launcher_names = ['mpiexec.mpich', 'mpiexec.mpich2', 'mpiexec',
-                          'mpiexec.hydra', 'mpiexec.mpd', 'mpiexec.smpd',
-                          'mpiexec.gforker', 'mpiexec.remshell',
-                          'mpirun.mpich2', 'mpirun.mpich2', 'mpirun']
-
         pm = ''
-        for d in p:
-            for name in launcher_names:
-                absname = os.path.join(d, name)
-                if os.path.isfile(absname):
-                    pm = self.__get_mpich2_3_default_pm__(absname)
-                    # Set launcher name
-                    if d == self.bindir:
-                        self.mpiexec = absname
+        absname = ''
+
+        if self.mpiexec != None:
+            absname = self.__get_mpiexec_absname__(p)
+            pm = self.__get_mpich2_3_default_pm__(absname)
+
+        else:
+            launcher_names = ['mpiexec.mpich', 'mpiexec.mpich2', 'mpiexec',
+                              'mpiexec.hydra', 'mpiexec.smpd',
+                              'mpiexec.gforker', 'mpiexec.remshell',
+                              'mpirun.mpich2', 'mpirun.mpich', 'mpirun']
+
+            for d in p:
+                for name in launcher_names:
+                    absname = os.path.join(d, name)
+                    if os.path.isfile(absname):
+                        pm = self.__get_mpich2_3_default_pm__(absname)
+                        if pm == 'mpd': # MPD is deprecated; avoid it
+                            continue
+                        # Set launcher name
+                        if d == self.bindir:
+                            self.mpiexec = absname
+                        else:
+                            self.mpiexec = name
+                        break
                     else:
-                        self.mpiexec = name
+                        absname = ''
+                    if self.mpiexec != None:
+                        break
+                if self.mpiexec != None:
                     break
-            if self.mpiexec != None:
-                break
 
         if (self.mpiexec == None):
-            basename = 'mpiexec'
             self.mpiexec = 'mpiexec'
-        else:
-            basename = os.path.basename(self.mpiexec)
+
+        basename = os.path.basename(self.mpiexec)
 
         # Determine if SMPD should be handled
 
@@ -1161,12 +1377,17 @@ class mpi_environment:
 
         launcher_base = os.path.basename(self.mpiexec)
 
-        if launcher_base[:7] == 'mpiexec':
-            self.mpmd = MPI_MPMD_mpiexec | MPI_MPMD_configfile | MPI_MPMD_script
-            self.mpiexec_n = ' -n '
-        elif launcher_base[:6] == 'mpirun':
-            self.mpiexec_n = ' -np '
-            self.mpmd = MPI_MPMD_script
+        if not self.mpiexec_n:
+            if launcher_base[:7] == 'mpiexec':
+                self.mpiexec_n = ' -n '
+            elif launcher_base[:6] == 'mpirun':
+                self.mpiexec_n = ' -np '
+
+        if not self.mpmd:
+            if launcher_base[:7] == 'mpiexec':
+                self.mpmd = MPI_MPMD_mpiexec | MPI_MPMD_configfile | MPI_MPMD_script
+            elif launcher_base[:6] == 'mpirun':
+                self.mpmd = MPI_MPMD_script
 
         # Other options to add
 
@@ -1183,9 +1404,9 @@ class mpi_environment:
                 if hostsfile != None:
                     self.mpiexec += ' -f ' + hostsfile
 
-            if (resource_info != None):
+            if resource_info != None and not self.mpiexec_n_per_node:
                 ppn = resource_info.n_procs_per_node()
-                if ppn != 1:
+                if ppn:
                     self.mpiexec_n_per_node = ' -ppn ' + str(ppn)
 
         elif pm == 'smpd':
@@ -1247,56 +1468,6 @@ class mpi_environment:
 
     #---------------------------------------------------------------------------
 
-    def __init_mpich1__(self, p, resource_info=None, wdir = None):
-
-        """
-        Initialize for MPICH1 environment.
-        """
-
-        # Determine base executable paths
-
-        launcher_names = ['mpirun.mpich',
-                          'mpirun.mpich-mpd',
-                          'mpirun.mpich-shmem',
-                          'mpirun']
-
-        for d in p:
-            for name in launcher_names:
-                absname = os.path.join(d, name)
-                if os.path.isfile(absname):
-                    if d == self.bindir:
-                        self.mpiexec = absname
-                    else:
-                        self.mpiexec = name
-                    break
-            if self.mpiexec != None:
-                break
-
-        # Determine processor count and MPMD handling
-
-        self.mpiexec_n = ' -np '
-        self.mpmd = MPI_MPMD_script
-
-        # MPD daemons must be launched using the ch_p4mpd device,
-        # but may not be automated as easily as with MPICH2's mpdboot,
-        # so it is not handled here, and must be managed explicitely
-        # by the user or environment.
-
-        # Other options to add
-
-        # Resource manager info
-
-        if resource_info != None:
-            hostsfile = resource_info.get_hosts_file(wdir)
-            if hostsfile != None:
-                self.mpiexec += ' -machinefile ' + hostsfile
-
-        # Info commands
-
-        self.info_cmds = ['mpichversion']
-
-    #---------------------------------------------------------------------------
-
     def __init_openmpi__(self, p, resource_info=None, wdir = None):
         """
         Initialize for OpenMPI environment.
@@ -1304,36 +1475,54 @@ class mpi_environment:
 
         # Determine base executable paths
 
-        launcher_names = ['mpiexec.openmpi', 'mpirun.openmpi',
-                          'mpiexec', 'mpirun']
-        info_name = ''
+        if self.mpiexec != None:
+            absname = self.__get_mpiexec_absname__(p)
 
-        for d in p:
-            for name in launcher_names:
-                absname = os.path.join(d, name)
-                if os.path.isfile(absname):
-                    if d == self.bindir:
-                        self.mpiexec = absname
+        else:
+            launcher_names = ['mpiexec.openmpi', 'mpirun.openmpi',
+                              'mpiexec', 'mpirun']
+
+            for d in p:
+                for name in launcher_names:
+                    absname = os.path.join(d, name)
+                    if os.path.isfile(absname):
+                        if d == self.bindir:
+                            self.mpiexec = absname
+                        else:
+                            self.mpiexec = name
+                        break
                     else:
-                        self.mpiexec = name
-                    info_name = os.path.join(d, 'ompi_info')
+                        absname = ''
+                    if self.mpiexec != None:
+                        break
+                if self.mpiexec != None:
                     break
-            if self.mpiexec != None:
-                break
+
+        if (self.mpiexec == None):
+            self.mpiexec = 'mpiexec'
+
+        if absname:
+            info_name = os.path.join(os.path.dirname(absname),
+                                     'ompi_info')
+        else:
+            info_name = ''
 
         # Determine processor count and MPMD handling
 
         launcher_base = os.path.basename(self.mpiexec)
 
-        self.mpiexec_n = ' -n '
-        if (resource_info != None):
+        if not self.mpiexec_n:
+            self.mpiexec_n = ' -n '
+        if resource_info != None and not self.mpiexec_n_per_node:
             ppn = resource_info.n_procs_per_node()
-            if ppn != 1:
+            if ppn:
                 self.mpiexec_n_per_node = ' --npernode ' + str(ppn)
-        if launcher_base[:7] == 'mpiexec':
-            self.mpmd = MPI_MPMD_mpiexec | MPI_MPMD_script
-        elif launcher_base[:7] == 'mpirun':
-            self.mpmd = MPI_MPMD_script
+
+        if not self.mpmd:
+            if launcher_base[:7] == 'mpiexec':
+                self.mpmd = MPI_MPMD_mpiexec | MPI_MPMD_script
+            elif launcher_base[:6] == 'mpirun':
+                self.mpmd = MPI_MPMD_script
 
         # Other options to add
 
@@ -1362,54 +1551,6 @@ class mpi_environment:
 
     #---------------------------------------------------------------------------
 
-    def __init_lam__(self, p, resource_info=None, wdir = None):
-        """
-        Initialize for LAM/MPI environment.
-        We choose to use the mpiexec command, which wraps lamboot,
-        mpirun, and lamhalt, and provides for a basically standard
-        mpiexec syntax.
-        """
-
-        # Determine base executable paths
-
-        launcher_names = ['mpiexec.lam', 'mpiexec']
-
-        for d in p:
-            for name in launcher_names:
-                absname = os.path.join(d, name)
-                if os.path.isfile(absname):
-                    if d == self.bindir:
-                        self.mpiexec = absname
-                    else:
-                        self.mpiexec = name
-                    break
-            if self.mpiexec != None:
-                break
-
-        # Determine processor count and MPMD handling
-
-        launcher_base = os.path.basename(self.mpiexec)
-
-        self.mpiexec_n = ' -n '
-        self.mpmd = MPI_MPMD_mpiexec | MPI_MPMD_script
-
-        # Resource manager info
-
-        hostsfile = None
-        if resource_info != None:
-            hostsfile = resource_info.get_hosts_file(wdir)
-
-        if hostsfile != None:
-            self.mpiexec += ' --machinefile ' + hostsfile
-        else:
-            self.mpiexec += ' --boot'
-
-        # Info commands
-
-        self.info_cmds = ['laminfo -all']
-
-    #---------------------------------------------------------------------------
-
     def __init_bgp__(self, p, resource_info=None, wdir = None):
 
         """
@@ -1454,7 +1595,7 @@ class mpi_environment:
         if rm == 'SLURM':
             self.mpiexec = 'srun'
             self.mpiexec_n = ' --ntasks='
-            if ppn != 1:
+            if ppn:
                 self.mpiexec_n_per_node = ' --ntasks-per-node=' + str(ppn)
         else:
             if ppn != 1:
@@ -1471,19 +1612,18 @@ class mpi_environment:
 
     #---------------------------------------------------------------------------
 
-    def __init_hp_mpi__(self, p, resource_info=None, wdir = None):
+    def __init_platform_mpi__(self, p, resource_info=None, wdir = None):
         """
-        Initialize for HP MPI environment.
+        Initialize for Platform MPI environment.
 
         The last version of HP MPI is version 2.3, released early 2009.
         HP MPI was then acquired by Platform MPI (formerly Scali MPI),
         which merged Scali MPI and HP MPI in Platform MPI 8.0.
-        Platform MPI still seems to use the mpirun launcher syntax.
         """
 
         # Determine base executable paths
 
-        self.mpiexec = 'mpirun'
+        self.mpiexec = 'mpirun' # mpiexec also possible, but fewer options
 
         for d in p:
             if not os.path.isabs(self.mpiexec):
@@ -1494,6 +1634,7 @@ class mpi_environment:
                     break
 
         # Determine processor count and MPMD handling
+        # Appfile also possible, but uses -np instead of -n
 
         self.mpmd = MPI_MPMD_script
         self.mpiexec_n = '-np'
@@ -1588,12 +1729,7 @@ class mpi_environment:
         # but these are cases on systems we have used in the past
         # but do not currently have access to).
 
-        if platform.uname()[0] == 'OSF1':
-            if abs_exec_path('prun') != None:
-                self.mpiexec = 'prun'
-                self.mpiexec_n = ' -n '
-
-        elif platform.uname()[0] == 'AIX':
+        if platform.uname()[0] == 'AIX':
             if abs_exec_path('poe') != None:
                 self.mpiexec = 'poe'
                 self.mpiexec_n = None
@@ -1655,24 +1791,6 @@ class exec_environment:
 
         self.mpi_env = mpi_environment(pkg, self.resources, wdir)
 
-        # Modify options based on system-wide or user configuration
-
-        config = configparser.ConfigParser()
-        config.read(pkg.get_configfiles())
-
-        if config.has_section('mpi'):
-            for option in config.items('mpi'):
-               k = option[0]
-               v = option[1]
-               if not v:
-                   v = None
-               elif v[0] in ['"', "'"]:
-                   v = v[1:-1]
-               if k == 'mpmd':
-                   self.mpi_env.mpmd_mode = eval(v)
-               else:
-                   self.mpi_env.__dict__[k] = v
-
 #-------------------------------------------------------------------------------
 
 if __name__ == '__main__':
