@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -51,10 +51,6 @@ except Exception:
 # Third-party modules
 #-------------------------------------------------------------------------------
 
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
-
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
 
@@ -71,6 +67,7 @@ from Pages.BatchRunningStopByIterationDialogForm import Ui_BatchRunningStopByIte
 
 from Base.Toolbox import GuiParam
 from Base.QtPage import ComboModel, IntValidator, RegExpValidator, setGreenColor
+from Base.QtPage import to_qvariant, from_qvariant
 from Base.CommandMgrDialogView import CommandMgrDialogView
 from Pages.BatchRunningModel import BatchRunningModel
 from Pages.ScriptRunningModel import ScriptRunningModel
@@ -298,6 +295,7 @@ class BatchRunningStopByIterationDialogView(QDialog, Ui_BatchRunningStopByIterat
         self.result  = self.default.copy()
 
         v = IntValidator(self.lineEditStopIter, min=1)
+        v.setExclusiveMin(True)
         self.lineEditStopIter.setValidator(v)
 
         # Previous values
@@ -315,7 +313,7 @@ class BatchRunningStopByIterationDialogView(QDialog, Ui_BatchRunningStopByIterat
         Private slot to set a iteration number to stop the code.
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            iter = int(text)
+            iter = from_qvariant(text, int)
             self.iter = iter
 
 
@@ -525,8 +523,6 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
 
         self.class_list = None
 
-        self.n_procs = None
-
         if self.case['batch_type'] != None:
 
             self.groupBoxArchi.setTitle("Job and script files")
@@ -541,10 +537,15 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
 
         else:
 
-            try:
-                self.n_procs = int(self.mdl.getString('n_procs'))
-            except Exception:
-                self.n_procs = 1
+            if self.jmdl.dictValues['run_nprocs'] == None:
+                try:
+                    # For backwards compatibility
+                    # (this is a specific case, as we move information from
+                    # the XML model to the batch script)
+                    self.jmdl.dictValues['run_nprocs'] = self.mdl.getString('n_procs')
+                    self.mdl.setString('n_procs', None)
+                except Exception:
+                    pass
 
 
         # Connections
@@ -689,8 +690,11 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         """
         Increment, decrement and colorize the input argument entry
         """
-        self.n_procs = int(v)
-        self.mdl.setString('n_procs', str(v))
+        if v > 1:
+            self.jmdl.dictValues['run_nprocs'] = str(v)
+        else:
+            self.jmdl.dictValues['run_nprocs'] = None
+        self.jmdl.updateBatchFile('run_nprocs')
 
 
     @pyqtSignature("")
@@ -849,7 +853,6 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         run_new_f.close()
 
 
-
     def getCommandOutput(self, cmd):
         """
         Run a command and return it's standard output.
@@ -1027,10 +1030,10 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
                 self.getClassList()
                 if len(self.class_list) > 0:
                     for c in self.class_list:
-                        self.comboBoxClass.addItem(self.tr(c), c)
+                        self.comboBoxClass.addItem(self.tr(c), to_qvariant(c))
                 else:
                     c = self.job_class
-                    self.comboBoxClass.addItem(self.tr(c), c)
+                    self.comboBoxClass.addItem(self.tr(c), to_qvariant(c))
 
             # All passes
             try:
@@ -1087,7 +1090,12 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
             self.spinBoxNProcs.hide()
 
         if self.case['batch_type'] == None:
-            self.spinBoxNProcs.setValue(self.n_procs)
+            n_procs_s = self.jmdl.dictValues['run_nprocs']
+            if n_procs_s:
+                n_procs = int(n_procs_s)
+            else:
+                n_procs = 1
+            self.spinBoxNProcs.setValue(n_procs)
         else:
             pass
 
