@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -46,6 +46,18 @@ import Base.Toolbox as Tool
 from Base.XMLvariables import Variables, Model
 from Base.XMLmodel import XMLmodel, ModelTest
 
+#-------------------------------------------------------------------------------
+# EOS
+#-------------------------------------------------------------------------------
+
+EOS = 1
+try:
+   import eosAva
+except:
+   EOS = 0
+else :
+   import eosAva
+
 #-------------------------------------------------------------------------------
 # Model class
 #-------------------------------------------------------------------------------
@@ -69,6 +81,12 @@ class FluidCharacteristicsModel(Variables, Model):
         self.node_heat      = self.setNewFluidProperty(self.node_fluid, 'specific_heat')
         self.node_cond      = self.setNewFluidProperty(self.node_fluid, 'thermal_conductivity')
 
+        import cs_config
+        cfg = cs_config.config()
+        self.freesteam = 0
+        if cfg.libs['freesteam'].have != "no":
+            self.freesteam = 1
+
 
     def __nodeFromTag(self, name):
         """
@@ -85,7 +103,7 @@ class FluidCharacteristicsModel(Variables, Model):
                              self.node_heat, self.node_dyn)
 
         elif self.node_comp['model'] != None and self.node_comp['model'] != 'off':
-            self.node_vol_visc  = self.setNewFluidProperty(self.node_fluid, 'volumic_viscosity')
+            self.node_vol_visc  = self.setNewFluidProperty(self.node_fluid, 'volume_viscosity')
             self.node_dyn = self.setNewFluidProperty(self.node_fluid, 'dynamic_diffusion')
             self.node_cond      = self.setNewFluidProperty(self.node_fluid, 'thermal_conductivity')
             self.nodeList = (self.node_density, self.node_viscosity,
@@ -114,7 +132,10 @@ class FluidCharacteristicsModel(Variables, Model):
         default['specific_heat']        = 1017.24
         default['thermal_conductivity'] = 0.02495
         default['dynamic_diffusion']    = 0.01
-        default['volumic_viscosity']    = 0.
+        default['volume_viscosity']    = 0.
+        default['material']             = "user_material"
+        default['method']               = "user_properties"
+        default['phas']                 = "liquid"
 
         return default
 
@@ -181,6 +202,150 @@ class FluidCharacteristicsModel(Variables, Model):
                d['compressible_model']
 
 
+    @Variables.noUndo
+    def getMaterials(self):
+        """
+        get the nature of materials
+        """
+        nodem = self.node_fluid.xmlGetNode('material')
+        if nodem == None:
+            material = self.defaultFluidCharacteristicsValues()['material']
+            self.setMaterials(material)
+            nodem = self.node_fluid.xmlGetNode('material')
+        material = nodem['choice']
+        return material
+
+
+    @Variables.undoLocal
+    def setMaterials(self, material):
+        """
+        set the nature of materials
+        """
+        childNode = self.node_fluid.xmlInitChildNode('material')
+        m = childNode.xmlGetNode('material')
+        oldMaterial = None
+        if m != None:
+            oldMaterial = m['choice']
+        childNode.xmlSetAttribute(choice = material)
+        self.updateMethod(oldMaterial)
+
+        if material == "user_material":
+            for node in self.node_fluid.xmlGetChildNodeList('property'):
+                if node['choice'] == "thermal_law":
+                    node['choice'] = "variable"
+
+
+    @Variables.noUndo
+    def getMethod(self):
+        """
+        get the nature of materials
+        """
+        nodem = self.node_fluid.xmlGetNode('method')
+        if nodem == None:
+            method = self.defaultFluidCharacteristicsValues()['method']
+            self.setMethod(method)
+            nodem = self.node_fluid.xmlGetNode('method')
+        method = nodem['choice']
+        return method
+
+
+    @Variables.undoLocal
+    def setMethod(self, method):
+        """
+        update reference value for EOS
+        """
+        childNode = self.node_fluid.xmlInitChildNode('method')
+        childNode.xmlSetAttribute(choice = method)
+        self.getReference()
+
+        # suppress phas choice if not EOS
+        if method == self.defaultFluidCharacteristicsValues()['method'] or \
+           method == "freesteam":
+            nodem = self.node_fluid.xmlGetNode('phas')
+            if nodem:
+                nodem .xmlRemoveNode()
+
+
+    @Variables.undoGlobal
+    def updateMethod(self, oldMaterial):
+        """
+        update reference value for EOS
+        """
+        material = self.getMaterials()
+        if oldMaterial != material:
+            if material == self.defaultFluidCharacteristicsValues()['material'] :
+               self.setMethod(self.defaultFluidCharacteristicsValues()['method'])
+            elif EOS == 1:
+               self.ava = eosAva.EosAvailable()
+               self.ava.setMethods(material)
+               self.setMethod(self.ava.whichMethods()[0])
+            else:
+                self.setMethod("freesteam")
+            # suppress phas choice if not EOS
+            if self.getMethod() == self.defaultFluidCharacteristicsValues()['method'] or \
+               self.getMethod() == "freesteam":
+                nodem = self.node_fluid.xmlGetNode('phas')
+                if nodem:
+                   nodem .xmlRemoveNode()
+
+
+    @Variables.noUndo
+    def getReference(self):
+        """
+        return reference value for EOS
+        """
+        reference = ""
+        material = self.getMaterials()
+        method = self.getMethod()
+        if material == "user_material":
+            reference = material
+        else:
+            if self.freesteam == 1:
+                if self.getMethod() == "freesteam":
+                    reference = "freesteam"
+            if EOS == 1:
+                if self.getMethod() != "freesteam":
+                    phas = self.getFieldNature()
+                    self.ava = eosAva.EosAvailable()
+                    self.ava.setMethods(material)
+                    self.ava.setReferences(material, self.getMethod())
+                    ref = self.ava.whichReferences()
+
+                    if phas == "liquid" :
+                        reference = ref[0]
+                    elif phas == "gas" :
+                        reference = ref[1]
+        # update XML
+        childNode = self.node_fluid.xmlInitChildNode('reference')
+        childNode.xmlSetAttribute(choice = reference)
+
+        return reference
+
+
+    @Variables.noUndo
+    def getFieldNature(self):
+        """
+        get field nature for EOS
+        """
+        nodem = self.node_fluid.xmlGetNode('phas')
+        if nodem == None:
+            nature = self.defaultFluidCharacteristicsValues()['phas']
+            self.setFieldNature(nature)
+            nodem = self.node_fluid.xmlGetNode('phas')
+        nature = nodem['choice']
+        return nature
+
+
+    @Variables.noUndo
+    def setFieldNature(self, nature):
+        """
+        set field nature for EOS
+        """
+        self.isInList(nature, ('liquid', 'gas'))
+        childNode = self.node_fluid.xmlInitChildNode('phas')
+        childNode.xmlSetAttribute(choice = nature)
+
+
     @Variables.noUndo
     def getInitialValue(self, tag):
         """
@@ -189,7 +354,7 @@ class FluidCharacteristicsModel(Variables, Model):
         """
         self.isInList(tag, ('density', 'molecular_viscosity',
                             'specific_heat', 'thermal_conductivity',
-                            'volumic_viscosity', 'dynamic_diffusion'))
+                            'volume_viscosity', 'dynamic_diffusion'))
         node = self.node_fluid.xmlGetNode('property', name=tag)
         pp = node.xmlGetDouble('initial_value')
         if pp == None:
@@ -206,8 +371,8 @@ class FluidCharacteristicsModel(Variables, Model):
         """
         self.isInList(tag, ('density', 'molecular_viscosity',
                             'specific_heat', 'thermal_conductivity',
-                            'volumic_viscosity', 'dynamic_diffusion'))
-        if tag != 'volumic_viscosity':
+                            'volume_viscosity', 'dynamic_diffusion'))
+        if tag != 'volume_viscosity':
             self.isGreater(val, 0.)
         else:
             self.isPositiveFloat(val)
@@ -242,13 +407,13 @@ class FluidCharacteristicsModel(Variables, Model):
     @Variables.noUndo
     def getInitialValueVolumicViscosity(self):
         """Return initial value of volumic viscosity"""
-        return self.getInitialValue('volumic_viscosity')
+        return self.getInitialValue('volume_viscosity')
 
 
     @Variables.undoLocal
     def setInitialValueVolumicViscosity(self, val):
         """Put initial value for volumic viscosity"""
-        self.setInitialValue('volumic_viscosity', val)
+        self.setInitialValue('volume_viscosity', val)
 
 
     @Variables.noUndo
@@ -295,7 +460,7 @@ class FluidCharacteristicsModel(Variables, Model):
         """
         self.isInList(tag, ('density', 'molecular_viscosity',
                             'specific_heat', 'thermal_conductivity',
-                            'volumic_viscosity'))
+                            'volume_viscosity'))
         node = self.node_fluid.xmlGetNode('property', name=tag)
         formula = node.xmlGetString('formula')
         if not formula:
@@ -311,17 +476,17 @@ class FluidCharacteristicsModel(Variables, Model):
         """
         self.isInList(tag, ('density', 'molecular_viscosity',
                             'specific_heat', 'thermal_conductivity',
-                            'volumic_viscosity'))
+                            'volume_viscosity'))
         if tag == "density":
-            formula = "rho ="
+            formula = "rho = -1.;"
         elif tag == "molecular_viscosity":
-            formula = "mu ="
+            formula = "mu = -1.;"
         elif tag == "specific_heat":
-            formula = "cp ="
-        elif tag == "volumic_viscosity":
-            formula = "Viscv ="
+            formula = "cp = -1.;"
+        elif tag == "volume_viscosity":
+            formula = "Viscv = -1.;"
         elif tag == "thermal_conductivity":
-            formula = "lambda ="
+            formula = "lambda = -1.;"
 
         return formula
 
@@ -334,7 +499,7 @@ class FluidCharacteristicsModel(Variables, Model):
         """
         self.isInList(tag, ('density', 'molecular_viscosity',
                             'specific_heat', 'thermal_conductivity',
-                            'volumic_viscosity'))
+                            'volume_viscosity'))
         node = self.node_fluid.xmlGetNode('property', name=tag)
         node.xmlSetData('formula', str)
 
@@ -344,10 +509,10 @@ class FluidCharacteristicsModel(Variables, Model):
         """Return choice of node I{tag}. Choice is constant or variable"""
         self.isInList(tag, ('density', 'molecular_viscosity',
                             'specific_heat', 'thermal_conductivity',
-                            'volumic_viscosity'))
+                            'volume_viscosity'))
         node = self.__nodeFromTag(tag)
         c = node['choice']
-        self.isInList(c, ('constant', 'user_law', 'variable'))
+        self.isInList(c, ('constant', 'thermal_law', 'variable'))
         return c
 
 
@@ -356,8 +521,8 @@ class FluidCharacteristicsModel(Variables, Model):
         """Put choice in xml file's node I{tag}"""
         self.isInList(tag, ('density', 'molecular_viscosity',
                             'specific_heat', 'thermal_conductivity',
-                            'volumic_viscosity'))
-        self.isInList(choice, ('constant', 'user_law', 'variable'))
+                            'volume_viscosity'))
+        self.isInList(choice, ('constant', 'thermal_law', 'variable'))
 
         node = self.__nodeFromTag(tag)
         node['choice'] = choice
