@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -207,12 +207,14 @@ class VolumicZone(Zone):
 
         if self.case['package'].name == 'code_saturne':
             self._natureList.append('head_losses')
+            self._natureList.append('porosity')
             self._natureList.append('momentum_source_term')
 
         self._natureDict = {}
         self._natureDict['initialization']       = self.tr("Initialization")
         if self.case['package'].name == 'code_saturne':
             self._natureDict['head_losses']          = self.tr("Head losses")
+            self._natureDict['porosity']             = self.tr("Porosity")
             self._natureDict['momentum_source_term'] = self.tr("Momentum source\n term")
 
         from Pages.ThermalScalarModel import ThermalScalarModel
@@ -222,7 +224,7 @@ class VolumicZone(Zone):
         del ThermalScalarModel
 
         node = self.case.xmlGetNode('additional_scalars')
-        number = len(node.xmlGetNodeList('scalar', type='user'))
+        number = len(node.xmlGetNodeList('variable', type='user'))
         if number > 0:
             self._natureList.append('scalar_source_term')
             self._natureDict['scalar_source_term']   = self.tr("Scalar source term")
@@ -234,6 +236,7 @@ class VolumicZone(Zone):
         dico['nature'] = {}
         dico['nature']['initialization']       = "on"
         dico['nature']['head_losses']          = "off"
+        dico['nature']['porosity']             = "off"
         dico['nature']['momentum_source_term'] = "off"
         dico['nature']['mass_source_term']     = "off"
         dico['nature']['thermal_source_term']  = "off"
@@ -871,21 +874,38 @@ class BoundaryLocalizationModel(LocalizationModel):
         """
         Replace a zone by another in the XML file
         """
-        Boundary(old_zone.getNature(), old_zone.getLabel(), self.case).delete()
-        newLabel, newCodeNumber, newLocal = LocalizationModel.replaceZone(self, old_zone, new_zone)
+        if (new_zone.getNature() != old_zone.getNature()):
+            Boundary(old_zone.getNature(), old_zone.getLabel(), self.case).delete()
+            newLabel, newCodeNumber, newLocal = LocalizationModel.replaceZone(self, old_zone, new_zone)
 
-        newNature = new_zone.getNature()
-        Model().isInList(newNature, self.__natureList)
+            newNature = new_zone.getNature()
+            Model().isInList(newNature, self.__natureList)
 
-        node = self.__XMLBoundaryConditionsNode.xmlGetNode('boundary',
+            node = self.__XMLBoundaryConditionsNode.xmlGetNode('boundary',
                                                             label = old_zone.getLabel())
 
-        node['label'] = newLabel
-        node['name'] = newCodeNumber
-        node['nature'] = newNature
-        node.xmlSetTextNode(newLocal)
+            node['label'] = newLabel
+            node['name'] = newCodeNumber
+            node['nature'] = newNature
+            node.xmlSetTextNode(newLocal)
 
-        Boundary(new_zone.getNature(), new_zone.getLabel(), self.case)
+            Boundary(new_zone.getNature(), new_zone.getLabel(), self.case)
+        else:
+            label      = old_zone.getLabel()
+            codeNumber = old_zone.getCodeNumber()
+            localis    = old_zone.getLocalization()
+
+            newLabel = new_zone.getLabel()
+            if label != newLabel:
+                self.setLabel(label, newLabel)
+
+            newCodeNumber = new_zone.getCodeNumber()
+            if codeNumber != newCodeNumber:
+                self.setCodeNumber(codeNumber, newCodeNumber)
+
+            newLocal = new_zone.getLocalization()
+            if localis != newLocal:
+                self.setLocalization(newLabel, newLocal)
 
 
     @Variables.undoGlobal
@@ -914,8 +934,13 @@ class BoundaryLocalizationModel(LocalizationModel):
         node = self.__XMLBoundaryConditionsNode.xmlGetNode('boundary', 'name', 'nature', label = label)
         node.xmlSetTextNode(localization)
 
+        lst.reverse()
+
         for z in lst:
             n = self.__XMLBoundaryConditionsNode.xmlGetNode('boundary', 'nature', 'label', name = z + 1)
+            label = n['label']
+            nature = n['nature']
+            Boundary(nature, label, self.case).delete()
             n.xmlRemoveNode()
 
         count = 1
@@ -949,7 +974,7 @@ class LocalizationVolumicTestCase(ModelTest):
         node = self.case.xmlGetNode('volumic_conditions')
 
         doc = '''<volumic_conditions>
-                    <zone head_losses="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
                             all[]
                     </zone>
                  </volumic_conditions>'''
@@ -970,19 +995,19 @@ class LocalizationVolumicTestCase(ModelTest):
         model.addZone()
 
         doc = '''<volumic_conditions>
-                    <zone head_losses="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
                             all[]
                     </zone>
-                    <zone head_losses="off" initialization="on" label="Zone_1" mass_source_term="off" momentum_source_term="off" name="2" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="Zone_1" mass_source_term="off" momentum_source_term="off" name="2" thermal_source_term="off">
                             not(all[])
                     </zone>
-                    <zone head_losses="off" initialization="on" label="toto" mass_source_term="off" momentum_source_term="off" name="3" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="toto" mass_source_term="off" momentum_source_term="off" name="3" thermal_source_term="off">
                             1 or door
                     </zone>
-                    <zone head_losses="off" initialization="on" label="fenetre" mass_source_term="off" momentum_source_term="off" name="4" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="fenetre" mass_source_term="off" momentum_source_term="off" name="4" thermal_source_term="off">
                             12 and window or door
                     </zone>
-                    <zone head_losses="off" initialization="on" label="Zone_2" mass_source_term="off" momentum_source_term="off" name="5" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="Zone_2" mass_source_term="off" momentum_source_term="off" name="5" thermal_source_term="off">
                             not(all[];not(all[]);1 or door;12 and window or door)
                     </zone>
                 </volumic_conditions>'''
@@ -994,13 +1019,13 @@ class LocalizationVolumicTestCase(ModelTest):
         model.deleteZone(label="Zone_2")
 
         doc = '''<volumic_conditions>
-                    <zone head_losses="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
                             all[]
                     </zone>
-                    <zone head_losses="off" initialization="on" label="Zone_1" mass_source_term="off" momentum_source_term="off" name="2" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="Zone_1" mass_source_term="off" momentum_source_term="off" name="2" thermal_source_term="off">
                             not(all[])
                     </zone>
-                    <zone head_losses="off" initialization="on" label="fenetre" mass_source_term="off" momentum_source_term="off" name="4" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="fenetre" mass_source_term="off" momentum_source_term="off" name="4" thermal_source_term="off">
                             12 and window or door
                     </zone>
                 </volumic_conditions>'''
@@ -1025,16 +1050,16 @@ class LocalizationVolumicTestCase(ModelTest):
         model.replaceZone(zone1, new_zone)
 
         doc = '''<volumic_conditions>
-                    <zone head_losses="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
                             all[]
                     </zone>
-                    <zone head_losses="off" initialization="on" label="Zone_1" mass_source_term="off" momentum_source_term="off" name="2" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="Zone_1" mass_source_term="off" momentum_source_term="off" name="2" thermal_source_term="off">
                             not(all[])
                     </zone>
-                    <zone head_losses="off" initialization="on" label="toto" mass_source_term="off" momentum_source_term="off" name="3" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="toto" mass_source_term="off" momentum_source_term="off" name="3" thermal_source_term="off">
                             1 or door
                     </zone>
-                    <zone head_losses="off" initialization="on" label="window" mass_source_term="off" momentum_source_term="off" name="4" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="window" mass_source_term="off" momentum_source_term="off" name="4" thermal_source_term="off">
                             12 or window or door
                     </zone>
                 </volumic_conditions>'''
@@ -1055,16 +1080,16 @@ class LocalizationVolumicTestCase(ModelTest):
 
         model.setLocalization("Zone_1", "1 and 2 and 3 or group1")
         doc = '''<volumic_conditions>
-                    <zone head_losses="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
                             all[]
                     </zone>
-                    <zone head_losses="off" initialization="on" label="Zone_1" mass_source_term="off" momentum_source_term="off" name="2" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="Zone_1" mass_source_term="off" momentum_source_term="off" name="2" thermal_source_term="off">
                             1 and 2 and 3 or group1
                     </zone>
-                    <zone head_losses="off" initialization="on" label="toto" mass_source_term="off" momentum_source_term="off" name="3" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="toto" mass_source_term="off" momentum_source_term="off" name="3" thermal_source_term="off">
                             1 or door
                     </zone>
-                    <zone head_losses="off" initialization="on" label="fenetre" mass_source_term="off" momentum_source_term="off" name="4" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="fenetre" mass_source_term="off" momentum_source_term="off" name="4" thermal_source_term="off">
                             12 and window or door
                     </zone>
                 </volumic_conditions>'''
@@ -1086,16 +1111,16 @@ class LocalizationVolumicTestCase(ModelTest):
         model.setNature('porte', "head_losses,thermal_source_term")
 
         doc = '''<volumic_conditions>
-                    <zone head_losses="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="all_cells" mass_source_term="off" momentum_source_term="off" name="1" thermal_source_term="off">
                             all[]
                     </zone>
-                    <zone head_losses="off" initialization="on" label="Zone_1" mass_source_term="off" momentum_source_term="off" name="2" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="Zone_1" mass_source_term="off" momentum_source_term="off" name="2" thermal_source_term="off">
                             not(all[])
                     </zone>
-                    <zone head_losses="on" initialization="off" label="porte" mass_source_term="off" momentum_source_term="off" name="3" thermal_source_term="on">
+                    <zone head_losses="on" porosity="off" initialization="off" label="porte" mass_source_term="off" momentum_source_term="off" name="3" thermal_source_term="on">
                             1 or door
                     </zone>
-                    <zone head_losses="off" initialization="on" label="fenetre" mass_source_term="off" momentum_source_term="off" name="4" thermal_source_term="off">
+                    <zone head_losses="off" porosity="off" initialization="on" label="fenetre" mass_source_term="off" momentum_source_term="off" name="4" thermal_source_term="off">
                             12 and window or door
                     </zone>
                 </volumic_conditions>'''
