@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -38,10 +38,6 @@ import logging
 #-------------------------------------------------------------------------------
 # Third-party modules
 #-------------------------------------------------------------------------------
-import sys
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
@@ -52,7 +48,7 @@ from PyQt4.QtGui  import *
 
 from Base.Toolbox   import GuiParam
 from Pages.MobileMeshForm  import Ui_MobileMeshForm
-from Base.QtPage    import setGreenColor, IntValidator,  ComboModel
+from Base.QtPage    import setGreenColor, IntValidator,  ComboModel, from_qvariant
 from Pages.MobileMeshModel import MobileMeshModel
 
 from Pages.QMeiEditorView import QMeiEditorView
@@ -192,7 +188,7 @@ if (xray2 < xr2) {
         Input viscosity type of mesh : isotrop or orthotrop.
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            nalinf = int(text)
+            nalinf = from_qvariant(text, int)
             self.mdl.setSubIterations(nalinf)
 
 
@@ -217,15 +213,15 @@ if (xray2 < xr2) {
 
         if self.mdl.getViscosity() == 'isotrop':
             if not exp:
-                exp = "mesh_vi1 = 1;"
-            req = [('mesh_vi1', 'mesh viscosity')]
+                exp = "mesh_viscosity_1 = 1;"
+            req = [('mesh_viscosity_1', 'mesh viscosity')]
             exa = MobileMeshView.viscosity_iso
         else:
             if not exp:
-                exp = "mesh_vi1 = 1;\nmesh_vi2 = 1;\nmesh_vi3 = 1;"
-            req = [('mesh_vi1', 'mesh viscosity X'),
-                   ('mesh_vi2', 'mesh viscosity Y'),
-                   ('mesh_vi3', 'mesh viscosity Z')]
+                exp = "mesh_viscosity_1 = 1;\nmesh_viscosity_2 = 1;\nmesh_viscosity_3 = 1;"
+            req = [('mesh_viscosity_1', 'mesh viscosity X'),
+                   ('mesh_viscosity_2', 'mesh viscosity Y'),
+                   ('mesh_viscosity_3', 'mesh viscosity Z')]
             exa = MobileMeshView.viscosity_ortho
 
         symb = [('x', "X cell's gravity center"),
