@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -260,6 +260,7 @@ integer          isym,ireslp,ireslq,ipol,isqrt
 integer          inc,isweep,niterf,iccocg,iel,icycle,nswmod
 integer          itenso,iinvpe, iinvpp
 integer          idtva0
+integer          incp, lvar
 integer          nagmax, npstmg
 integer          ibsize, iesize
 integer          insqrt
@@ -279,7 +280,7 @@ double precision, allocatable, dimension(:) :: rhs0
 !===============================================================================
 
 ! Allocate temporary arrays
-allocate(dam(ncelet), xam(nfac,2))
+allocate(dam(ncelet))
 allocate(smbini(ncelet))
 if (iswdyp.ge.1) then
   allocate(adxk(ncelet), adxkm1(ncelet), dpvarm1(ncelet))
@@ -290,7 +291,7 @@ endif
 if (ivar.gt.0) then
   call field_get_name(ivarfl(ivar), chaine)
 else
-  chaine = nomvar(ipp)
+  chaine = nomva0
 endif
 cnom= chaine(1:16)
 
@@ -298,6 +299,8 @@ cnom= chaine(1:16)
 isym  = 1
 if (iconvp.gt.0) isym  = 2
 
+allocate(xam(isym,nfac))
+
 ! Matrix block size
 ibsize = 1
 iesize = 1
@@ -361,10 +364,8 @@ endif
 
 call matrix &
 !==========
- ( ncelet , ncel   , nfac   , nfabor ,                            &
-   iconvp , idiffp , ndircp , isym   , nfecra ,                   &
+ ( iconvp , idiffp , ndircp , isym   ,                            &
    thetap , imucpp ,                                              &
-   ifacel , ifabor ,                                              &
    coefbp , cofbfp , rovsdt , flumas , flumab , viscfm , viscbm , &
    xcpp   , dam    , xam    )
 
@@ -417,7 +418,7 @@ if (abs(thetex).gt.epzero) then
   !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp , idftnp ,                            &
+   iwarnp , imucpp , idftnp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetex ,          &
    pvara  , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
    flumas , flumab , viscfs , viscbs , visccs , xcpp   ,          &
@@ -465,7 +466,7 @@ call bilsca &
 !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp , idftnp ,                            &
+   iwarnp , imucpp , idftnp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
    flumas , flumab , viscfs , viscbs , visccs , xcpp   ,          &
@@ -576,7 +577,9 @@ do while (isweep.le.nswmod.and.residu.gt.epsrsp*rnorm.or.isweep.eq.1)
   ! Dynamic relaxation of the system
   if (iswdyp.ge.1) then
 
-    ! Computation of the variable ralaxation coefficient
+    ! Computation of the variable relaxation coefficient
+    incp = 0
+    lvar = 0
 
     !$omp parallel do
     do iel = 1, ncelet
@@ -586,9 +589,9 @@ do while (isweep.le.nswmod.and.residu.gt.epsrsp*rnorm.or.isweep.eq.1)
 
     call bilsca &
     !==========
-   ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
-     ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-     ipp    , iwarnp , imucpp , idftnp ,                            &
+   ( idtvar , lvar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
+     ischcp , isstpp , incp   , imrgra , iccocg ,                   &
+     iwarnp , imucpp , idftnp ,                                     &
      blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
      dpvar  , dpvar  , coefap , coefbp , cofafp , cofbfp ,          &
      flumas , flumab , viscfs , viscbs , visccs , xcpp   ,          &
@@ -714,7 +717,7 @@ do while (isweep.le.nswmod.and.residu.gt.epsrsp*rnorm.or.isweep.eq.1)
   !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp , idftnp ,                            &
+   iwarnp , imucpp , idftnp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
    flumas , flumab , viscfs , viscbs , visccs , xcpp   ,          &
@@ -787,7 +790,7 @@ if (iescap.gt.0) then
   !==========
  ( idtva0 , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp , idftnp ,                            &
+   iwarnp , imucpp , idftnp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
    flumas , flumab , viscfs , viscbs , visccs , xcpp   ,          &
