@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -266,7 +266,7 @@ integer          idtva0
 integer          nagmax, npstmg
 integer          isou , jsou
 integer          ibsize, iesize
-integer          incp, insqrt
+integer          lvar, incp, insqrt
 
 double precision residu, rnorm, ressol, rnorm2
 double precision thetex
@@ -301,7 +301,7 @@ endif
 if (ivar.gt.0) then
   call field_get_name(ivarfl(ivar), chaine)
 else
-  chaine = nomvar(ippu)
+  chaine = nomva0
 endif
 cnom= chaine(1:16)
 
@@ -342,10 +342,8 @@ if (iesize.eq.1) then
 
   call matrxv &
   !==========
-   ( ncelet , ncel   , nfac   , nfabor ,                            &
-     iconvp , idiffp , ndircp , isym   , nfecra ,                   &
+   ( iconvp , idiffp , ndircp , isym   ,                            &
      thetap ,                                                       &
-     ifacel , ifabor ,                                              &
      coefbv , cofbfv , fimp   ,                                     &
      flumas , flumab , viscfm , viscbm ,                            &
      dam    , xam    )
@@ -354,10 +352,8 @@ elseif (iesize.eq.3) then
 
   call matrvv &
   !==========
-   ( ncelet , ncel   , nfac   , nfabor ,                            &
-     iconvp , idiffp , ndircp , isym   , nfecra ,                   &
+   ( iconvp , idiffp , ndircp , isym   ,                            &
      thetap ,                                                       &
-     ifacel , ifabor ,                                              &
      coefbv , cofbfv , fimp   ,                                     &
      flumas , flumab , viscfm , viscbm ,                            &
      dam    , xam    )
@@ -559,7 +555,7 @@ do while (isweep.le.nswmod.and.residu.gt.epsrsp*rnorm.or.isweep.eq.1)
 
     !$omp parallel do private(isou)
     do iel = 1, ncel
-      do isou =1,3
+      do isou = 1, 3
         dpvarm1(isou,iel) = dpvar(isou,iel)
         dpvar(isou,iel) = 0.d0
       enddo
@@ -595,7 +591,9 @@ do while (isweep.le.nswmod.and.residu.gt.epsrsp*rnorm.or.isweep.eq.1)
   ! Dynamic relaxation of the system
   if (iswdyp.ge.1) then
 
-    ! Computation of the variable ralaxation coefficient
+    ! Computation of the variable relaxation coefficient
+    incp = 0
+    lvar = 0
 
     !$omp parallel do private(isou)
     do iel = 1, ncelet
@@ -607,7 +605,7 @@ do while (isweep.le.nswmod.and.residu.gt.epsrsp*rnorm.or.isweep.eq.1)
 
     call bilscv &
     !==========
-   ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
+   ( idtvar , lvar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
      ischcp , isstpp , incp   , imrgra , ivisep ,                   &
      ippu   , iwarnp , idftnp ,                                     &
      blencp , epsrgp , climgp , relaxp , thetap ,                   &
