@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -774,6 +774,19 @@ cs_file_listdir(const char *path);
 cs_file_off_t
 cs_file_size(const char  *path);
 
+/*----------------------------------------------------------------------------
+ * Remove a file if it exists and is a regular file.
+ *
+ * parameters
+ *   path <-- file path.
+ *
+ * returns:
+ *   0 in case of success or if file does not exist, 0 otherwise.
+ *----------------------------------------------------------------------------*/
+
+int
+cs_file_remove(const char  *path);
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
