@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -65,6 +65,7 @@ BEGIN_C_DECLS
 /* Number of defined halos */
 
 static int _cs_glob_n_halos = 0;
+static int _cs_glob_halo_max_stride = 3;
 
 #if defined(HAVE_MPI)
 
@@ -587,7 +588,8 @@ cs_halo_update_buffers(const cs_halo_t *halo)
 
     size_t send_buffer_size =   CS_MAX(halo->n_send_elts[CS_HALO_EXTENDED],
                                        halo->n_elts[CS_HALO_EXTENDED])
-                              * CS_MAX(sizeof(cs_lnum_t), sizeof(cs_real_t)) * 3;
+                              * CS_MAX(sizeof(cs_lnum_t),
+                                       sizeof(cs_real_t)) * _cs_glob_halo_max_stride;
 
     int n_requests = halo->n_c_domains*2;
 
@@ -1149,23 +1151,11 @@ cs_halo_sync_var_strided(const cs_halo_t  *halo,
   cs_lnum_t end_shift = 0;
   int local_rank_id = (cs_glob_n_ranks == 1) ? 0 : -1;
 
-#if defined(HAVE_MPI)
-
-  if (cs_glob_n_ranks > 1) {
-    const size_t send_buffer_size =   CS_MAX(halo->n_send_elts[CS_HALO_EXTENDED],
-                                             halo->n_elts[CS_HALO_EXTENDED])
-                                    * sizeof(cs_real_t) * stride;
-
-    if (send_buffer_size > _cs_glob_halo_send_buffer_size) {
-      _cs_glob_halo_send_buffer_size =  send_buffer_size;
-      BFT_REALLOC(_cs_glob_halo_send_buffer,
-                  _cs_glob_halo_send_buffer_size,
-                  char);
-    }
+  if (stride > _cs_glob_halo_max_stride) {
+    _cs_glob_halo_max_stride = stride;
+    cs_halo_update_buffers(halo);
   }
 
-#endif /* defined(HAVE_MPI) */
-
   if (sync_mode == CS_HALO_STANDARD)
     end_shift = 1;
 
