@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -447,6 +447,31 @@ _test_halo_compatibility(const cs_halo_t  *halo)
  * Public function definitions for Fortran API
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ * Rotate vector values for periodic cells on extended halos.
+ *
+ * Fortran API:
+ *
+ * subroutine pervec
+ * *****************
+ *
+ * double precision var(3,ncelet) : <-> : interleaved vector
+ *----------------------------------------------------------------------------*/
+
+void
+CS_PROCF (pervec, PERVEC) (cs_real_t  var[])
+{
+  const cs_halo_t *halo = cs_glob_mesh->halo;
+
+  if (halo == NULL)
+    return;
+
+  cs_halo_perio_sync_var_vect(halo,
+                              CS_HALO_EXTENDED,
+                              var,
+                              0);
+}
+
 /*----------------------------------------------------------------------------
  * Rotate vector values for periodic cells on extended halos.
  *
