@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -1447,9 +1447,10 @@ _renum_face_multipass_redistribute(int                         n_i_threads,
          current thread. */
 
       int f_t_id1 = t_id1 + g_id*n_i_threads;
+      cs_lnum_t fl_id_max = CS_MIN(t_face_last[t_id1], faces_list_size - 1);
 
       for (fl_id_end = t_face_last[t_id];
-            (   fl_id_end <= t_face_last[t_id1]
+            (   fl_id_end <= fl_id_max
              && l_face_cells[faces_list[fl_id_end]][0] <= t1_c_end
              && n_t_faces_move < 0);
            fl_id_end++) {
@@ -1457,6 +1458,8 @@ _renum_face_multipass_redistribute(int                         n_i_threads,
           n_t_faces_move += 1;
       }
 
+      fl_id_end = CS_MIN(fl_id_end, faces_list_size - 1);
+
       while (   fl_id_end >= t_face_last[t_id]
              && fl_id_end > 0
              && (   l_face_cells[faces_list[fl_id_end]][0]
@@ -2154,7 +2157,7 @@ _estimate_imbalance(const cs_numbering_t  *face_numbering)
       n_t_faces_mean = (double)n_t_faces_sum / n_threads;
 
       imbalance = (n_t_faces_max / n_t_faces_mean) - 1.0;
-      t_imbalance_tot = imbalance*n_t_faces_sum;
+      t_imbalance_tot += imbalance*n_t_faces_sum;
 
     }
 
