@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -975,10 +975,7 @@ void CS_PROCF (tplnbr, TPLNBR)
  cs_int_t  *ntpl
 )
 {
-  size_t i;
-  cs_time_plot_format_t fmt;
-
-  size_t i_max = 0;
+  int fmt;
 
   *ntpl = 0;
 
