@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -61,6 +61,7 @@ use paramx
 use pointe
 use numvar
 use optcal
+use dimens, only: nvar
 use cstphy
 use cstnum
 use entsor
@@ -82,7 +83,7 @@ integer          nptdis , numcpl , nvcpto
 
 integer          locpts(nptdis)
 
-double precision rtp(ncelet,*)
+double precision rtp(ncelet,nflown:nvar)
 double precision coopts(3,nptdis), djppts(3,nptdis)
 double precision pndpts(nptdis), dofpts(3,nptdis)
 double precision rvdis(nptdis,nvcpto)
@@ -91,12 +92,10 @@ double precision rvdis(nptdis,nvcpto)
 
 integer          ipt    , iel    , isou
 integer          ivar   , iscal
-integer          inc    , iccocg , iprev  , nswrgp
-integer          iwarnp , imligp
+integer          inc    , iccocg , iprev
 integer          ipos
 integer          itytu0
 
-double precision epsrgp , climgp , extrap
 double precision xjjp   , yjjp   , zjjp
 double precision d2s3
 double precision xjpf,yjpf,zjpf,jpf
@@ -108,10 +107,15 @@ double precision, allocatable, dimension(:,:,:) :: gradv
 double precision, allocatable, dimension(:,:) :: grad
 double precision, allocatable, dimension(:) :: trav1, trav2, trav3, trav4
 double precision, allocatable, dimension(:) :: trav5, trav6, trav7, trav8
+
 double precision, dimension(:), pointer :: crom
+double precision, dimension(:,:), pointer :: vel
 
 !===============================================================================
 
+! Map field arrays
+call field_get_val_v(ivarfl(iu), vel)
+
 !=========================================================================
 ! 1.  INITIALISATIONS
 !=========================================================================
@@ -197,16 +201,9 @@ ipos = 1
 ! 1.  Prepare for pressure
 !=========================================================================
 
-nswrgp = nswrgr(ipr)
-imligp = imligr(ipr)
-iwarnp = iwarni(ipr)
-epsrgp = epsrgr(ipr)
-climgp = climgr(ipr)
-extrap = extrag(ipr)
-
 call field_gradient_scalar(ivarfl(ipr), iprev, imrgra, inc,  &
-                           iccocg, nswrgp, iwarnp, imligp,   &
-                           epsrgp, extrap, climgp, grad)
+                           iccocg,                           &
+                           grad)
 
 ! For a specific face to face coupling, geometric assumptions are made
 
@@ -281,22 +278,13 @@ endif
 ! 2.  Prepare for velocity
 !=========================================================================
 
-nswrgp = nswrgr(iu)
-imligp = imligr(iu)
-iwarnp = iwarni(iu)
-epsrgp = epsrgr(iu)
-climgp = climgr(iu)
-
 call field_gradient_vector(ivarfl(iu), iprev, imrgra, inc,  &
-                           nswrgp, iwarnp, imligp,          &
-                           epsrgp, climgp, gradv)
+                           gradv)
 
 do isou = 1, 3
 
   ipos = ipos + 1
 
-  ivar = iu + isou - 1
-
   ! For a specific face to face coupling, geometric assumptions are made
 
   if (ifaccp.eq.1) then
@@ -317,7 +305,7 @@ do isou = 1, 3
       !        yjjp = djppts(2,ipt)
       !        zjjp = djppts(3,ipt)
 
-      !        rvdis(ipt,ipos) = rtp(iel,ivar)
+      !        rvdis(ipt,ipos) = vel(isou,iel)
 
       ! -- SOLU
 
@@ -325,7 +313,7 @@ do isou = 1, 3
       !        yjf = coopts(2,ipt) - xyzcen(2,iel)
       !        zjf = coopts(3,ipt) - xyzcen(3,iel)
 
-      !        rvdis(ipt,ipos) = rtp(iel,ivar) &
+      !        rvdis(ipt,ipos) = vel(isou,iel) &
       !          + xjf*gradv(1,isou,iel) + yjf*gradv(2,isou,iel) &
       !          + zjf*gradv(3,isou,iel)
 
@@ -335,7 +323,7 @@ do isou = 1, 3
       yjjp = djppts(2,ipt)
       zjjp = djppts(3,ipt)
 
-      rvdis(ipt,ipos) =   rtp(iel,ivar)            &
+      rvdis(ipt,ipos) =   vel(isou,iel)            &
                         + xjjp*gradv(1,isou,iel)   &
                         + yjjp*gradv(2,isou,iel)   &
                         + zjjp*gradv(3,isou,iel)
@@ -372,7 +360,7 @@ do isou = 1, 3
       yjjp = dofpts(2,ipt) + djppts(2,ipt)
       zjjp = dofpts(3,ipt) + djppts(3,ipt)
 
-      rvdis(ipt,ipos) =   rtp(iel,ivar)            &
+      rvdis(ipt,ipos) =   vel(isou,iel)            &
                         + xjjp*gradv(1,isou,iel)   &
                         + yjjp*gradv(2,isou,iel)   &
                         + zjjp*gradv(3,isou,iel)
@@ -400,16 +388,9 @@ if (itytur.eq.2) then
 !          3.1.1. INTERPOLATION EN J'
 !=======================================================================
 
-  nswrgp = nswrgr(ik)
-  imligp = imligr(ik)
-  iwarnp = iwarni(ik)
-  epsrgp = epsrgr(ik)
-  climgp = climgr(ik)
-  extrap = extrag(ik)
-
   call field_gradient_scalar(ivarfl(ik), iprev, imrgra, inc,      &
-                             iccocg, nswrgp, iwarnp, imligp,      &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                              &
+                             grad)
 
   ! For a specific face to face coupling, geometric assumptions are made
 
@@ -449,16 +430,9 @@ if (itytur.eq.2) then
 
   !         Prparation des donnes: interpolation de epsilon en J'
 
-  nswrgp = nswrgr(iep)
-  imligp = imligr(iep)
-  iwarnp = iwarni(iep)
-  epsrgp = epsrgr(iep)
-  climgp = climgr(iep)
-  extrap = extrag(iep)
-
   call field_gradient_scalar(ivarfl(iep), iprev, imrgra, inc,     &
-                             iccocg, nswrgp, iwarnp, imligp,      &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                              &
+                             grad)
 
   ! For a specific face to face coupling, geometric assumptions are made
 
@@ -543,8 +517,6 @@ if (itytur.eq.2) then
 
     do isou = 1, 3
 
-      ivar = iu + isou - 1
-
       ! Velocity gradient has already been computed above
 
       do ipt = 1, nptdis
@@ -651,16 +623,9 @@ elseif (itytur.eq.3) then
     if (isou.eq.5) ivar = ir13
     if (isou.eq.6) ivar = ir23
 
-    nswrgp = nswrgr(ivar)
-    imligp = imligr(ivar)
-    iwarnp = iwarni(ivar)
-    epsrgp = epsrgr(ivar)
-    climgp = climgr(ivar)
-    extrap = extrag(ivar)
-
     call field_gradient_scalar(ivarfl(ivar), iprev, imrgra, inc,    &
-                               iccocg, nswrgp, iwarnp, imligp,      &
-                               epsrgp, extrap, climgp, grad)
+                               iccocg,                              &
+                               grad)
 
     ! For a specific face to face coupling, geometric assumptions are made
 
@@ -736,16 +701,9 @@ elseif (itytur.eq.3) then
 
   ! Prparation des donnes: interpolation de epsilon en J'
 
-  nswrgp = nswrgr(iep)
-  imligp = imligr(iep)
-  iwarnp = iwarni(iep)
-  epsrgp = epsrgr(iep)
-  climgp = climgr(iep)
-  extrap = extrag(iep)
-
   call field_gradient_scalar(ivarfl(iep), iprev, imrgra, inc,     &
-                             iccocg, nswrgp, iwarnp, imligp,      &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                              &
+                             grad)
 
   ! For a specific face to face coupling, geometric assumptions are made
 
@@ -897,16 +855,9 @@ elseif (iturb.eq.50) then
 
   !         Prparation des donnes: interpolation de k en J'
 
-  nswrgp = nswrgr(ik)
-  imligp = imligr(ik)
-  iwarnp = iwarni(ik)
-  epsrgp = epsrgr(ik)
-  climgp = climgr(ik)
-  extrap = extrag(ik)
-
   call field_gradient_scalar(ivarfl(ik), iprev, imrgra, inc,      &
-                             iccocg, nswrgp, iwarnp, imligp,      &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                              &
+                             grad)
 
   ! For a specific face to face coupling, geometric assumptions are made
 
@@ -946,16 +897,9 @@ elseif (iturb.eq.50) then
 
   ! Prparation des donnes: interpolation de epsilon en J'
 
-  nswrgp = nswrgr(iep)
-  imligp = imligr(iep)
-  iwarnp = iwarni(iep)
-  epsrgp = epsrgr(iep)
-  climgp = climgr(iep)
-  extrap = extrag(iep)
-
   call field_gradient_scalar(ivarfl(iep), iprev, imrgra, inc,  &
-                             iccocg, nswrgp, iwarnp, imligp,   &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                           &
+                             grad)
 
   ! For a specific face to face coupling, geometric assumptions are made
 
@@ -995,16 +939,9 @@ elseif (iturb.eq.50) then
 
   !         Prparation des donnes: interpolation de Phi en J'
 
-  nswrgp = nswrgr(iphi)
-  imligp = imligr(iphi)
-  iwarnp = iwarni(iphi)
-  epsrgp = epsrgr(iphi)
-  climgp = climgr(iphi)
-  extrap = extrag(iphi)
-
   call field_gradient_scalar(ivarfl(iphi), iprev, imrgra, inc,  &
-                             iccocg, nswrgp, iwarnp, imligp,    &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                            &
+                             grad)
 
   do ipt = 1, nptdis
 
@@ -1021,16 +958,9 @@ elseif (iturb.eq.50) then
 
   !         Prparation des donnes: interpolation de F-barre en J'
 
-  nswrgp = nswrgr(ifb)
-  imligp = imligr(ifb)
-  iwarnp = iwarni(ifb)
-  epsrgp = epsrgr(ifb)
-  climgp = climgr(ifb)
-  extrap = extrag(ifb)
-
   call field_gradient_scalar(ivarfl(ifb), iprev, imrgra, inc,  &
-                             iccocg, nswrgp, iwarnp, imligp,   &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                           &
+                             grad)
 
   ! For a specific face to face coupling, geometric assumptions are made
 
@@ -1127,16 +1057,9 @@ elseif (iturb.eq.60) then
 
   !         Prparation des donnes: interpolation de k en J'
 
-  nswrgp = nswrgr(ik)
-  imligp = imligr(ik)
-  iwarnp = iwarni(ik)
-  epsrgp = epsrgr(ik)
-  climgp = climgr(ik)
-  extrap = extrag(ik)
-
   call field_gradient_scalar(ivarfl(ik), iprev, imrgra, inc,  &
-                             iccocg, nswrgp, iwarnp, imligp,  &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                          &
+                             grad)
 
   ! For a specific face to face coupling, geometric assumptions are made
 
@@ -1176,16 +1099,9 @@ elseif (iturb.eq.60) then
 
   !         Prparation des donnes: interpolation de omega en J'
 
-  nswrgp = nswrgr(iomg)
-  imligp = imligr(iomg)
-  iwarnp = iwarni(iomg)
-  epsrgp = epsrgr(iomg)
-  climgp = climgr(iomg)
-  extrap = extrag(iomg)
-
   call field_gradient_scalar(ivarfl(iomg), iprev, imrgra, inc,  &
-                             iccocg, nswrgp, iwarnp, imligp,    &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                            &
+                             grad)
 
   ! For a specific face to face coupling, geometric assumptions are made
 
@@ -1290,8 +1206,6 @@ elseif (iturb.eq.60) then
 
     do isou = 1, 3
 
-      ivar = iu + isou - 1
-
       ! Velocity gradient has already been computed above
 
       do ipt = 1, nptdis
@@ -1372,16 +1286,9 @@ if (nscal.gt.0) then
 
 ! --- Calcul du gradient du scalaire pour interpolation
 
-    nswrgp = nswrgr(ivar)
-    imligp = imligr(ivar)
-    iwarnp = iwarni(ivar)
-    epsrgp = epsrgr(ivar)
-    climgp = climgr(ivar)
-    extrap = extrag(ivar)
-
     call field_gradient_scalar(ivarfl(ivar), iprev, imrgra, inc,  &
-                               iccocg, nswrgp, iwarnp, imligp,    &
-                               epsrgp, extrap, climgp, grad)
+                               iccocg,                            &
+                               grad)
 
     ! For a specific face to face coupling, geometric assumptions are made
 
