@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -89,6 +89,7 @@ use ppincl
 use mesh
 use field
 use cs_c_bindings
+use turbomachinery
 
 !===============================================================================
 
@@ -103,7 +104,7 @@ integer          iwarnp
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 
@@ -586,7 +587,7 @@ if (idtvar.ge.0) then
       call log_iteration_clipping_field(flid, icfmin, icfmax, dt, dt)
 
       ttcabs = ttcabs + (dtloc - dt(1))
-      if (imobil.eq.1) then
+      if (imobil.eq.1 .or. iturbo.eq.2) then
         ttcmob = ttcmob + (dtloc - dt(1))
       endif
 
