@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -66,7 +66,6 @@ subroutine ecrava &
 !===============================================================================
 
 use paramx
-use dimens, only: ndimfb
 use numvar
 use cstphy
 use entsor
@@ -102,7 +101,7 @@ integer          nvar   , nscal
 
 double precision xyzcen(ndim,ncelet)
 double precision cdgfbo(ndim,nfabor)
-double precision dt(ncelet), rtp(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision frcxt(3,ncelet), prhyd(ncelet)
 
@@ -116,33 +115,35 @@ character        rubriq*64,car2*2,car4*4,car54*54
 character        cindfp*2,cindfs*4,cindff*4,cindfm*4
 character        cindfc*2,cindfl*4
 character        cphase*2 , cscal(nscamx)*4
-character        cflu  (nvarmx)*4 , cmom (nbmomx)*4
+character        cflu  (nvarmx)*4
 character        nomflu(nvarmx)*18, nomrtp(nvarmx)*20
 character        nomcli(nvarmx)*18
 character        cstruc(nstrmx)*2, cindst*2
 character        ficsui*32
 logical          lprev
 integer          nphas
-integer          ivar  , iscal , imom, f_id
+integer          ivar  , iscal , f_id
 integer          idecal, iclapc, icha  , icla
-integer          ii    , ivers , idtm  , idtcm
+integer          ii    , ivers
 integer          iptsna, iptsta, iptsca
 integer          ierror, irtyp , itysup, nbval
-integer          nbctm , ipcefj, ipcla1, ipcla2, ipcla3
+integer          ipcefj, ipcla1, ipcla2, ipcla3
 integer          nfmtsc, nfmtfl, nfmtmo, nfmtch, nfmtcl
 integer          nfmtst
 integer          nbflu , ilecec, iecr
-integer          icdtvu(nbmom2)
 integer          ngbstr(2)
-integer          ifac, iel, istr
+integer          ifac, iel, istr, isou
 integer          impava, impavx, nfld, iflmas, iflmab
 double precision tmpstr(27)
 
 integer, allocatable, dimension(:) :: mflnum
 double precision, allocatable, dimension(:) :: w1
+double precision, allocatable, dimension(:,:) :: l_velocity
 
 double precision, dimension(:,:), pointer :: xut
 double precision, dimension(:), pointer :: sval
+double precision, dimension(:,:), pointer :: vel
+double precision, dimension(:,:), pointer :: val_vp
 
 !===============================================================================
 !     A noter :
@@ -212,14 +213,6 @@ do ivar = min(nvar  ,nfmtfl)+1,nvar
   cflu(ivar) = cindff
 enddo
 
-!     Codage en chaine de caracteres du numero du moment
-do imom = 1, min(nbmomt,nfmtmo)
-  write(cmom(imom),'(I4.4)') imom
-enddo
-do imom = min(nbmomt,nfmtmo)+1,nbmomt
-  cmom(imom) = cindfm
-enddo
-
 !     Verifications pour les formats et les numeros
 !       de scalaire en chaine.
 !     Avertissement (certaines infos passent a la trappe)
@@ -343,6 +336,13 @@ nbval  = 1
 irtyp  = 1
 call ecrsui(impava,rubriq,len(rubriq),itysup,nbval,irtyp,iale)
 
+!  ---> Cavitation
+rubriq = 'cavitation'
+itysup = 0
+nbval  = 1
+irtyp  = 1
+call ecrsui(impava,rubriq,len(rubriq),itysup,nbval,irtyp,icavit)
+
 rubriq = 'instant_mobile_precedent'
 itysup = 0
 nbval  = 1
@@ -409,13 +409,36 @@ if (iale.eq.1) then
   nomrtp(ivma)='vit_maillage_v_ce'
   nomrtp(iwma)='vit_maillage_w_ce'
 endif
+if (icavit.ge.0) then
+  nomrtp(ivoidf)='taux_vide_ce'
+endif
 
 !     Dans le cas ou il y a plusieurs phases,
 !       on ne veut ecrire la pression qu'une seule fois
 !       mais ca tombe bien, car on ne la verra qu'une seule fois
 !       dans la liste des variables
 
-do ivar = 1, nvar
+! TODO: improve ecrsui for field structure
+call field_get_val_v(ivarfl(iu), vel)
+allocate(l_velocity(ncelet, 3))
+do iel = 1, ncelet
+  do isou = 1, 3
+    l_velocity(iel,isou) = vel(isou,iel)
+  enddo
+enddo
+
+do ivar = 1, 3
+
+  itysup = 1
+  nbval  = 1
+  irtyp  = 2
+  rubriq = nomrtp(ivar)
+  call ecrsui(impava,rubriq,len(rubriq),itysup,nbval,irtyp,l_velocity(1,ivar))
+
+enddo
+deallocate(l_velocity)
+
+do ivar = nflown, nvar
 
   itysup = 1
   nbval  = 1
@@ -425,6 +448,7 @@ do ivar = 1, nvar
 
 enddo
 
+
 do iscal = 1, nscal
   if (ityturt(iscal).eq.2 .or. ityturt(iscal).eq.3) then
     !  ---> Turbulent flux model
@@ -545,6 +569,13 @@ if (iecaux.eq.1) then
   irtyp  = 1
   call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,iale)
 
+  !  ---> Cavitation
+  rubriq = 'cavitation'
+  itysup = 0
+  nbval  = 1
+  irtyp  = 1
+  call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,icavit)
+
 
 #if defined(_CS_LANG_FR)
   car54 =' Fin de l''ecriture des dimensions et des options     '
@@ -589,7 +620,8 @@ if (iecaux.eq.1) then
   endif
 
   !     Masse volumique si elle est variable uniquement
-  if (irovar.eq.1) then
+  !     La masse volumique est egalement ecrite pour le modele de cavitation
+  if (irovar.eq.1.or.icavit.ge.0) then
     !          Masse volumique - cellules
     rubriq = 'rho_ce_phase'//cphase
     itysup = 1
@@ -598,6 +630,16 @@ if (iecaux.eq.1) then
     call field_get_val_s(icrom, sval)
     call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,sval)
 
+    ! Masse volumique du pdt precedent - cellules (uniquement pour cavitation)
+    if (icavit.ge.0) then
+      rubriq = 'rho_old_ce_phase'//cphase
+      itysup = 1
+      nbval  = 1
+      irtyp  = 2
+      call field_get_val_prev_s(icrom, sval)
+      call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,sval)
+    endif
+
     !          Masse volumique - faces de bord
     rubriq = 'rho_fb_phase'//cphase
     itysup = 3
@@ -607,7 +649,8 @@ if (iecaux.eq.1) then
     call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,sval)
   endif
 
-  !     On n'ecrit les proprietes physiques que si on les extrapole.
+  !     On n'ecrit les proprietes physiques que si on les extrapole ou
+  !     pour le modele de cavitation
   !       On pourrait les ecrire a tous les coups en prevision d'une
   !       suite avec extrapolation, mais
   !          - c'est rare
@@ -617,9 +660,9 @@ if (iecaux.eq.1) then
   !       Une exception : on ecrit egalement Cp en effet joule pour
   !         pouvoir calculer la temperature H/Cp en debut de calcul
 
-  if (iviext.gt.0) then
-    !         Viscosite moleculaire - cellules (si variable)
-    if (ivivar.eq.1) then
+  if (iviext.gt.0.or.icavit.ge.0) then
+    !         Viscosite moleculaire - cellules (si variable ou cavitation)
+    if (ivivar.eq.1.or.icavit.ge.0) then
       rubriq = 'viscl_ce_phase'//cphase
       itysup = 1
       nbval  = 1
@@ -628,13 +671,15 @@ if (iecaux.eq.1) then
                   propce(1,ipproc(iviscl)))
     endif
 
-    !         Viscosite turbulente ou de sous-maille - cellules
-    rubriq = 'visct_ce_phase'//cphase
-    itysup = 1
-    nbval  = 1
-    irtyp  = 2
-    call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,   &
-                propce(1,ipproc(ivisct)))
+    if (iviext.gt.0) then
+      !         Viscosite turbulente ou de sous-maille - cellules
+      rubriq = 'visct_ce_phase'//cphase
+      itysup = 1
+      nbval  = 1
+      irtyp  = 2
+      call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,   &
+                  propce(1,ipproc(ivisct)))
+    endif
   endif
 
   if ((icpext.gt.0.and.icp.gt.0).or.              &
@@ -711,8 +756,8 @@ if (iecaux.eq.1) then
 
   nbflu = 0
 
-  do f_id = 1, nfld
-    mflnum(f_id) = 0
+  do ii = 1, nfld
+    mflnum(ii) = 0
   enddo
 
   nomflu(ipr)='fm_p_phase'//cphase
@@ -760,6 +805,9 @@ if (iecaux.eq.1) then
     nomflu(ivma)='fm_vit_maill_v'
     nomflu(iwma)='fm_vit_maill_w'
   endif
+  if (icavit.ge.0) then
+    nomflu(ivoidf)='fm_taux_vide'
+  endif
 
   ! For variables
 
@@ -817,8 +865,8 @@ if (iecaux.eq.1) then
 
   nbflu = 0
 
-  do f_id = 1, nfld
-    mflnum(f_id) = 0
+  do ii = 1, nfld
+    mflnum(ii) = 0
   enddo
 
   nomflu(ipr)='fm_a_p_phase'//cphase
@@ -864,6 +912,9 @@ if (iecaux.eq.1) then
     nomflu(ivma)='fm_a_vit_maill_v'
     nomflu(iwma)='fm_a_vit_maill_w'
   endif
+  if (icavit.ge.0) then
+    nomflu(ivoidf)='fm_a_taux_vide'
+  endif
 
   do ivar = 1, nvar
 
@@ -975,6 +1026,9 @@ if (iecaux.eq.1) then
     nomcli(ivma)='_vit_maillage_v'
     nomcli(iwma)='_vit_maillage_w'
   endif
+  if (icavit.ge.0) then
+    nomcli(ivoidf)='_taux_vide'
+  endif
 
   call restart_write_bc_coeffs(impavx)
 
@@ -994,12 +1048,29 @@ if (iecaux.eq.1) then
 #endif
   write(nfecra,1110)car54
 
+  ! Backward differential scheme in time
+  if (ibdtso.gt.1) then
+
+    ! Warning: must be adapted if ivar.ne.iu
+    !          must be adapted if ibdtso.gt.2
+    ivar = iu
+    f_id = ivarfl(ivar)
+    call field_get_val_prev_v(f_id, val_vp)
+    rubriq = 'velocity_prev'
+    itysup = 1 ! cells location
+    nbval = 3 ! interleaved velocity
+    irtyp  = 2 ! double precision
+    call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,   &
+                val_vp)
+
+  endif
+
 ! ---> Termes sources
 !      Lorsqu'ils sont extrapoles (pour les versions elec, voir plus bas)
 
   iecr = 0
 
-! ---> Termes sources Navier-Stokes
+! ---> Termes sources Navier-Stokes (plus taux de vide si cavitation)
 
   !     Si les termes sont a l'ordre 2
   if (isno2t.gt.0) then
@@ -1023,6 +1094,12 @@ if (iecaux.eq.1) then
     call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,   &
                 propce(1,iptsna+2))
 
+    if (icavit.ge.0) then
+      rubriq = 'tsource_vf_ce_phase'//cphase
+      call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,   &
+                propce(1,iptsna+3))
+    endif
+
   endif
 
 ! ---> Termes sources turbulence
@@ -1158,112 +1235,7 @@ if (iecaux.eq.1) then
 
 ! ---> Moyennes (cumuls)
 
-!  ---> Nombre de moyennes
-  rubriq = 'nombre_moyennes_temps'
-  itysup = 0
-  nbval  = 1
-  irtyp  = 1
-  call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,nbmomt)
-
-!     Cumuls des moyennes
-  do imom = 1, nbmomt
-    itysup = 1
-    nbval  = 1
-    irtyp  = 2
-    rubriq = 'cumul_ce_moment'//cmom(imom)
-    call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,     &
-                propce(1,ipproc(icmome(imom))))
-  enddo
-
-!     Cumuls des durees
-
-!     On determine un numero unique de duree, local au fichier suite.
-!       les durees variable ou non sont considerees sans distinction
-!     Le tableau ICDTVU(2*NBMOMX) renvoie aux cumuls temporels variables
-!       en espace pour les indices 1->NBMOMX et aux cumuls temporels
-!       uniformes pour les indices NBMOMX+1->2*NBMOMX
-
-!     Initialisation des elements de travail
-  nbctm = 0
-  do ii = 1, nbmom2
-    icdtvu(ii) = 0
-  enddo
-
-
-  do imom = 1, nbmomt
-    idtm = idtmom(imom)
-!        Si cumul variable en espace
-    if (idtm.gt.0) then
-!          Si cumul pas encore vu
-      if (icdtvu(idtm).eq.0) then
-!            C'est un nouveau, le NBCTM ieme
-        nbctm = nbctm+1
-!            On le marque
-        icdtvu(idtm) = nbctm
-!            On ecrit ses valeurs
-        if (nbctm.le.nfmtmo) then
-          write(car4,'(I4.4)') nbctm
-        else
-          car4 = cindfm
-        endif
-        idtcm  = ipproc(icdtmo(idtm))
-        itysup = 1
-        nbval  = 1
-        irtyp  = 2
-        rubriq = 'cumul_temps_ce_'//car4
-        call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp, &
-                    propce(1,idtcm))
-      endif
-!          Cumul vu ou pas, on ecrit son numero, >0 pour dire qu'il est
-!            variable en espace
-      rubriq = 'numero_cumul_temps_moment'//cmom(imom)
-      itysup = 0
-      nbval  = 1
-      irtyp  = 1
-      call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,   &
-                  icdtvu(idtm))
-
-!        Sinon, si cumul uniforme en espace
-    elseif (idtm.lt.0) then
-!          Si cumul pas encore vu
-      if (icdtvu(nbmomx-idtm).eq.0) then
-!            C'est un nouveau, le NBCTM ieme
-        nbctm = nbctm+1
-!            On le marque
-        icdtvu(nbmomx-idtm) = -nbctm
-!            On ecrit ses valeurs
-        if (nbctm.le.nfmtmo) then
-          write(car4,'(I4.4)') nbctm
-        else
-          car4 = cindfm
-        endif
-        idtcm  = -idtm
-        itysup = 0
-        nbval  = 1
-        irtyp  = 2
-        rubriq = 'cumul_temps_'//car4
-        call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp, &
-                    dtcmom(idtcm))
-      endif
-!          Cumul vu ou pas, on ecrit son numero, <0 pour dire qu'il est
-!            uniforme en espace
-      rubriq = 'numero_cumul_temps_moment'//cmom(imom)
-      itysup = 0
-      nbval  = 1
-      irtyp  = 1
-      call ecrsui(impavx,rubriq,len(rubriq),itysup,nbval,irtyp,   &
-                  icdtvu(nbmomx-idtm))
-    endif
-  enddo
-
-  if (nbmomt.gt.0) then
-#if defined(_CS_LANG_FR)
-    car54=' Fin de l''ecriture des moyennes temporelles          '
-#else
-    car54=' End writing the time averages                        '
-#endif
-    write(nfecra,1110)car54
-  endif
+  call time_moment_restart_write(impavx)
 
 ! ---> Distance a la paroi
 !      On pourra ecrire ici la distance a la paroi
