@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -75,6 +75,8 @@ use ppincl
 use ppcpfu
 use radiat
 use cs_coal_incl
+use cs_c_bindings
+use field
 
 !===============================================================================
 
@@ -84,7 +86,7 @@ implicit none
 
 ! Local variables
 
-integer          ii, nmodpp
+integer          n_fields, nmodpp
 integer          nscmax, nesmax, nscusi
 integer          ieepre, ieeder, ieecor, ieetot, iihmpu
 integer          ialgce
@@ -93,6 +95,10 @@ double precision relaxp, extrap
 
 !===============================================================================
 
+! Check for restart and read matching time steps
+
+call parameters_read_restart_info
+
 !===============================================================================
 ! 0. INITIALISATION DE L'INFORMATION "FICHIER XML (IHM) REQUIS & EXISTE"
 !===============================================================================
@@ -142,7 +148,22 @@ endif
 !     ==========================
 
 iihmpu = iihmpr
-call usipph(iihmpu , nfecra , iturb , irccor , itherm, icp)
+call usipph(iihmpu , nfecra , iturb , irccor , idirsm , itherm, icp, icavit)
+
+! --- ALE parameters
+
+!   - Code_Saturne GUI
+!     ================
+
+if (iihmpr.eq.1) then
+  call uialin (iale, nalinf, nalimx, epalim, iortvm)
+endif
+
+!   - User sub-routines
+!     =================
+
+call usalin
+
 
 !===============================================================================
 ! 2. INITIALISATION DE PARAMETRES DEPENDANT DU NOMBRE DE SCALAIRES
@@ -150,7 +171,6 @@ call usipph(iihmpu , nfecra , iturb , irccor , itherm, icp)
 
 ! --- Nombre de scalaires utilisateurs
 
-
 !   - Interface Code_Saturne
 !     ======================
 
@@ -228,11 +248,9 @@ endif
 call usray1
 !==========
 
-! --- Varpos
-!     Verification et construction de ISCAPP
-!      1ier passage
+!     Define fields for variables, check and build iscapp
 
-call varpos(nmodpp)
+call fldvar(nmodpp)
 !==========
 
 if (ippmod(icompf).ge.0) then
@@ -255,11 +273,11 @@ endif
 
 if (iihmpr.eq.1) then
 
-  call  csisca(iscavr, itherm, iscapp)
-  !===========
+  call csisca(iscavr, itherm)
+  !==========
 
-  call  csivis(iscavr, ivisls, iscalt, itherm, itempk)
-  !===========
+  call csivis(iscavr, ivisls, iscalt, itherm, itempk)
+  !==========
 
 endif
 
@@ -336,33 +354,20 @@ call usipgl                                                       &
    iihmpu , nfecra ,                                              &
    idtvar , ipucou , idilat , iphydr , ialgce , iescal )
 
-if (ialgce.ne.-999) call algcen(ialgce)
-
-! --- Parametres de la methode ALE
-
-!   - Interface Code_Saturne
-!     ======================
-
-if (iihmpr.eq.1) then
-
-  call uialin (iale, nalinf, nalimx, epalim, iortvm)
-  !==========
+! If time step is local or variable, pass information to C layer, as it
+! may ne needed for some field (or moment) definitions.
+if (idtvar.ne.0) then
+  call time_step_define_variable(1)
+endif
+if (idtvar.eq.2.or.idtvar.eq.-1) then
+  call time_step_define_local(1)
 endif
 
-!   - Sous-programme utilisateur
-!     ==========================
+if (ialgce.ne.-999) call algcen(ialgce)
 
-call usalin
-!==========
+! Define main properties (pointers, checks, ipp)
 
-! --- Varpos
-!     Positionnement de pointeurs
-!     Verifications
-!     Determination de IPR, IU ... ISCA, NVAR
-!     Determination de IPP...
-
-!      2ieme passage
-call varpos(nmodpp)
+call fldprp
 !==========
 
 !===============================================================================
@@ -379,18 +384,6 @@ call varpos(nmodpp)
 
 if (iihmpr.eq.1) then
 
-  call csvnum                                                     &
-  !==========
-            (nvar,                                                &
-             iu, iv, iw, ipr,                                     &
-             iturb, ik, iep,                                      &
-             ir11, ir22, ir33,                                    &
-             ir12, ir13, ir23,                                    &
-             iomg, iphi, ifb, ial,                                &
-             inusa,                                               &
-             iale, iuma, ivma, iwma,                              &
-             isca, iscapp, itherm)
-
 !     Suite de calcul, relecture fichier auxiliaire, champ de vitesse figé
 
   call csisui(ntsuit, ileaux, iccvfg)
@@ -406,7 +399,7 @@ if (iihmpr.eq.1) then
 
   call uinum1                                                     &
   !==========
-        (isca, iscapp, blencv, ischcv, isstpc, ircflu,            &
+        (blencv, ischcv, isstpc, ircflu,                          &
          cdtvar, nitmax, epsilo, iresol, imgr, nswrsm)
 
 !     Options numériques globales
@@ -424,14 +417,14 @@ if (iihmpr.eq.1) then
               irovar, ivivar, icorio,                                 &
               gx, gy, gz, omegax, omegay, omegaz ,                    &
               ro0, viscl0, viscv0, visls0, cp0, t0,                   &
-              p0, xmasmr, itempk)
+              p0, xmasmr, itempk, itherm, itpscl)
 
-  ! Scamin, scamax
-  call cssca2(iscalt, iscavr, scamin, scamax)
+!     Scamin, scamax
+  call cssca2(iscavr)
   !==========
 
   ! Diffusivites
-  call cssca3(itherm, iscalt, iscavr, visls0, t0, p0)
+  call cssca3(itherm, iscalt, iscavr, visls0, t0, p0, cp0)
   !==========
 
 !     Init turb (uref, almax) si necessaire (modele RANS)
@@ -444,17 +437,15 @@ if (iihmpr.eq.1) then
 
   iappel = 0
 
-  call uiprop                                                     &
+  call uiprop (ivisls, ismago, iale, icp, iscavr)
   !==========
-            (irom, iviscl, ivisct, ivisls, icour, ifour,          &
-             ismago, iale, icp, iscalt, iscavr,                   &
-             iprtot, ipppro, ipproc, icmome,                      &
-             ipptx, ippty, ipptz, ippdt,                          &
-             ivisma, idtvar, ipucou, iappel)
 
   call uimoyt (ndgmox, ntdmom, imoold, idfmom)
   !==========
 
+  call uiipsu(iporos)
+  !==========
+
 endif
 
 !   - Sous-programme utilisateur
@@ -483,11 +474,10 @@ endif
 call comcoc(imrgra)
 
 ! --- Varpos
-!      3ieme passage
-call varpos(nmodpp)
+!      1er passage
+call varpos
 !==========
 
-
 !===============================================================================
 ! 5. INITIALISATION DE PARAMETRES UTILISATEUR (entree sorties)
 !===============================================================================
@@ -498,38 +488,21 @@ call varpos(nmodpp)
 !   - Interface Code_Saturne
 !     ======================
 
+call field_get_n_fields(n_fields)
 
 if (iihmpr.eq.1) then
 
-    iappel = 1
+  iappel = 1
 
-    call uiprop                                                   &
-    !==========
-            (irom, iviscl, ivisct, ivisls, icour, ifour,          &
-             ismago, iale, icp, iscalt, iscavr,                   &
-             iprtot, ipppro, ipproc, icmome,                      &
-             ipptx, ippty, ipptz, ippdt,                          &
-             ivisma, idtvar, ipucou, iappel)
-
-  do ii = 1,nvppmx
-    call fcnmva (nomvar(ii), len(nomvar(ii)), ii)
-    !==========
-  enddo
-
-  call csenso                                                     &
+  call uiprop (ivisls, ismago, iale, icp, iscavr)
   !==========
-     ( nvppmx, ncapt,  nthist, frhist, ntlist, iecaux,            &
-       ipstdv, ichrvr, ilisvr, ihisvr, tplfmt, isca, iscapp,      &
+
+  call csenso                                                   &
+  !==========
+     ( nvppmx, ncapt,  nthist, frhist, ntlist, iecaux,          &
+       ipstdv, ihisvr, tplfmt, isca, iscapp,                    &
        ipprtp, xyzcap )
 
-  do ii = 1,nvppmx
-    call cfnmva(nomvar(ii), len(nomvar(ii)), ii)
-    !==========
-  enddo
-
-  call nvamem
-  !==========
-
 endif
 
 !----
