@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -64,6 +64,7 @@ use ppincl
 use mesh
 use field
 use cfpoin, only:ithvar
+use cs_c_bindings
 
 !===============================================================================
 
@@ -73,31 +74,35 @@ implicit none
 
 integer          nvar   , nscal
 
-double precision dt(ncelet), rtp(ncelet,*), propce(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), propce(ncelet,*)
 
 ! Local variables
 
 character*80     chaine
-integer          ivar  , iscal , imom
+integer          ivar  , iscal
 integer          iel
-integer          iccfth
-integer          iclip , ipp  , iok   , ii
-integer          idtcm , ipcmom, iiptot
+integer          iclip , iok   , ii
+integer          iiptot
 integer          ibormo(nbmomx), imodif
-integer          kscmin, kscmax, iflid
+integer          kscmin, kscmax, keyvar, n_fields
+integer          f_id, f_id_prv, c_id, f_dim
+
+logical          interleaved
 
 double precision valmax, valmin, vfmin , vfmax
 double precision vdtmax, vdtmin
 double precision xekmin, xepmin, xomgmn, xphmin, xphmax
 double precision xnumin
-double precision x11min, x22min, x33min, valmom
-double precision vmomax(nbmomx), vmomin(nbmomx)
+double precision x11min, x22min, x33min
 double precision xxp0, xyp0, xzp0
 double precision xalmin, xalmax
 double precision scmaxp, scminp
 
 double precision rvoid(1)
-double precision, allocatable, dimension(:) :: w1, w2, w3, w4
+double precision, allocatable, dimension(:) :: w1, w2
+
+double precision, dimension(:), pointer :: field_s_v
+double precision, dimension(:,:), pointer :: field_v_v
 
 !===============================================================================
 
@@ -105,7 +110,11 @@ double precision, allocatable, dimension(:) :: w1, w2, w3, w4
 ! 1. Initialization
 !===============================================================================
 
-! Key id for scamin and scamax
+call field_get_n_fields(n_fields)
+
+call field_get_key_id("variable_id", keyvar)
+
+! Key ids for clipping
 call field_get_key_id("min_scalar_clipping", kscmin)
 call field_get_key_id("max_scalar_clipping", kscmax)
 
@@ -125,45 +134,39 @@ ithvar = 0
 iusini = 1
 
 if  (ippmod(icompf).ge.0) then
-  allocate(w1(ncelet), w2(ncelet), w3(ncelet),w4(ncelet))
 
   do iel = 1, ncel
     rtp(iel,isca(itempk)) = t0
   enddo
 
-  iccfth = 0
-  imodif = 1
-    call cfther                                                                &
-    !==========
-    ( nvar   ,                                                                 &
-      iccfth , imodif ,                                                        &
-      rtp    ,                                                                 &
-      w1     , w2     , w3    , rvoid  , rvoid )
-    deallocate(w1, w2, w3, w4)
-!     On initialise la diffusivite thermique
-    visls0(ienerg) = visls0(itempk)/cv0
+  call cf_thermo_default_init(ncel, ncelet, rtp)
+  !==========================
 
-    if(ivisls(ienerg).gt.0) then
-      if(ivisls(itempk).gt.0) then
-        if(icv.gt.0) then
-          do iel = 1, ncel
-            propce(iel,ipproc(ivisls(ienerg))) =         &
-                 propce(iel,ipproc(ivisls(itempk)))        &
-                 / propce(iel,ipproc(icv))
-          enddo
-        else
-          do iel = 1, ncel
-            propce(iel,ipproc(ivisls(ienerg))) =         &
-                 propce(iel,ipproc(ivisls(itempk))) / cv0
-          enddo
-        endif
+  ! On initialise la diffusivite thermique
+  visls0(ienerg) = visls0(itempk)/cv0
+
+  if(ivisls(ienerg).gt.0) then
+    if(ivisls(itempk).gt.0) then
+      if(icv.gt.0) then
+        do iel = 1, ncel
+          propce(iel,ipproc(ivisls(ienerg))) =                                &
+                                           propce(iel,ipproc(ivisls(itempk))) &
+                                         / propce(iel,ipproc(icv))
+        enddo
       else
         do iel = 1, ncel
-          propce(iel,ipproc(ivisls(ienerg))) =         &
-               visls0(itempk) / propce(iel,ipproc(icv))
+          propce(iel,ipproc(ivisls(ienerg))) =                                &
+                                           propce(iel,ipproc(ivisls(itempk))) &
+                                         / cv0
         enddo
       endif
+    else
+      do iel = 1, ncel
+        propce(iel,ipproc(ivisls(ienerg))) =  visls0(itempk) &
+                                            / propce(iel,ipproc(icv))
+      enddo
     endif
+  endif
 
 endif
 
@@ -172,10 +175,10 @@ endif
 
 if (iihmpr.eq.1) then
 
-  call uiiniv (ncelet, isuite, isca, iscold,       &
-               ithvar, ipr, iscalt, itempk, ienerg,&
+  call uiiniv (ncelet, isuite,                     &
+               ithvar,                             &
                ro0, cp0, viscl0, uref,             &
-               almax, xyzcen, rtp)
+               almax, xyzcen)
 
 endif
 
@@ -187,7 +190,7 @@ if (ippmod(iphpar).eq.0) then
   call cs_user_initialization &
   !==========================
 ( nvar   , nscal  ,                                                             &
-  dt     , rtp    , propce )
+  dt     )
 
   !     Avec l'interface, il peut y avoir eu initialisation,
   !       meme si usiniv n'est pas utilise.
@@ -210,7 +213,7 @@ else
 
   if  (ippmod(icompf).ge.0) then
 
-    allocate(w1(ncelet), w2(ncelet), w3(ncelet),w4(ncelet))
+    allocate(w1(ncelet), w2(ncelet))
     imodif = 1
 
     call cfther                                                                 &
@@ -218,9 +221,9 @@ else
    ( nvar   ,                                                                   &
      ithvar , imodif ,                                                          &
      rtp    ,                                                                   &
-     w1     , w2     , w3    , rvoid  , rvoid  )
+     w1     , w2     , rvoid )
 
-    deallocate(w1, w2, w3, w4)
+    deallocate(w1, w2)
 
   endif
 
@@ -513,9 +516,9 @@ if(nscal.gt.0.and.(iusini.eq.1.or.isuite.eq.1)) then
     if(iscavr(ii).le.0.or.iscavr(ii).gt.nscal) then
 
       ! Get the min clipping
-      iflid = ivarfl(isca(ii))
-      call field_get_key_double(iflid, kscmin, scminp)
-      call field_get_key_double(iflid, kscmax, scmaxp)
+      f_id = ivarfl(isca(ii))
+      call field_get_key_double(f_id, kscmin, scminp)
+      call field_get_key_double(f_id, kscmax, scmaxp)
 
       if (scminp.le.scmaxp) then
         ivar = isca(ii)
@@ -539,7 +542,7 @@ if(nscal.gt.0.and.(iusini.eq.1.or.isuite.eq.1)) then
           call clpsca(ncelet, ncel, iscal, rvoid, rtp)
           !==========
         else
-          chaine = nomvar(ipprtp(isca(ii)))
+          call field_get_label(ivarfl(isca(ii)), chaine)
           write(nfecra,3040) ii,chaine(1:16),                     &
                              valmin,scminp,valmax,scmaxp
           iok = iok + 1
@@ -556,9 +559,9 @@ if(nscal.gt.0.and.(iusini.eq.1.or.isuite.eq.1)) then
     if(iscavr(ii).gt.0.and.iscavr(ii).le.nscal) then
 
       ! Get the min clipping
-      iflid = ivarfl(isca(ii))
-      call field_get_key_double(iflid, kscmin, scminp)
-      call field_get_key_double(iflid, kscmax, scmaxp)
+      f_id = ivarfl(isca(ii))
+      call field_get_key_double(f_id, kscmin, scminp)
+      call field_get_key_double(f_id, kscmax, scmaxp)
 
 
       if (scminp.le.scmaxp) then
@@ -584,7 +587,7 @@ if(nscal.gt.0.and.(iusini.eq.1.or.isuite.eq.1)) then
 !       On pourrait clipper dans le cas ou VALMIN.GE.0, mais ca
 !       n'apporterait rien, par definition
           if(valmin.lt.0.d0) then
-            chaine = nomvar(ipprtp(isca(ii)))
+            call field_get_name(ivarfl(isca(ii)), chaine)
             write(nfecra,3050)ii,chaine(1:16),                     &
                               valmin,scminp,valmax,scmaxp
             iok = iok + 1
@@ -596,7 +599,7 @@ if(nscal.gt.0.and.(iusini.eq.1.or.isuite.eq.1)) then
             call clpsca(ncelet, ncel, iscal, rtp(1,isca(iscavr(ii))), rtp)
             !==========
           else
-            chaine = nomvar(ipprtp(isca(ii)))
+            call field_get_name(ivarfl(isca(ii)), chaine)
             write(nfecra,3050)ii,chaine(1:16),valmin,scminp,valmax,scmaxp
             iok = iok + 1
           endif
@@ -607,7 +610,7 @@ if(nscal.gt.0.and.(iusini.eq.1.or.isuite.eq.1)) then
 ! On pourrait clipper dans le cas ou VALMIN.GE.VFMIN.AND.VALMAX.LE.VFMAX
 !     mais ca n'apporterait rien, par definition
           if(valmin.lt.vfmin.or.valmax.gt.vfmax) then
-            chaine = nomvar(ipprtp(isca(ii)))
+            call field_get_name(ivarfl(isca(ii)), chaine)
             write(nfecra,3051)ii,chaine(1:16),                     &
                               valmin,scminp,valmax,scmaxp,         &
                               ii,iclvfl(ii)
@@ -630,80 +633,61 @@ endif
 write(nfecra,2000)
 
 !     Inconnues de calcul : on affiche les bornes
-do ipp  = 2, nvppmx
-  if(itrsvr(ipp ).ge.1) then
-    ivar = itrsvr(ipp )
+f_id = -1
+c_id = 1
+
+do ivar = 1, nvar
+  f_id_prv = f_id
+  f_id = ivarfl(ivar)
+  if (f_id.eq.f_id_prv) then
+    c_id = c_id + 1
+  else
+    c_id = 1
+  endif
+
+  call field_get_dim(f_id, f_dim, interleaved)
+
+  if (f_dim.gt.1) then
+    call field_get_val_v(f_id, field_v_v)
+  else if (f_dim.eq.1) then
+    call field_get_val_s(f_id, field_s_v)
+  endif
+
+  if (f_dim.gt.1) then
     valmax = -grand
     valmin =  grand
     do iel = 1, ncel
-      valmax = max(valmax,rtp(iel,ivar))
-      valmin = min(valmin,rtp(iel,ivar))
+      valmax = max(valmax, field_v_v(c_id,iel))
+      valmin = min(valmin, field_v_v(c_id,iel))
+    enddo
+  else
+    valmax = -grand
+    valmin =  grand
+    do iel = 1, ncel
+      valmax = max(valmax, field_s_v(iel))
+      valmin = min(valmin, field_s_v(iel))
     enddo
-    if (irangp.ge.0) then
-      call parmax (valmax)
-      !==========
-      call parmin (valmin)
-      !==========
-    endif
-    chaine = nomvar(ipp )
-    write(nfecra,2010)chaine(1:16),valmin,valmax
   endif
+
+  if (irangp.ge.0) then
+    call parmax (valmax)
+    !==========
+    call parmin (valmin)
+    !==========
+  endif
+  call field_get_label(f_id, chaine)
+  write(nfecra,2010)chaine(1:16),valmin,valmax
 enddo
 write(nfecra,2020)
 
-!     Moyennes  : on affiche les bornes
-if(nbmomt.gt.0) then
-  do imom = 1, nbmomt
-    ipcmom = ipproc(icmome(imom))
-
-!       Si on ne (re)initialise pas
-    if(imoold(imom).ne.-1) then
-      valmax = -grand
-      valmin =  grand
-!         Si le cumul en temps est variable en espace
-      if(idtmom(imom).gt.0) then
-        idtcm  = ipproc(icdtmo(idtmom(imom)))
-        do iel = 1, ncel
-          valmom = propce(iel,ipcmom) / max(propce(iel,idtcm),epzero)
-          valmax = max(valmax,valmom)
-          valmin = min(valmin,valmom)
-        enddo
-!         Si le cumul en temps est uniforme
-      else
-        idtcm  =-idtmom(imom)
-        do iel = 1, ncel
-          valmom = propce(iel,ipcmom)/ max(dtcmom(idtcm),epzero)
-          valmax = max(valmax,valmom)
-          valmin = min(valmin,valmom)
-        enddo
-      endif
-      if (irangp.ge.0) then
-        call parmax (valmax)
-        !==========
-        call parmin (valmin)
-        !==========
-      endif
-!       Si on  (re)initialise
-    else
-      valmax = 0.d0
-      valmin = 0.d0
-    endif
-
-    chaine = nomvar(ipppro(ipcmom))
-    write(nfecra,2010)chaine(1:16),valmin,valmax
-
-  enddo
-  write(nfecra,2020)
-endif
-
 if (idtvar.ge.0) then
 !     Pas de temps : on affiche les bornes
 !                    si < 0 on s'arrete
   vdtmax = -grand
   vdtmin =  grand
   do iel = 1, ncel
-    vdtmax = max(vdtmax,dt    (iel))
-    vdtmin = min(vdtmin,dt    (iel))
+    vdtmax = max(vdtmax,dt(iel))
+    vdtmin = min(vdtmin,dt(iel))
   enddo
   if (irangp.ge.0) then
     call parmax (vdtmax)
@@ -711,7 +695,7 @@ if (idtvar.ge.0) then
     call parmin (vdtmin)
     !==========
   endif
-  write(nfecra,2010) nomvar(ippdt), vdtmin, vdtmax
+  write(nfecra,2010) 'dt', vdtmin, vdtmax
   write(nfecra,2020)
 
   if (vdtmin.le.zero) then
@@ -724,78 +708,7 @@ endif
 !     Cumul du temps associe aux moments : on affiche les bornes
 !                                          si < 0 on s'arrete
 
-if(nbmomt.gt.0) then
-
-!     Indicateur de calcul des bornes pour les cumuls non uniformes
-  do imom = 1, nbmomt
-    if(idtmom(imom).gt.0) then
-      ibormo(imom) =  0
-      vmomax(imom) = -grand
-      vmomin(imom) =  grand
-    endif
-  enddo
-
-!     Calcul des bornes des cumuls non uniformes
-  do imom = 1, nbmomt
-    if(idtmom(imom).gt.0) then
-      if(ibormo(imom).eq.0) then
-        idtcm  = ipproc(icdtmo(idtmom(imom)))
-        vdtmax = -grand
-        vdtmin =  grand
-        do iel = 1, ncel
-          vdtmax = max(vdtmax,propce(iel,idtcm))
-          vdtmin = min(vdtmin,propce(iel,idtcm))
-        enddo
-        if (irangp.ge.0) then
-          call parmax (vdtmax)
-          !==========
-          call parmin (vdtmin)
-          !==========
-        endif
-        vmomax(imom) = vdtmax
-        vmomin(imom) = vdtmin
-        ibormo(imom) = 1
-      endif
-    endif
-  enddo
-
-!     Impression des bornes
-  write(nfecra,2030)
-  do imom = 1, nbmomt
-    if(idtmom(imom).gt.0) then
-      write(nfecra,2040) imom,vmomin(imom),       &
-                              vmomax(imom),       &
-                              'Variable'
-    elseif(idtmom(imom).lt.0) then
-#if defined(_CS_LANG_FR)
-      write(nfecra,2040) imom,dtcmom(-idtmom(imom)),              &
-                              dtcmom(-idtmom(imom)),              &
-                              'Uniforme'
-#else
-      write(nfecra,2040) imom,dtcmom(-idtmom(imom)),              &
-                              dtcmom(-idtmom(imom)),              &
-                              'Uniform'
-#endif
-    endif
-  enddo
-  write(nfecra,2050)
-
-!     On s'arrete si des cumuls sont negatifs
-  do imom = 1, nbmomt
-    if(idtmom(imom).gt.0) then
-      if(vmomin(imom).lt.zero) then
-        write(nfecra,3011) imom,vmomin(imom)
-        iok = iok + 1
-      endif
-    elseif(idtmom(imom).lt.0) then
-      if(dtcmom(-idtmom(imom)).lt.zero) then
-        write(nfecra,3011) imom,dtcmom(-idtmom(imom))
-        iok = iok + 1
-      endif
-    endif
-  enddo
-
-endif
+call time_moment_log_iteration
 
 !===============================================================================
 ! 7.  ARRET GENERAL SI PB
@@ -830,15 +743,6 @@ write(nfecra,3000)
  2x,     a16,      e12.4,      e12.4                             )
  2020 format(                                                     &
 ' ---------------------------------',                           /)
- 2030 format(                                                     &
-' Duree cumulee :',                                             /,&
-' ------------------------------------------------------------',/,&
-'   Moyenne  Valeur min  Valeur max Uniforme/Variable en espac',/,&
-' ------------------------------------------------------------'  )
- 2040 format(                                                     &
-        i10,      e12.4,      e12.4,1x,   a8                     )
- 2050 format(                                                     &
-' ------------------------------------------------------------',/)
 
  3000 format(/,/,                                                 &
 '-------------------------------------------------------------',/)
@@ -860,28 +764,6 @@ write(nfecra,3000)
 '@    cs_user_initialization.f90 ou via l''interface.',         /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@',                                                            /)
- 3011 format(                                                     &
-'@',                                                            /,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@',                                                            /,&
-'@ @@ ATTENTION : ARRET A L''INITIALISATION DES VARIABLES',     /,&
-'@    =========',                                               /,&
-'@    CUMUL DE DUREE POUR LES MOYENNES NEGATIVE',               /,&
-'@',                                                            /,&
-'@  Le calcul ne peut etre execute.',                           /,&
-'@',                                                            /,&
-'@  La valeur minimale de la duree cumulee pour la moyenne',    /,&
-'@    IMOM = ',i10,   ' est ',e14.5,                            /,&
-'@',                                                            /,&
-'@  Verifier l''initialisation ou le fichier de reprise.',      /,&
-'@',                                                            /,&
-'@  Dans le cas ou les valeurs lues dans le fichier',           /,&
-'@    de reprise sont incorrectes, on peut reinitialiser',      /,&
-'@    la moyenne et le cumul temporel associe en imposant',     /,&
-'@    IMOOLD(IMOM) = -1.',                                      /,&
-'@',                                                            /,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
  3020 format(                                                     &
 '@',                                                            /,&
@@ -1173,15 +1055,6 @@ write(nfecra,3000)
  2x,     a16,      e12.4,      e12.4                             )
  2020 format(                                                     &
 ' ---------------------------------',                           /)
- 2030 format(                                                     &
-' Time averages (sum over the time-steps)',                     /,&
-' ------------------------------------------------------------',/,&
-'   Average  Min. value  Max. value Uniform/Variable in space', /,&
-' ------------------------------------------------------------'  )
- 2040 format(                                                     &
-        i10,      e12.4,      e12.4,1x,   a8                     )
- 2050 format(                                                     &
-' ------------------------------------------------------------',/)
 
  3000 format(/,/,                                                 &
 '-------------------------------------------------------------',/)
@@ -1202,26 +1075,6 @@ write(nfecra,3000)
 '@    cs_user_initialization.f90 or with the interface.',       /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@',                                                            /)
- 3011 format(                                                     &
-'@',                                                            /,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@',                                                            /,&
-'@ @@ WARNING: ABORT IN THE VARIABLES INITIALIZATION',          /,&
-'@    ========',                                                /,&
-'@    NEGATIVE CUMULATIVE TIME FOR THE MOMENTS',                /,&
-'@',                                                            /,&
-'@  The calculation will not be run.',                          /,&
-'@',                                                            /,&
-'@  The minimum value of the cumulative time for the moment',   /,&
-'@    IMOM = ',i10,   ' est ',e14.5,                            /,&
-'@',                                                            /,&
-'@  Verify the initialization or the restart file.',            /,&
-'@  In the case where the values read in the restart file',     /,&
-'@    are incorrect, the moment and the associated cumulative', /,&
-'@    time may be re-initialized by setting IMOOLD(IMOM) = -1.',/,&
-'@',                                                            /,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
  3020 format(                                                     &
 '@',                                                            /,&
