@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -91,7 +91,7 @@ integer          ncelet , ncel
 integer          nvar   , nscal
 
 
-double precision rtp(ncelet,*)
+double precision rtp(ncelet,nflown:nvar)
 
 ! Local variables
 
@@ -109,14 +109,16 @@ integer          ierror, irtyp,  itysup, nbval
 integer          nberro, ilecec
 integer          iturph, jturph, itytph, jtytph
 integer          nfmtsc, nfmtru
-integer          jturb, jtytur, jale, jturbt
+integer          jturb, jtytur, jale, jturbt, jcavit
 integer          impamo
-integer          ival
+integer          ival, isou
 integer          f_id
 double precision d2s3, d2s3xk
 double precision rval
+double precision, allocatable, dimension(:,:) :: l_velocity
 
 double precision, dimension(:,:), pointer :: xut
+double precision, dimension(:,:), pointer :: vel
 
 !===============================================================================
 
@@ -408,6 +410,25 @@ if (nberro.ne.0) then
   jale = 0
 endif
 
+!     Cavitation
+
+nberro = 0
+
+rubriq = 'cavitation'
+itysup = 0
+nbval  = 1
+irtyp  = 1
+call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,jcavit,    &
+            ierror)
+nberro=nberro+ierror
+
+! --->  Message si erreur (pas de stop pour compatibilite avec les fichiers anterieurs)
+!       -> on n'affiche le message que si ICAVIT>=0 (sinon RAS)
+if (nberro.ne.0) then
+  if (icavit.ge.0) write(nfecra,9401)
+  jcavit = -1
+endif
+
 ! --->  Stop si pas de temps incoherent
 if(ntpabs.ge.ntmabs.and.inpdt0.eq.0) then
   write(nfecra,9410)ntpabs,ntmabs
@@ -488,6 +509,8 @@ itytph = itytur
 jtytph = jtytur
 
 !     Vitesse
+! TODO: must be improved for field structure
+allocate(l_velocity(ncelet, 3))
 
 itysup = 1
 nbval  = 1
@@ -495,20 +518,27 @@ irtyp  = 2
 
 rubriq = 'vitesse_u_ce_phase'//cphase
 call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,      &
-     rtp(1,iu),ierror)
+     l_velocity(:,1),ierror)
 nberro=nberro+ierror
 
 rubriq = 'vitesse_v_ce_phase'//cphase
 call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,      &
-     rtp(1,iv),ierror)
+     l_velocity(:,2),ierror)
 nberro=nberro+ierror
 
 rubriq = 'vitesse_w_ce_phase'//cphase
 call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,      &
-     rtp(1,iw),ierror)
+     l_velocity(:,3),ierror)
 nberro=nberro+ierror
 
+call field_get_val_v(ivarfl(iu), vel)
+do iel = 1, ncelet
+  do isou = 1, 3
+    vel(isou, iel) = l_velocity(iel,isou)
+  enddo
+enddo
 
+deallocate(l_velocity)
 
 !     Turbulence (ke -> ke, ke -> rij, rij -> ke, rij -> rij ...)
 !       Quand on ne sait pas deduire les grandeurs turbulence des infos
@@ -1081,6 +1111,29 @@ if (iale.eq.1 .and. jale.eq.1) then
 
 endif
 
+!  ---> Cavitation
+
+if (icavit.ge.0 .and. jcavit.ge.0) then
+
+  nberro = 0
+
+  itysup = 1
+  nbval  = 1
+  irtyp  = 2
+
+  rubriq = 'taux_vide_ce'
+  call lecsui(impamo,rubriq,len(rubriq),itysup,nbval,irtyp,       &
+       rtp(1,ivoidf),ierror)
+  nberro=nberro+ierror
+
+  if (nberro.ne.0) then
+    write(nfecra,9514)
+  endif
+
+  write(nfecra,1601)
+
+endif
+
 !================================================================
 ! 6. LECTURE D'INFORMATIONS COMPLEMENTAIRES LEGERES
 !================================================================
@@ -1135,6 +1188,8 @@ return
  1599 format('   Fin de la lecture des scalaires                    '  )
  1600 format('   Fin de la lecture de la vitesse de maillage        ',/,&
        '                                  (methode ALE)       '  )
+ 1601 format('   Fin de la lecture du taux de vide'                  ,/,&
+       '                                (modele de cavitation)'  )
  1799 format(' Fin de la lecture                                    '  )
 
 #else
@@ -1148,6 +1203,7 @@ return
        '        variables complete                            '  )
  1599 format('   Reading scalars complete                           '  )
  1600 format('   Reading the mesh velocity (ALE method) complete    '  )
+ 1601 format('   Reading the void fraction (cavitation) complete'      )
  1799 format(' Reading complete                                     '  )
 
 #endif
@@ -1695,6 +1751,24 @@ return
 '@                                     maillage reinitialisee)',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 9514 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /,&
+'@ @@ ATTENTION : LECTURE DU FICHIER SUITE PRINCIPAL',          /,&
+'@    =========',                                               /,&
+'@',                                                            /,&
+'@      ERREUR LORS DE LA LECTURE DU TAUX DE VIDE',             /,&
+'@        (MODELE DE CAVITATION)',                              /,&
+'@',                                                            /,&
+'@    Verifier que le fichier suite utilise n''a pas ete',      /,&
+'@        endommage.',                                          /,&
+'@',                                                            /,&
+'@    Le calcul peut neanmoins etre execute (taux de vide',     /,&
+'@                                           reinitialisee)'   ,/,&
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
 
 #else
@@ -1988,6 +2062,24 @@ return
 '@                                     velocity reset)        ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 9514 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /,&
+'@ @@ WARNING : AT THE MAIN RESTART FILE READING',              /,&
+'@    =========',                                               /,&
+'@',                                                            /,&
+'@      ERROR AT THE READING OF VOID FRACTION',                 /,&
+'@        (CAVITATION MODELING)',                               /,&
+'@',                                                            /,&
+'@    Please check the integrity of the file used as',          /,&
+'@        restart file',                                        /,&
+'@',                                                            /,&
+'@    The calculation can be executed however (void fraction',  /,&
+'@                                             reset)',         /,&
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
 
 #endif
