@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -48,7 +48,6 @@
 !> \param[in,out] rtp, rtpa     calculated variables at cell centers
 !>                               (at current and previous time steps)
 !> \param[in]     propce        physical properties at cell centers
-!> \param[in]     coefa, coefb  boundary conditions
 !> \param[in]     frcxt         external force generating the hydrostatic
 !>                              pressure
 !> \param[in]     prhyd         hydrostatic pressure predicted at cell centers
@@ -62,7 +61,7 @@ subroutine navstv &
  ( nvar   , nscal  , iterns , icvrge , itrale ,                   &
    isostd ,                                                       &
    dt     , rtp    , rtpa   , propce ,                            &
-   coefa  , coefb  , frcxt  , prhyd  ,                            &
+   frcxt  , prhyd  ,                                              &
    trava  , ximpa  , uvwk   )
 
 !===============================================================================
@@ -92,6 +91,7 @@ use lagdim, only: ntersl
 use turbomachinery
 use ptrglo
 use field
+use cavitation
 
 !===============================================================================
 
@@ -105,7 +105,6 @@ integer          isostd(nfabor+1)
 
 double precision, pointer, dimension(:)   :: dt
 double precision, pointer, dimension(:,:) :: rtp, rtpa, propce
-double precision, dimension(nfabor,*) :: coefa, coefb
 double precision, pointer, dimension(:,:) :: frcxt
 double precision, pointer, dimension(:) :: prhyd
 double precision, pointer, dimension(:,:) :: trava, uvwk
@@ -123,16 +122,19 @@ integer          nswrgp, imligp, iwarnp
 integer          nbrval, iappel, iescop
 integer          ndircp, icpt
 integer          numcpl
+integer          iflvoi, iflvob
 double precision rnorm , rnormt, rnorma, rnormi, vitnor
 double precision dtsrom, unsrom, surf  , rhom, rovolsdt
 double precision epsrgp, climgp, extrap, xyzmax(3)
 double precision thetap, xdu, xdv, xdw
 double precision xxp0 , xyp0 , xzp0
 double precision rhofac, dtfac, ddepx , ddepy, ddepz
-double precision xnrdis
+double precision xnrdis, xnrtmp
 double precision vitbox, vitboy, vitboz
-
-double precision t1, t2, t3, t4, ellap1, ellap2
+double precision t1, t2, t3, t4
+double precision visclc, visctc
+double precision distbf, srfbnf, hint
+double precision rnx, rny, rnz, rcodcx, rcodcy, rcodcz, rcodcn
 
 double precision, allocatable, dimension(:,:,:), target :: viscf
 double precision, allocatable, dimension(:), target :: viscb
@@ -149,6 +151,7 @@ double precision, allocatable, dimension(:) :: secvif, secvib
 double precision, dimension(:,:), allocatable :: gradp
 double precision, dimension(:,:), allocatable :: mshvel
 double precision, dimension(:), allocatable :: coefa_dp, coefb_dp
+double precision, dimension(:), allocatable :: xinvro
 
 double precision, dimension(:,:), pointer :: grdphd
 double precision, dimension(:,:), pointer :: vel, vela
@@ -157,9 +160,14 @@ double precision, dimension(:), pointer :: viscbi
 double precision, dimension(:,:), pointer :: dttens
 double precision, dimension(:,:), pointer :: dfrcxt
 
+double precision, dimension(:,:), pointer :: coefau, cofafu, claale
+double precision, dimension(:,:,:), pointer :: coefbu, cofbfu, clbale
+
 double precision, dimension(:), pointer :: coefa_p
 double precision, dimension(:), pointer :: imasfl, bmasfl
-double precision, dimension(:), pointer :: brom, crom
+double precision, dimension(:), pointer :: brom, crom, croma, viscl, visct
+double precision, dimension(:), pointer :: ivoifl, bvoifl
+double precision, dimension(:), pointer :: coavoi, cobvoi
 double precision, dimension(:,:), pointer :: trav
 
 !===============================================================================
@@ -176,8 +184,6 @@ else if (idften(iu).eq.6) then
 endif
 
 allocate(trav(3,ncelet))
-allocate(vela(3,ncelet))
-allocate(vel(3,ncelet))
 
 ! Allocate other arrays, depending on user options
 
@@ -190,7 +196,6 @@ if (iphydr.eq.2) then
 else
   grdphd => rvoid2
 endif
-if (iescal(iestot).gt.0) allocate(esflum(nfac), esflub(ndimfb))
 if (idften(iu).eq.1) then
   if (itytur.eq.3.and.irijnu.eq.1) then
     allocate(wvisfi(1,1,nfac), wvisbi(ndimfb))
@@ -215,6 +220,10 @@ if (ivisse.eq.1) then
   allocate(secvif(nfac),secvib(ndimfb))
 endif
 
+! Map field arrays
+call field_get_val_v(ivarfl(iu), vel)
+call field_get_val_prev_v(ivarfl(iu), vela)
+
 ! Map some specific field arrays
 if (idtten.ge.0) then
   call field_get_val_v(idtten, dttens)
@@ -227,17 +236,6 @@ allocate(w1(ncelet))
 allocate(w7(ncelet), w8(ncelet), w9(ncelet))
 if (irnpnw.eq.1) allocate(w10(ncelet))
 
-! Interleaved value of vel and vela
-!$omp parallel do
-do iel = 1, ncelet
-  vel (1,iel) = rtp (iel,iu)
-  vel (2,iel) = rtp (iel,iv)
-  vel (3,iel) = rtp (iel,iw)
-  vela(1,iel) = rtpa(iel,iu)
-  vela(2,iel) = rtpa(iel,iv)
-  vela(3,iel) = rtpa(iel,iw)
-enddo
-
 if (iwarni(iu).ge.1) then
   write(nfecra,1000)
 endif
@@ -263,14 +261,15 @@ if (nterup.gt.1) then
 
   ! Calcul de la norme L2 de la vitesse
   if (iterns.eq.1) then
-    xnrmu0 = 0.d0
-    !$omp parallel do reduction(+:xnrmu0)
+    xnrtmp = 0.d0
+    !$omp parallel do reduction(+:xnrtmp)
     do iel = 1, ncel
-      xnrmu0 = xnrmu0 +(vela(1,iel)**2        &
+      xnrtmp = xnrtmp +(vela(1,iel)**2        &
                       + vela(2,iel)**2        &
                       + vela(3,iel)**2)       &
                       * volume(iel)
     enddo
+    xnrmu0 = xnrtmp
     if (irangp.ge.0) then
       call parsom (xnrmu0)
       !==========
@@ -300,6 +299,10 @@ if (nterup.gt.1) then
 
 endif
 
+! --- Physical quantities
+call field_get_val_s(iprpfl(iviscl), viscl)
+call field_get_val_s(iprpfl(ivisct), visct)
+
 ! Initialize timers
 t1 = 0.d0
 t2 = 0.d0
@@ -349,7 +352,18 @@ if ( ippmod(icompf).ge.0 ) then
 endif
 
 !===============================================================================
-! 4. Velocity prediction step
+! 4. Compute liquid-vapour mass transfer term for cavitating flows
+!===============================================================================
+
+if (icavit.ge.0) then
+
+  call cavitation_compute_source_term (rtpa(:,ipr), rtpa(:,ivoidf))
+  !==================================
+
+endif
+
+!===============================================================================
+! 5. Velocity prediction step
 !===============================================================================
 
 iappel = 1
@@ -366,6 +380,12 @@ call field_get_val_s(iflmab, bmasfl)
 call field_get_val_s(icrom, crom)
 call field_get_val_s(ibrom, brom)
 
+! Pointers to BC coefficients
+call field_get_coefa_v(ivarfl(iu), coefau)
+call field_get_coefb_v(ivarfl(iu), coefbu)
+call field_get_coefaf_v(ivarfl(iu), cofafu)
+call field_get_coefbf_v(ivarfl(iu), cofbfu)
+
 call predvv &
 !==========
 ( iappel ,                                                       &
@@ -399,9 +419,9 @@ if (iprco.le.0) then
 
   call inimav                                                     &
   !==========
- ( iu     , itypfl ,                                              &
+ ( ivarfl(iu)      , itypfl ,                                     &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp ,                                              &
    crom, brom,                                                    &
    vel    ,                                                       &
@@ -433,11 +453,14 @@ if (iprco.le.0) then
     epsrgp = epsrgr(iuma)
     climgp = climgr(iuma)
 
+    call field_get_coefa_v(ivarfl(iuma), claale)
+    call field_get_coefb_v(ivarfl(iuma), clbale)
+
     call inimav &
     !==========
-  ( iu     , itypfl ,                                              &
+  ( ivarfl(iuma)    , itypfl ,                                     &
     iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
-    iwarnp , nfecra ,                                              &
+    iwarnp ,                                                       &
     epsrgp , climgp ,                                              &
     crom, brom,                                                    &
     mshvel ,                                                       &
@@ -489,38 +512,9 @@ if (iprco.le.0) then
 
   ! Ajout de la vitesse du solide dans le flux convectif,
   ! si le maillage est mobile (solide rigide)
-  ! En turbomachine, on conna\EEt exactement la vitesse de maillage \E0 ajouter
-  if (imobil.eq.1) then
-
+  ! En turbomachine, on connait exactement la vitesse de maillage a ajouter
+  if (imobil.eq.1 .or. iturbo.eq.1 .or. iturbo.eq.2) then
     !$omp parallel do private(iel1, iel2, dtfac, rhofac, vitbox, vitboy, vitboz)
-    do ifac = 1, nfac
-      iel1 = ifacel(1,ifac)
-      iel2 = ifacel(2,ifac)
-      dtfac  = 0.5d0*(dt(iel1) + dt(iel2))
-      rhofac = 0.5d0*(crom(iel1) + crom(iel2))
-      vitbox = omegay*cdgfac(3,ifac) - omegaz*cdgfac(2,ifac)
-      vitboy = omegaz*cdgfac(1,ifac) - omegax*cdgfac(3,ifac)
-      vitboz = omegax*cdgfac(2,ifac) - omegay*cdgfac(1,ifac)
-      imasfl(ifac) = imasfl(ifac) - rhofac*(        &
-           vitbox*surfac(1,ifac) + vitboy*surfac(2,ifac) + vitboz*surfac(3,ifac) )
-    enddo
-    !$omp parallel do private(iel, dtfac, rhofac, vitbox, vitboy, vitboz) &
-    !$omp          if(nfabor > thr_n_min)
-    do ifac = 1, nfabor
-      iel = ifabor(ifac)
-      dtfac  = dt(iel)
-      rhofac = brom(ifac)
-      vitbox = omegay*cdgfbo(3,ifac) - omegaz*cdgfbo(2,ifac)
-      vitboy = omegaz*cdgfbo(1,ifac) - omegax*cdgfbo(3,ifac)
-      vitboz = omegax*cdgfbo(2,ifac) - omegay*cdgfbo(1,ifac)
-      bmasfl(ifac) = bmasfl(ifac) - rhofac*(        &
-           vitbox*surfbo(1,ifac) + vitboy*surfbo(2,ifac) + vitboz*surfbo(3,ifac) )
-    enddo
-
-  endif
-
-  if (iturbo.eq.1 .or. iturbo.eq.2) then
-
     do ifac = 1, nfac
       iel1 = ifacel(1,ifac)
       iel2 = ifacel(2,ifac)
@@ -535,7 +529,8 @@ if (iprco.le.0) then
                                               + vitboz*surfac(3,ifac))
       endif
     enddo
-
+    !$omp parallel do private(iel, dtfac, rhofac, vitbox, vitboy, vitboz) &
+    !$omp          if(nfabor > thr_n_min)
     do ifac = 1, nfabor
       iel = ifabor(ifac)
       if (irotce(iel).ne.0) then
@@ -549,25 +544,10 @@ if (iprco.le.0) then
                                               + vitboz*surfbo(3,ifac))
       endif
     enddo
-
   endif
 
-  ! Interleaved values of vel and vela
-
-  !$omp parallel do
-  do iel = 1, ncelet
-    rtp (iel,iu) = vel (1,iel)
-    rtp (iel,iv) = vel (2,iel)
-    rtp (iel,iw) = vel (3,iel)
-    rtpa(iel,iu) = vela(1,iel)
-    rtpa(iel,iv) = vela(2,iel)
-    rtpa(iel,iw) = vela(3,iel)
-  enddo
-
   ! Free memory
   !--------------
-  deallocate(vel)
-  deallocate(vela)
   deallocate(coefa_dp, coefb_dp)
 
   return
@@ -575,19 +555,19 @@ if (iprco.le.0) then
 endif
 
 !===============================================================================
-! 4. Update mesh for unsteady turbomachinery computations
+! 6. Update mesh for unsteady turbomachinery computations
 !===============================================================================
 
-if (iturbo.eq.2) then
-
-  call dmtmps(t1)
-  !==========
+if (iturbo.eq.2 .and. iterns.eq.1) then
 
   ! Update mesh
 
-  call turbomachinery_update_mesh (ttcmob, ellap1)
+  call turbomachinery_update_mesh (ttcmob, rs_ell(1))
   !==============================
 
+  call dmtmps(t1)
+  !==========
+
   do ifac = 1, nfabor
     isympa(ifac) = 1
   enddo
@@ -601,7 +581,7 @@ if (iturbo.eq.2) then
     allocate(viscf(3, 3, nfac))
   endif
 
-  if (allocated(wvisfi)) then ! TODO verifier
+  if (allocated(wvisfi)) then
     deallocate(viscfi)
 
     if (idften(iu).eq.1) then
@@ -631,6 +611,10 @@ if (iturbo.eq.2) then
 
   call turbomachinery_reinit_i_face_fields
 
+  ! Update local pointers on "internal faces" fields
+
+  call field_get_val_s(iflmas, imasfl)
+
   if (irangp.ge.0 .or. iperio.eq.1) then
 
     ! Scratch and resize work arrays
@@ -657,17 +641,14 @@ if (iturbo.eq.2) then
     call turbomachinery_update
     !=========================
 
-    ! Update field mappings ("owner" fields handled by update_turbomachinery)
+    ! Update field mappings ("owner" fields handled by turbomachinery_update)
 
-    call fldtri(nproce, dt, rtpa, rtp, propce, coefa, coefb)
+    call fldtri(nproce, dt, rtpa, rtp, propce)
     !==========
 
     ! Resize other arrays related to the velocity-pressure resolution
 
-    call resize_vec_real_array(vel)
-    call resize_vec_real_array(vela)
     call resize_vec_real_array(trav)
-
     call resize_vec_real_array(dfrcxt)
 
     ! Resize other arrays, depending on user options
@@ -688,23 +669,82 @@ if (iturbo.eq.2) then
       call resize_tens_real_array(ximpa)
     endif
 
+    ! Update local pointers on "cells" fields
+
+    call field_get_val_s(icrom, crom)
+
+    call field_get_val_s(iprpfl(iviscl), viscl)
+    call field_get_val_s(iprpfl(ivisct), visct)
+
+    call field_get_val_v(ivarfl(iu), vel)
+    call field_get_val_prev_v(ivarfl(iu), vela)
+
+    if (idtten.ge.0) call field_get_val_v(idtten, dttens)
+
   endif
 
-  ! Update local pointers
+  ! Update the Dirichlet wall boundary conditions for velocity (based on the
+  ! solid body rotation on the new mesh).
+  ! Note that the velocity BC update is made only if the user has not specified
+  ! any specific Dirichlet condition for velocity.
 
-  call field_get_val_s(iflmas, imasfl)
-  call field_get_val_s(iflmab, bmasfl)
+  do ifac = 1, nfabor
 
-  call field_get_val_s(icrom, crom)
-  call field_get_val_s(ibrom, brom)
+    iel = ifabor(ifac)
+
+    if (coftur(ifac).lt.rinfin*0.5d0) then
+
+      ! --- Physical Propreties
+      visclc = viscl(iel)
+      visctc = visct(iel)
+
+      ! --- Geometrical quantities
+      distbf = distb(ifac)
+      srfbnf = surfbn(ifac)
+
+      ! Unit normal
+      rnx = surfbo(1,ifac)/srfbnf
+      rny = surfbo(2,ifac)/srfbnf
+      rnz = surfbo(3,ifac)/srfbnf
+
+      if (itytur.eq.3) then
+        hint =   visclc         /distbf
+      else
+        hint = ( visclc+visctc )/distbf
+      endif
+
+      rcodcx = rotax(2)*cdgfbo(3,ifac) - rotax(3)*cdgfbo(2,ifac)
+      rcodcy = rotax(3)*cdgfbo(1,ifac) - rotax(1)*cdgfbo(3,ifac)
+      rcodcz = rotax(1)*cdgfbo(2,ifac) - rotax(2)*cdgfbo(1,ifac)
+
+      ! Gradient boundary conditions (Dirichlet)
+      !-----------------------------
+      rcodcn = rcodcx*rnx+rcodcy*rny+rcodcz*rnz
+
+      coefau(1,ifac) = (1.d0-coftur(ifac))*(rcodcx - rcodcn*rnx) + rcodcn*rnx
+      coefau(2,ifac) = (1.d0-coftur(ifac))*(rcodcy - rcodcn*rny) + rcodcn*rny
+      coefau(3,ifac) = (1.d0-coftur(ifac))*(rcodcz - rcodcn*rnz) + rcodcn*rnz
+
+      ! Flux boundary conditions (Dirichlet)
+      !-------------------------
+
+      cofafu(1,ifac) = -hfltur(ifac)*(rcodcx - rcodcn*rnx) - hint*rcodcn*rnx
+      cofafu(2,ifac) = -hfltur(ifac)*(rcodcy - rcodcn*rny) - hint*rcodcn*rny
+      cofafu(3,ifac) = -hfltur(ifac)*(rcodcz - rcodcn*rnz) - hint*rcodcn*rnz
+
+    endif
+
+  enddo
 
   call dmtmps(t2)
   !==========
 
+  rs_ell(2) = t2-t1
+
 endif
 
 !===============================================================================
-! 5. Pressure correction step
+! 7. Pressure correction step
 !===============================================================================
 
 if (iwarni(iu).ge.1) then
@@ -732,7 +772,7 @@ if (ippmod(icompf).lt.0) then
 endif
 
 !===============================================================================
-! 6. Mesh velocity solving (ALE)
+! 8. Mesh velocity solving (ALE)
 !===============================================================================
 
 if (iale.eq.1) then
@@ -745,9 +785,19 @@ if (iale.eq.1) then
 endif
 
 !===============================================================================
-! 7. Update of the fluid velocity field
+! 9. Update of the fluid velocity field
 !===============================================================================
 
+! Mass flux initialization for cavitating flows
+if (icavit.ge.0) then
+  do ifac = 1, nfac
+    imasfl(ifac) = 0.d0
+  enddo
+  do ifac = 1, nfabor
+    bmasfl(ifac) = 0.d0
+  enddo
+endif
+
 if (ippmod(icompf).lt.0) then
 
   ! irevmc = 0: Only the standard method is available for the coupled
@@ -792,13 +842,29 @@ if (ippmod(icompf).lt.0) then
     !Allocation
     allocate(gradp(ncelet,3))
 
-    call grdpot &
-    !==========
-    ( ipr    , imrgra , inc    , iccocg , nswrgp , imligp , iphydr , &
-      iwarnp , epsrgp , climgp , extrap ,                            &
-      dfrcxt ,                                                       &
-      drtp   , coefa_dp        , coefb_dp        ,                   &
-      gradp  )
+    if (icavit.lt.0) then
+      call grdpot &
+      !==========
+      ( ipr    , imrgra , inc    , iccocg , nswrgp , imligp , iphydr , &
+        iwarnp , epsrgp , climgp , extrap ,                            &
+        dfrcxt ,                                                       &
+        drtp   , coefa_dp        , coefb_dp        ,                   &
+        gradp  )
+    else
+      allocate(xinvro(ncelet))
+      do iel = 1, ncel
+        xinvro(iel) = 1.d0/crom(iel)
+      enddo
+
+      call grdpre &
+      !==========
+      ( ipr    , imrgra , inc    , iccocg , nswrgp , imligp ,          &
+        iwarnp , epsrgp , climgp , extrap ,                            &
+        drtp   , xinvro , coefa_dp , coefb_dp ,                        &
+        gradp  )
+
+      deallocate(xinvro)
+    endif
 
     thetap = thetav(ipr)
     !$omp parallel do private(isou)
@@ -953,11 +1019,14 @@ if (iale.eq.1) then
   epsrgp = epsrgr(iuma)
   climgp = climgr(iuma)
 
+  call field_get_coefa_v(ivarfl(iuma), claale)
+  call field_get_coefb_v(ivarfl(iuma), clbale)
+
   call inimav &
   !==========
-( iuma   , itypfl ,                                              &
+( ivarfl(iuma)    , itypfl ,                                     &
   iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
-  iwarnp , nfecra ,                                              &
+  iwarnp ,                                                       &
   epsrgp , climgp ,                                              &
   crom, brom,                                                    &
   mshvel ,                                                       &
@@ -1010,41 +1079,13 @@ endif
 !FIXME for me we should do that before predvv
 ! Ajout de la vitesse du solide dans le flux convectif,
 ! si le maillage est mobile (solide rigide)
-! En turbomachine, on conna\EEt exactement la vitesse de maillage \E0 ajouter
+! En turbomachine, on connait exactement la vitesse de maillage a ajouter
+if (imobil.eq.1 .or. iturbo.eq.1 .or. iturbo.eq.2) then
 
-if (imobil.eq.1) then
+  if (iturbo.eq.1.or.iturbo.eq.2) call dmtmps(t3)
+                                  !==========
 
   !$omp parallel do private(iel1, iel2, dtfac, rhofac, vitbox, vitboy, vitboz)
-  do ifac = 1, nfac
-    iel1 = ifacel(1,ifac)
-    iel2 = ifacel(2,ifac)
-    dtfac  = 0.5d0*(dt(iel1) + dt(iel2))
-    rhofac = 0.5d0*(crom(iel1) + crom(iel2))
-    vitbox = omegay*cdgfac(3,ifac) - omegaz*cdgfac(2,ifac)
-    vitboy = omegaz*cdgfac(1,ifac) - omegax*cdgfac(3,ifac)
-    vitboz = omegax*cdgfac(2,ifac) - omegay*cdgfac(1,ifac)
-    imasfl(ifac) = imasfl(ifac) - rhofac*(        &
-         vitbox*surfac(1,ifac) + vitboy*surfac(2,ifac) + vitboz*surfac(3,ifac) )
-  enddo
-  !$omp parallel do private(iel, dtfac, rhofac, vitbox, vitboy, vitboz) &
-  !$omp             if(nfabor > thr_n_min)
-  do ifac = 1, nfabor
-    iel = ifabor(ifac)
-    dtfac  = dt(iel)
-    rhofac = brom(ifac)
-    vitbox = omegay*cdgfbo(3,ifac) - omegaz*cdgfbo(2,ifac)
-    vitboy = omegaz*cdgfbo(1,ifac) - omegax*cdgfbo(3,ifac)
-    vitboz = omegax*cdgfbo(2,ifac) - omegay*cdgfbo(1,ifac)
-    bmasfl(ifac) = bmasfl(ifac) - rhofac*(        &
-         vitbox*surfbo(1,ifac) + vitboy*surfbo(2,ifac) + vitboz*surfbo(3,ifac) )
-  enddo
-endif
-
-if (iturbo.eq.1 .or. iturbo.eq.2) then
-
-  call dmtmps(t3)
-  !==========
-
   do ifac = 1, nfac
     iel1 = ifacel(1,ifac)
     iel2 = ifacel(2,ifac)
@@ -1059,7 +1100,8 @@ if (iturbo.eq.1 .or. iturbo.eq.2) then
                                             + vitboz*surfac(3,ifac))
     endif
   enddo
-
+  !$omp parallel do private(iel, dtfac, rhofac, vitbox, vitboy, vitboz) &
+  !$omp             if(nfabor > thr_n_min)
   do ifac = 1, nfabor
     iel = ifabor(ifac)
     if (irotce(iel).ne.0) then
@@ -1074,15 +1116,65 @@ if (iturbo.eq.1 .or. iturbo.eq.2) then
     endif
   enddo
 
-  call dmtmps(t4)
-  !==========
+  if (iturbo.eq.1.or.iturbo.eq.2) call dmtmps(t4)
+                                  !==========
 
-  ellap2 = t2-t1 + t4-t3
+  rs_ell(2) = rs_ell(2) + t4-t3
 
 endif
 
 !===============================================================================
-! 8. Compute error estimators for correction step and the global algo
+! 10. Cavitation: void fraction solving and update the mixture density/viscosity
+!      and mass flux (resopv solved the convective flux of void fraction, divU)
+!===============================================================================
+
+if (icavit.ge.0) then
+
+  ! Void fraction solving
+
+  call resvoi(dt, rtp, rtpa, propce)
+  !==========
+
+  ! Halo synchronization
+
+  call synsca(rtp(:,ivoidf))
+  !==========
+
+  ! Get the void fraction boundary conditions
+
+  call field_get_coefa_s(ivarfl(ivoidf), coavoi)
+  call field_get_coefb_s(ivarfl(ivoidf), cobvoi)
+
+  ! Get the convective flux of the void fraction
+
+  call field_get_key_int(ivarfl(ivoidf), kimasf, iflvoi)
+  call field_get_key_int(ivarfl(ivoidf), kbmasf, iflvob)
+  call field_get_val_s(iflvoi, ivoifl)
+  call field_get_val_s(iflvob, bvoifl)
+
+  ! Update mixture density/viscosity and mass flux
+
+  call cavitation_update_phys_prop &
+  !===============================
+ ( rtp(:,ivoidf), coavoi, cobvoi, ivoifl, bvoifl, &
+   crom, brom, propce(:,ipproc(iviscl)), imasfl, bmasfl )
+
+  ! Verbosity
+
+  if (mod(ntcabs,ntlist).eq.0.and.iterns.eq.nterup) then
+
+    call field_get_val_prev_s(icrom, croma)
+
+    call cavitation_print_mass_budget &
+    !================================
+   ( crom, croma, dt, imasfl, bmasfl )
+
+  endif
+
+endif
+
+!===============================================================================
+! 11. Compute error estimators for correction step and the global algo
 !===============================================================================
 
 if (iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
@@ -1133,9 +1225,9 @@ if (iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
 
   call inimav                                                     &
   !==========
- ( iu     , itypfl ,                                              &
+ ( ivarfl(iu)      , itypfl ,                                     &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp ,                                              &
    crom, brom,                                                    &
    vel    ,                                                       &
@@ -1148,9 +1240,7 @@ if (iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
 
   if (iescal(iescor).gt.0) then
     init = 1
-    call divmas(ncelet, ncel, nfac, nfabor, init, nfecra,         &
-    !==========
-                ifacel, ifabor, esflum, esflub, w1)
+    call divmas(init, esflum, esflub, w1)
 
     if (ncetsm.gt.0) then
       !$omp parallel do private(iel) if(ncetsm > thr_n_min)
@@ -1210,10 +1300,11 @@ if (iescal(iescor).gt.0.or.iescal(iestot).gt.0) then
 
   endif
 
+  deallocate(esflum, esflub)
 endif
 
 !===============================================================================
-! 9. Loop on the velocity/Pressure coupling (PISO)
+! 12. Loop on the velocity/Pressure coupling (PISO)
 !===============================================================================
 
 if (nterup.gt.1) then
@@ -1222,15 +1313,15 @@ if (nterup.gt.1) then
 
   icvrge = 1
 
-  xnrmu = 0.d0
-  !$omp parallel do reduction(+:xnrmu0) private(xdu, xdv, xdw)
+  xnrtmp = 0.d0
+  !$omp parallel do reduction(+:xnrtmp) private(xdu, xdv, xdw)
   do iel = 1,ncel
     xdu = vel(1,iel) - uvwk(1,iel)
     xdv = vel(2,iel) - uvwk(2,iel)
     xdw = vel(3,iel) - uvwk(3,iel)
-    xnrmu = xnrmu +(xdu**2 + xdv**2 + xdw**2)     &
-                                * volume(iel)
+    xnrtmp = xnrtmp +(xdu**2 + xdv**2 + xdw**2) * volume(iel)
   enddo
+  xnrmu = xnrtmp
   ! --->    TRAITEMENT DU PARALLELISME
 
   if (irangp.ge.0) call parsom (xnrmu)
@@ -1281,7 +1372,7 @@ if (ippmod(icompf).lt.0) then
 endif
 
 !===============================================================================
-! 10. Printing
+! 13. Printing
 !===============================================================================
 
 if (iwarni(iu).ge.1) then
@@ -1398,7 +1489,11 @@ if (iwarni(iu).ge.1) then
 endif
 
 if (iturbo.eq.2) then
-  if (mod(ntcabs,ntlist).eq.0)  write(nfecra,3000) ellap1, ellap2
+  if (mod(ntcabs,ntlist).eq.0.and.iterns.eq.nterup) then
+     write(nfecra,3000) rs_ell(1), rs_ell(1) + rs_ell(2)
+     rs_ell(1) = 0.d0
+     rs_ell(2) = 0.d0
+  endif
 endif
 
 ! Free memory
@@ -1413,22 +1508,8 @@ if (allocated(wvisfi)) deallocate(wvisfi, wvisbi)
 if (allocated(secvif)) deallocate(secvif, secvib)
 if (iphydr.eq.2) deallocate(grdphd)
 
-! Interleaved values of vel and vela
-
-!$omp parallel do
-do iel = 1, ncelet
-  rtp (iel,iu) = vel (1,iel)
-  rtp (iel,iv) = vel (2,iel)
-  rtp (iel,iw) = vel (3,iel)
-  rtpa(iel,iu) = vela(1,iel)
-  rtpa(iel,iv) = vela(2,iel)
-  rtpa(iel,iw) = vela(3,iel)
-enddo
-
 ! Free memory
 !--------------
-deallocate(vel)
-deallocate(vela)
 deallocate(coefa_dp, coefb_dp)
 
 !--------
