@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -46,34 +46,6 @@ module post
 
     !---------------------------------------------------------------------------
 
-    !> \brief Initialize post-processing of moments
-
-    !> \param[in]   cumumative_time   pointer to cumulative time array
-
-    subroutine cs_post_init_moments(cumulative_time)     &
-      bind(C, name='cs_post_init_moments')
-      use, intrinsic :: iso_c_binding
-      implicit none
-      real(c_double), dimension(*), intent(in) :: cumulative_time
-    end subroutine cs_post_init_moments
-
-    !---------------------------------------------------------------------------
-
-    !> \brief Output post-processing meshes using associated writers.
-
-    !> \param[in]  nt_cur_abs  current time step number
-    !> \param[in]  t_cur_abs   current physical time
-
-    subroutine cs_post_write_meshes(nt_cur_abs, t_cur_abs)  &
-      bind(C, name='cs_post_write_meshes')
-      use, intrinsic :: iso_c_binding
-      implicit none
-      integer(c_int), value :: nt_cur_abs
-      real(c_double), value :: t_cur_abs
-    end subroutine cs_post_write_meshes
-
-    !---------------------------------------------------------------------------
-
     !> \brief Update "active" or "inactive" flag of writers based on the
     !>        time step.
 
