@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -109,7 +109,6 @@ subroutine predvv &
 use paramx
 use dimens, only: ndimfb
 use numvar
-use pointe, only: forbr, porosi
 use entsor
 use cstphy
 use cstnum
@@ -126,9 +125,12 @@ use ihmpre, only: iihmpr
 use mesh
 use turbomachinery
 use cs_f_interfaces
+use cs_c_bindings
 use cfpoin
 use field
 use field_operator
+use pointe, only: gamcav
+use cavitation
 
 !===============================================================================
 
@@ -143,7 +145,7 @@ integer          ncepdp , ncesmp
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtpa(ncelet,*)
+double precision dt(ncelet), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision flumas(nfac), flumab(nfabor)
 double precision tslagr(ncelet,*)
@@ -170,8 +172,8 @@ double precision vela  (3  ,ncelet)
 
 ! Local variables
 
-integer          iel   , ielpdc, ifac  , ivar  , isou  , itypfl
-integer          iccocg, inc   , iprev , init  , ii    , isqrt
+integer          f_id  , iel   , ielpdc, ifac  , isou  , itypfl
+integer          iccocg, inc   , iprev , init  , ii    , jj    , isqrt
 integer          ireslp, nswrgp, imligp, iwarnp, ipp
 integer          iswdyp, idftnp
 integer          ipcvis, ipcvst
@@ -194,13 +196,14 @@ double precision cpdc11, cpdc22, cpdc33, cpdc12, cpdc13, cpdc23
 double precision d2s3  , thetap, thetp1, thets , dtsrom
 double precision diipbx, diipby, diipbz
 double precision cx    , cy    , cz
+double precision ccorio
 double precision dvol
 
 double precision rvoid(1)
 
 ! Working arrays
 double precision, allocatable, dimension(:,:) :: eswork
-double precision, allocatable, dimension(:,:) :: grad
+double precision, allocatable, dimension(:,:) :: grad, gradni
 double precision, dimension(:,:), allocatable :: smbr
 double precision, dimension(:,:,:), allocatable :: fimp
 double precision, dimension(:,:), allocatable :: gavinj
@@ -208,9 +211,18 @@ double precision, dimension(:,:), allocatable :: tsexp
 double precision, dimension(:,:,:), allocatable :: tsimp
 double precision, allocatable, dimension(:,:) :: viscce
 double precision, dimension(:,:), allocatable :: vect
+double precision, dimension(:), allocatable :: xinvro
 double precision, dimension(:), pointer :: brom, crom, croma, pcrom
 double precision, dimension(:), pointer :: coefa_k, coefb_k
 double precision, dimension(:), pointer :: coefa_p, coefb_p
+double precision, dimension(:), pointer :: porosi
+double precision, dimension(:,:), allocatable :: rij
+double precision, dimension(:), pointer :: coef1, coef2, coef3, coef4, coef5, coef6
+double precision, dimension(:,:), allocatable :: coefat
+double precision, dimension(:,:,:), allocatable :: coefbt
+double precision, dimension(:,:), allocatable :: tflmas, tflmab
+double precision, dimension(:,:), allocatable :: divt
+double precision, dimension(:,:), pointer :: forbr
 
 !===============================================================================
 
@@ -239,6 +251,13 @@ if (iroext.gt.0.or.idilat.gt.1) then
   call field_get_val_prev_s(icrom, croma)
 endif
 
+! With porosity
+if (iporos.ge.1) then
+  call field_get_val_s(ipori, porosi)
+endif
+
+if (ineedf.eq.1 .and. iterns.eq.1) call field_get_val_v(iforbr, forbr)
+
 ipcvis = ipproc(iviscl)
 ipcvst = ipproc(ivisct)
 ! Theta relatif aux termes sources explicites
@@ -249,6 +268,17 @@ else
   iptsna = 0
 endif
 
+! Coefficient of the "Coriolis-type" term
+if (icorio.eq.1) then
+  ! Relative velocity formulation
+  ccorio = 2.d0
+elseif (iturbo.eq.1) then
+  ! Mixed relative/absolute velocity formulation
+  ccorio = 1.d0
+else
+  ccorio = 0.d0
+endif
+
 !===============================================================================
 ! 2. Potential forces (pressure gradient and gravity)
 !===============================================================================
@@ -295,26 +325,15 @@ if (iappel.eq.1.and.iphydr.eq.1) then
     enddo
   endif
 !     Ajout eventuel de la force de Coriolis
-  if (icorio.eq.1) then
-    ! "True" Coriolis term if one solves the relative velocity
-    do iel = 1, ncel
-      cx = omegay*vela(3,iel) - omegaz*vela(2,iel)
-      cy = omegaz*vela(1,iel) - omegax*vela(3,iel)
-      cz = omegax*vela(2,iel) - omegay*vela(1,iel)
-      dfrcxt(1 ,iel) = dfrcxt(1 ,iel) - 2.d0*crom(iel)*cx
-      dfrcxt(2 ,iel) = dfrcxt(2 ,iel) - 2.d0*crom(iel)*cy
-      dfrcxt(3 ,iel) = dfrcxt(3 ,iel) - 2.d0*crom(iel)*cz
-    enddo
-  elseif (iturbo.eq.1) then
-    ! "Coriolis-type" term if one solves the absolute velocity
+  if (icorio.eq.1 .or. iturbo.eq.1) then
     do iel = 1, ncel
       if (irotce(iel).ne.0) then
         cx = rotax(2)*vela(3,iel) - rotax(3)*vela(2,iel)
         cy = rotax(3)*vela(1,iel) - rotax(1)*vela(3,iel)
         cz = rotax(1)*vela(2,iel) - rotax(2)*vela(1,iel)
-        dfrcxt(iel,1) = dfrcxt(iel,1) - crom(iel)*cx
-        dfrcxt(iel,2) = dfrcxt(iel,2) - crom(iel)*cy
-        dfrcxt(iel,3) = dfrcxt(iel,3) - crom(iel)*cz
+        dfrcxt(iel,1) = dfrcxt(iel,1) - ccorio*crom(iel)*cx
+        dfrcxt(iel,2) = dfrcxt(iel,2) - ccorio*crom(iel)*cy
+        dfrcxt(iel,3) = dfrcxt(iel,3) - ccorio*crom(iel)*cz
       endif
     enddo
   endif
@@ -334,12 +353,6 @@ allocate(grad(3,ncelet))
 
 iccocg = 1
 inc    = 1
-nswrgp = nswrgr(ipr)
-imligp = imligr(ipr)
-iwarnp = iwarni(ipr)
-epsrgp = epsrgr(ipr)
-climgp = climgr(ipr)
-extrap = extrag(ipr)
 
 ! For compressible flows, the new Pressure field is required
 if (ippmod(icompf).ge.0) then
@@ -350,10 +363,51 @@ else
   iprev = 1
 endif
 
-call field_gradient_potential(ivarfl(ipr), iprev, imrgra, inc,    &
-                              iccocg, nswrgp, iphydr, iwarnp,     &
-                              imligp, epsrgp , extrap, climgp,    &
-                              frcxt, grad)
+if (icavit.lt.0) then
+  call field_gradient_potential(ivarfl(ipr), iprev, imrgra, inc,    &
+                                iccocg, iphydr,                     &
+                                frcxt, grad)
+
+else
+
+  ! Cavitating flows: consitency of the gradient with the diffusive flux scheme
+  ! of the correction step
+
+  call field_get_coefa_s (ivarfl(ipr), coefa_p)
+  call field_get_coefb_s (ivarfl(ipr), coefb_p)
+
+  allocate(gradni(ncelet,3))
+  allocate(xinvro(ncelet))
+
+  do iel = 1, ncel
+    xinvro(iel) = 1.d0/crom(iel)
+  enddo
+
+  iccocg = 1
+  inc    = 1
+  nswrgp = nswrgr(ipr)
+  imligp = imligr(ipr)
+  iwarnp = iwarni(ipr)
+  epsrgp = epsrgr(ipr)
+  climgp = climgr(ipr)
+  extrap = extrag(ipr)
+
+  call grdpre (ipr, imrgra, inc, iccocg, nswrgp, imligp,  &
+               iwarnp, epsrgp, climgp, extrap,            &
+               rtpa(1,ipr), xinvro, coefa_p, coefb_p,     &
+               gradni )
+
+  do iel = 1, ncelet
+    do isou = 1, 3
+      grad(isou,iel) = gradni(iel,isou)
+    enddo
+  enddo
+
+  deallocate(gradni)
+  deallocate(xinvro)
+
+endif
+
 
 !    Calcul des efforts aux parois (partie 2/5), si demande
 !    La pression a la face est calculee comme dans gradrc/gradmc
@@ -423,6 +477,9 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
 !     Calcul de rho dt/rho*grad P.n aux faces
 !       Pour gagner du temps, on ne reconstruit pas.
   itypfl = 1
+  ! Cavitation algorithm: the pressure step corresponds to the
+  ! correction of the volumetric flux, not the mass flux
+  if (icavit.ge.0)  itypfl = 0
   init   = 1
   inc    = 0
   iflmb0 = 1
@@ -434,19 +491,18 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
 
   call inimav                                                     &
   !==========
- ( iu     , itypfl ,                                              &
+ ( ivarfl(iu)      , itypfl ,                                     &
    iflmb0 , init   , inc    , imrgra , nswrp  , imligp ,          &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp ,                                              &
-   crom, brom   ,                                                 &
+   crom   , brom   ,                                              &
    trav   ,                                                       &
    coefav , coefbv ,                                              &
    viscf  , viscb  )
 
 !     Calcul de div(rho dt/rho*grad P)
   init = 1
-  call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                &
-                                ifacel,ifabor,viscf,viscb,xnormp)
+  call divmas(init,viscf,viscb,xnormp)
 
 !     Ajout de -Gamma
   if (ncesmp.gt.0) then
@@ -464,6 +520,13 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
 
   endif
 
+  ! Cavitation source term
+  if (icavit.gt.0) then
+    do iel = 1, ncel
+      xnormp(iel) = xnormp(iel) -volume(iel)*gamcav(iel)*(1.d0/rov - 1.d0/rol)
+    enddo
+  endif
+
 !     On conserve XNORMP, on complete avec u* a la fin et
 !       on le transfere a resopv
 
@@ -493,9 +556,16 @@ if (iappel.eq.1) then
     elseif (iphydr.eq.2) then
       do iel = 1, ncel
         rom = crom(iel)
-        trav(1,iel) = (rom*gx - grdphd(iel,1)) * volume(iel)
-        trav(2,iel) = (rom*gy - grdphd(iel,2)) * volume(iel)
-        trav(3,iel) = (rom*gz - grdphd(iel,3)) * volume(iel)
+        trav(1,iel) = (rom*gx - grdphd(iel,1) - grad(1,iel)) * volume(iel)
+        trav(2,iel) = (rom*gy - grdphd(iel,2) - grad(2,iel)) * volume(iel)
+        trav(3,iel) = (rom*gz - grdphd(iel,3) - grad(3,iel)) * volume(iel)
+      enddo
+    elseif (ippmod(icompf).ge.0) then
+      do iel = 1, ncel
+        rom = crom(iel)
+        trav(1,iel) = (rom*gx - grad(1,iel)) * volume(iel)
+        trav(2,iel) = (rom*gy - grad(2,iel)) * volume(iel)
+        trav(3,iel) = (rom*gz - grad(3,iel)) * volume(iel)
       enddo
     else
       do iel = 1, ncel
@@ -516,9 +586,16 @@ if (iappel.eq.1) then
     elseif (iphydr.eq.2) then
       do iel = 1, ncel
         rom = crom(iel)
-        trav(1,iel) = (rom*gx - grdphd(iel,1)) * volume(iel) * porosi(iel)
-        trav(2,iel) = (rom*gy - grdphd(iel,2)) * volume(iel) * porosi(iel)
-        trav(3,iel) = (rom*gz - grdphd(iel,3)) * volume(iel) * porosi(iel)
+        trav(1,iel) = (rom*gx - grdphd(iel,1) - grad(1,iel)) * volume(iel) * porosi(iel)
+        trav(2,iel) = (rom*gy - grdphd(iel,2) - grad(2,iel)) * volume(iel) * porosi(iel)
+        trav(3,iel) = (rom*gz - grdphd(iel,3) - grad(3,iel)) * volume(iel) * porosi(iel)
+      enddo
+    elseif (ippmod(icompf).ge.0) then
+      do iel = 1, ncel
+        rom = crom(iel)
+        trav(1,iel) = (rom*gx - grad(1,iel)) * volume(iel) * porosi(iel)
+        trav(2,iel) = (rom*gy - grad(2,iel)) * volume(iel) * porosi(iel)
+        trav(3,iel) = (rom*gz - grad(3,iel)) * volume(iel) * porosi(iel)
       enddo
     else
       do iel = 1, ncel
@@ -544,9 +621,9 @@ elseif(iappel.eq.2) then
     elseif (iphydr.eq.2) then
       do iel = 1, ncel
         rom = crom(iel)
-        trav(1,iel) = trav(1,iel) + (rom*gx - grdphd(iel,1))*volume(iel)
-        trav(2,iel) = trav(2,iel) + (rom*gy - grdphd(iel,2))*volume(iel)
-        trav(3,iel) = trav(3,iel) + (rom*gz - grdphd(iel,3))*volume(iel)
+        trav(1,iel) = trav(1,iel) + (rom*gx - grdphd(iel,1) - grad(1,iel))*volume(iel)
+        trav(2,iel) = trav(2,iel) + (rom*gy - grdphd(iel,2) - grad(2,iel))*volume(iel)
+        trav(3,iel) = trav(3,iel) + (rom*gz - grdphd(iel,3) - grad(3,iel))*volume(iel)
       enddo
     else
       do iel = 1, ncel
@@ -572,11 +649,11 @@ elseif(iappel.eq.2) then
       do iel = 1, ncel
         rom = crom(iel)
         trav(1,iel) = trav(1,iel)                                       &
-                    + (rom*gx - grdphd(iel,1))*volume(iel)*porosi(iel)
+                    + (rom*gx - grdphd(iel,1) - grad(1,iel))*volume(iel)*porosi(iel)
         trav(2,iel) = trav(2,iel)                                       &
-                    + (rom*gy - grdphd(iel,2))*volume(iel)*porosi(iel)
+                    + (rom*gy - grdphd(iel,2) - grad(2,iel))*volume(iel)*porosi(iel)
         trav(3,iel) = trav(3,iel)                                       &
-                    + (rom*gz - grdphd(iel,3))*volume(iel)*porosi(iel)
+                    + (rom*gz - grdphd(iel,3) - grad(3,iel))*volume(iel)*porosi(iel)
       enddo
     else
       do iel = 1, ncel
@@ -668,6 +745,10 @@ if (iappel.eq.1) then
   if (idilat.gt.1.or.ippmod(icompf).ge.0) then
     call field_get_val_prev_s(icrom, pcrom)
 
+  ! Cavitation
+  else if (icavit.ge.0) then
+    call field_get_val_s(icroaa, pcrom)
+
   ! Standard algo
   else
 
@@ -716,17 +797,10 @@ if(     (itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60) &
   iccocg = 1
   iprev  = 1
   inc    = 1
-  nswrgp = nswrgr(ik)
-  imligp = imligr(ik)
-  epsrgp = epsrgr(ik)
-  climgp = climgr(ik)
-  extrap = extrag(ik)
-
-  iwarnp = iwarni(ik)
 
   call field_gradient_scalar(ivarfl(ik), iprev, imrgra, inc,      &
-                             iccocg, nswrgp, iwarnp, imligp,      &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                              &
+                             grad)
 
   d2s3 = 2.d0/3.d0
 
@@ -905,49 +979,8 @@ endif
 !     (if iphydr=1 then this term is already taken into account)
 
 ! --->  Explicit part
-if (icorio.eq.1.and.iphydr.eq.0) then
 
-  ! At the first iteration on PISO, the explicit part is added
-  if (iterns.eq.1) then
-
-    ! If no iterations: directly in trav array
-    if (nterup.eq.1) then
-
-      do iel = 1, ncel
-        cx = omegay*vela(3,iel) - omegaz*vela(2,iel)
-        cy = omegaz*vela(1,iel) - omegax*vela(3,iel)
-        cz = omegax*vela(2,iel) - omegay*vela(1,iel)
-        romvom = -2.d0*crom(iel)*volume(iel)
-
-        ! With porosity
-        if (iporos.ge.1) romvom = romvom*porosi(iel)
-
-        trav(1,iel) = trav(1,iel) + romvom*cx
-        trav(2,iel) = trav(2,iel) + romvom*cy
-        trav(3,iel) = trav(3,iel) + romvom*cz
-      enddo
-
-    ! If iterations: in trava
-    else
-
-      do iel = 1, ncel
-        cx = omegay*vela(3,iel) - omegaz*vela(2,iel)
-        cy = omegaz*vela(1,iel) - omegax*vela(3,iel)
-        cz = omegax*vela(2,iel) - omegay*vela(1,iel)
-        romvom = -2.d0*crom(iel)*volume(iel)
-
-        ! With porosity
-        if (iporos.ge.1) romvom = romvom*porosi(iel)
-
-        trava(1,iel) = trava(1,iel) + romvom*cx
-        trava(2,iel) = trava(2,iel) + romvom*cy
-        trava(3,iel) = trava(3,iel) + romvom*cz
-      enddo
-
-    endif
-  endif
-
-elseif (iturbo.eq.1 .and. iphydr.eq.0) then
+if ((icorio.eq.1.or.iturbo.eq.1) .and. iphydr.eq.0) then
 
   ! A la premiere iter sur navsto, on ajoute la partie issue des
   ! termes explicites
@@ -963,7 +996,7 @@ elseif (iturbo.eq.1 .and. iphydr.eq.0) then
           cx = rotax(2)*vela(3,iel) - rotax(3)*vela(2,iel)
           cy = rotax(3)*vela(1,iel) - rotax(1)*vela(3,iel)
           cz = rotax(1)*vela(2,iel) - rotax(2)*vela(1,iel)
-          romvom = -crom(iel)*volume(iel)
+          romvom = -ccorio*crom(iel)*volume(iel)
 
           ! With porosity
           if (iporos.ge.1) romvom = romvom*porosi(iel)
@@ -982,7 +1015,7 @@ elseif (iturbo.eq.1 .and. iphydr.eq.0) then
           cx = rotax(2)*vela(3,iel) - rotax(3)*vela(2,iel)
           cy = rotax(3)*vela(1,iel) - rotax(1)*vela(3,iel)
           cz = rotax(1)*vela(2,iel) - rotax(2)*vela(1,iel)
-          romvom = -crom(iel)*volume(iel)
+          romvom = -ccorio*crom(iel)*volume(iel)
 
           ! With porosity
           if (iporos.ge.1) romvom = romvom*porosi(iel)
@@ -1001,69 +1034,158 @@ endif
 
 !  At the second call, fimp is not needed anymore
 if(iappel.eq.1) then
-  if (icorio.eq.1) then
+  if (icorio.eq.1 .or. iturbo.eq.1) then
     ! The theta-scheme for the Coriolis term is the same as the other terms
     thetap = thetav(iu)
 
     do iel = 1, ncel
-      romvom = crom(iel)*volume(iel)*thetap
+      if (irotce(iel).ne.0) then
+        romvom = crom(iel)*volume(iel)*thetap
 
-      ! With porosity
-      if (iporos.ge.1) romvom = romvom*porosi(iel)
+        ! With porosity
+        if (iporos.ge.1) romvom = romvom*porosi(iel)
 
-      fimp(1,2,iel) = fimp(1,2,iel) + 2.d0*romvom*omegaz
-      fimp(2,1,iel) = fimp(2,1,iel) - 2.d0*romvom*omegaz
-      fimp(1,3,iel) = fimp(1,3,iel) - 2.d0*romvom*omegay
-      fimp(3,1,iel) = fimp(3,1,iel) + 2.d0*romvom*omegay
-      fimp(2,3,iel) = fimp(2,3,iel) + 2.d0*romvom*omegax
-      fimp(3,2,iel) = fimp(3,2,iel) - 2.d0*romvom*omegax
+        fimp(1,2,iel) = fimp(1,2,iel) + ccorio*romvom*rotax(3)
+        fimp(2,1,iel) = fimp(2,1,iel) - ccorio*romvom*rotax(3)
+        fimp(1,3,iel) = fimp(1,3,iel) - ccorio*romvom*rotax(2)
+        fimp(3,1,iel) = fimp(3,1,iel) + ccorio*romvom*rotax(2)
+        fimp(2,3,iel) = fimp(2,3,iel) + ccorio*romvom*rotax(1)
+        fimp(3,2,iel) = fimp(3,2,iel) - ccorio*romvom*rotax(1)
+      endif
     enddo
 
   endif
 endif
 
 !-------------------------------------------------------------------------------
-! ---> - DIVERGENCE DE RIJ
+! ---> - Divergence of tensor Rij
 
 if(itytur.eq.3.and.iterns.eq.1) then
 
+  allocate(rij(6,ncelet))
+  do iel = 1, ncelet
+    rij(1,iel) = rtpa(iel,ir11)
+    rij(2,iel) = rtpa(iel,ir22)
+    rij(3,iel) = rtpa(iel,ir33)
+    rij(4,iel) = rtpa(iel,ir12)
+    rij(5,iel) = rtpa(iel,ir23)
+    rij(6,iel) = rtpa(iel,ir13)
+  enddo
+
+! --- Boundary conditions on the components of the tensor Rij
+
+  allocate(coefat(6,nfabor))
+  call field_get_coefad_s(ivarfl(ir11),coef1)
+  call field_get_coefad_s(ivarfl(ir22),coef2)
+  call field_get_coefad_s(ivarfl(ir33),coef3)
+  call field_get_coefad_s(ivarfl(ir12),coef4)
+  call field_get_coefad_s(ivarfl(ir23),coef5)
+  call field_get_coefad_s(ivarfl(ir13),coef6)
+  do ifac = 1, nfabor
+    coefat(1,ifac) = coef1(ifac)
+    coefat(2,ifac) = coef2(ifac)
+    coefat(3,ifac) = coef3(ifac)
+    coefat(4,ifac) = coef4(ifac)
+    coefat(5,ifac) = coef5(ifac)
+    coefat(6,ifac) = coef6(ifac)
+  enddo
+
+  allocate(coefbt(6,6,nfabor))
+  do ifac = 1, nfabor
+    do ii = 1, 6
+      do jj = 1, 6
+        coefbt(jj,ii,ifac) = 0.d0
+      enddo
+    enddo
+  enddo
+  call field_get_coefbd_s(ivarfl(ir11),coef1)
+  call field_get_coefbd_s(ivarfl(ir22),coef2)
+  call field_get_coefbd_s(ivarfl(ir33),coef3)
+  call field_get_coefbd_s(ivarfl(ir12),coef4)
+  call field_get_coefbd_s(ivarfl(ir23),coef5)
+  call field_get_coefbd_s(ivarfl(ir13),coef6)
+  do ifac = 1, nfabor
+    coefbt(1,1,ifac) = coef1(ifac)
+    coefbt(2,2,ifac) = coef2(ifac)
+    coefbt(3,3,ifac) = coef3(ifac)
+    coefbt(4,4,ifac) = coef4(ifac)
+    coefbt(5,5,ifac) = coef5(ifac)
+    coefbt(6,6,ifac) = coef6(ifac)
+  enddo
+
+  ! Flux computation options
+  f_id = -1
+  init = 1;
+  inc  = 1;
+  iflmb0 = 0;
+  nswrgp = nswrgr(ir11);
+  imligp = imligr(ir11);
+  iwarnp = iwarni(ir11);
+  epsrgp = epsrgr(ir11);
+  climgp = climgr(ir11);
+  itypfl = 1;
+
+  allocate(tflmas(3,nfac))
+  allocate(tflmab(3,nfabor))
+
+  call divrij                                                     &
+  !==========
+ ( f_id   , itypfl ,                                              &
+   iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
+   iwarnp ,                                                       &
+   epsrgp , climgp ,                                              &
+   crom   , brom   ,                                              &
+   rij    ,                                                       &
+   coefat , coefbt ,                                              &
+   tflmas , tflmab )
+
+  deallocate(rij)
+  deallocate(coefat, coefbt)
+
+  !     Calcul des efforts aux bords (partie 5/5), si necessaire
+
+  if (ineedf.eq.1) then
+    do ifac = 1, nfabor
+      do isou = 1, 3
+        forbr(isou,ifac) = forbr(isou,ifac) + tflmab(isou,ifac)
+      enddo
+    enddo
+  endif
+
+  allocate(divt(3,ncelet))
+  init = 1
+  call divmat(init,tflmas,tflmab,divt)
+
+  deallocate(tflmas, tflmab)
+
   do isou = 1, 3
 
-    if(isou.eq.1) ivar = iu
-    if(isou.eq.2) ivar = iv
-    if(isou.eq.3) ivar = iw
-
-    call divrij(isou, ivar, rtpa, viscf, viscb)
-    !==========
-
-    init = 1
-    call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,              &
-                ifacel,ifabor,viscf,viscb,w1)
-
 !     Si on extrapole les termes source en temps :
 !       PROPCE recoit les termes de divergence
     if(isno2t.gt.0) then
       do iel = 1, ncel
         propce(iel,iptsna+isou-1 ) =                              &
-        propce(iel,iptsna+isou-1 ) - w1(iel)
+        propce(iel,iptsna+isou-1 ) - divt(isou,iel)
       enddo
 !     Si on n'extrapole pas les termes source en temps :
     else
 !       si on n'itere pas sur navsto : TRAV
       if(nterup.eq.1) then
         do iel = 1, ncel
-          trav(isou,iel) = trav(isou,iel) - w1(iel)
+          trav(isou,iel) = trav(isou,iel) - divt(isou,iel)
         enddo
 !       si on itere sur navsto       : TRAVA
       else
         do iel = 1, ncel
-          trava(isou,iel) = trava(isou,iel) - w1(iel)
+          trava(isou,iel) = trava(isou,iel) - divt(isou,iel)
         enddo
       endif
     endif
 
   enddo
 
+  deallocate(divt)
+
 endif
 
 
@@ -1217,6 +1339,13 @@ ipp  = ipprtp(iu)
 ! at the first iter only.
 if (iterns.eq.1) then
 
+  if (ibdtso.gt.1.and.ntcabs.gt.2.and.(idtvar.eq.0.or.idtvar.eq.1)) then
+    ! TODO: remove test on ntcabs and implemente a "proper" condition for
+    ! initialization.
+    f_id = ivarfl(iu)
+    call cs_backward_differentiation_in_time(f_id, tsexp, tsimp)
+  endif
+
   if (iihmpr.eq.1) then
     call uitsnv (vel, tsexp, tsimp)
   endif
@@ -1226,7 +1355,7 @@ if (iterns.eq.1) then
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    iu   ,                                                         &
    icepdc , icetsm , itypsm ,                                     &
-   dt     , rtpa   , propce ,                                     &
+   dt     ,                                                       &
    ckupdc , smacel , tsexp  , tsimp  )
 
 
@@ -1752,6 +1881,9 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
 
   ! To save time, no space reconstruction
   itypfl = 1
+  ! Cavitation algorithm: the pressure step corresponds to the
+  ! correction of the volumetric flux, not the mass flux
+  if (icavit.ge.0)  itypfl = 0
   init   = 1
   inc    = 1
   iflmb0 = 1
@@ -1763,18 +1895,17 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
 
   call inimav &
   !==========
- ( iu     , itypfl ,                                              &
+ ( ivarfl(iu)      , itypfl ,                                     &
    iflmb0 , init   , inc    , imrgra , nswrp  , imligp ,          &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp ,                                              &
-   crom, brom ,                                                   &
+   crom   , brom   ,                                              &
    vel    ,                                                       &
    coefav , coefbv ,                                              &
    viscf  , viscb  )
 
   init = 0
-  call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                &
-                                ifacel,ifabor,viscf,viscb,xnormp)
+  call divmas(init,viscf,viscb,xnormp)
 
   ! Compute the norm rnormp used in resopv
   isqrt = 1
