@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -108,7 +108,7 @@ use entsor
 use cstphy
 use cstnum
 use optcal
-use pointe, only: itypfb, b_head_loss
+use pointe, only: itypfb, b_head_loss, gamcav, dgdpca
 use albase
 use parall
 use period
@@ -119,6 +119,7 @@ use cplsat
 use mesh
 use field
 use field_operator
+use cavitation
 use cs_f_interfaces
 
 !===============================================================================
@@ -133,11 +134,13 @@ integer          ncesmp
 integer          icetsm(ncesmp)
 integer          isostd(nfabor+1)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
+double precision, dimension (1:ncelet), target :: dt
 double precision propce(ncelet,*)
 double precision smacel(ncesmp,nvar)
 double precision frcxt(3,ncelet), dfrcxt(3,ncelet)
-double precision tpucou(6, ncelet), trav(3,ncelet)
+double precision, dimension (1:6,1:ncelet), target :: tpucou
+double precision trav(3,ncelet)
 double precision viscf(nfac), viscb(ndimfb)
 double precision drtp(ncelet)
 double precision tslagr(ncelet,*)
@@ -158,7 +161,7 @@ integer          ireslp, nswmpr
 integer          isweep, niterf, icycle
 integer          iflmb0, ifcsor
 integer          nswrgp, imligp, iwarnp
-integer          ipcrom, iflmas, iflmab
+integer          iflmas, iflmab
 integer          ipp
 integer          idiffp, iconvp, ndircp
 integer          nitmap, imgrp , ncymap, nitmgp
@@ -171,8 +174,9 @@ integer          imucpp, idftnp, iswdyp
 integer          iescap, ircflp, ischcp, isstpp, ivar, ncymxp, nitmfp
 integer          nswrsp
 integer          insqrt
+integer          imvisp
 
-integer          icvflb
+integer          icvflb, f_id0
 integer          ivoid(1)
 
 double precision residu, phydr0
@@ -188,8 +192,7 @@ double precision cfl, kpdc, rho, pimp, bpmasf
 
 double precision rvoid(1)
 
-double precision, allocatable, dimension(:) :: dam
-double precision, allocatable, dimension(:,:) :: xam
+double precision, allocatable, dimension(:) :: dam, xam
 double precision, allocatable, dimension(:) :: res, divu, presa
 double precision, dimension(:,:), allocatable :: gradp
 double precision, allocatable, dimension(:) :: coefaf_dp, coefbf_dp
@@ -206,6 +209,12 @@ double precision, allocatable, dimension(:,:) :: frchy, dfrchy
 double precision, dimension(:), pointer :: coefa_p, coefb_p
 double precision, dimension(:), pointer :: coefaf_p, coefbf_p
 double precision, allocatable, dimension(:) :: iflux, bflux
+double precision, allocatable, dimension(:) :: xunsro
+double precision, allocatable, dimension(:), target :: xdtsro
+double precision, allocatable, dimension(:,:), target :: tpusro
+double precision, dimension(:), pointer :: viscap
+double precision, dimension(:,:), pointer :: vitenp
+double precision, allocatable, dimension(:,:) :: gradni
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer :: brom, crom, croma
 
@@ -219,7 +228,7 @@ double precision, dimension(:), pointer :: brom, crom, croma
 rnorm2 = 0.d0
 
 ! Allocate temporary arrays
-allocate(dam(ncelet), xam(nfac,2))
+allocate(dam(ncelet), xam(nfac))
 allocate(res(ncelet), presa(ncelet), divu(ncelet))
 allocate(rhs(ncelet), rovsdt(ncelet))
 allocate(iflux(nfac), bflux(ndimfb))
@@ -231,11 +240,17 @@ if (icalhy.eq.1) allocate(frchy(ndim,ncelet), dfrchy(ndim,ncelet))
 ! Diffusive flux Boundary conditions for delta P
 allocate(coefaf_dp(ndimfb), coefbf_dp(ndimfb))
 
+! Associate pointers to pressure diffusion coefficient
+viscap => dt(:)
+if (idften(ipr).eq.6)  vitenp => tpucou(:,:)
+
 ! --- Writing
 call field_get_name(ivarfl(ipr), chaine)
 lchain = 16
 ipp    = ipprtp(ipr)
 
+f_id0 = -1
+
 ! --- Boundary conditions
 
 call field_get_coefa_s(ivarfl(ipr), coefa_p)
@@ -279,6 +294,44 @@ endif
 
 isqrt = 1
 
+! Initialization dedicated to cavitation module
+if (icavit.ge.0) then
+
+  ! The pressure correction is done through the volumetric flux (that is
+  ! the convective flux of the void fraction), not the mass flux
+  call field_get_key_int(ivarfl(ivoidf), kimasf, iflmas)
+  call field_get_key_int(ivarfl(ivoidf), kbmasf, iflmab)
+  call field_get_val_s(iflmas, imasfl)
+  call field_get_val_s(iflmab, bmasfl)
+
+  ! Allocate and initialize specific arrays
+  allocate(xunsro(ncelet))
+  do iel = 1, ncelet
+    xunsro(iel) = 1.d0/crom(iel)
+  enddo
+  if (idften(ipr).eq.1) then
+    allocate(xdtsro(ncelet))
+    do iel = 1, ncelet
+      xdtsro(iel) = dt(iel)/crom(iel)
+    enddo
+  elseif (idften(ipr).eq.6) then
+    allocate(tpusro(6,ncelet))
+    do iel = 1, ncelet
+      tpusro(1,iel) = tpucou(1,iel)*xunsro(iel)
+      tpusro(2,iel) = tpucou(2,iel)*xunsro(iel)
+      tpusro(3,iel) = tpucou(3,iel)*xunsro(iel)
+      tpusro(4,iel) = tpucou(4,iel)*xunsro(iel)
+      tpusro(5,iel) = tpucou(5,iel)*xunsro(iel)
+      tpusro(6,iel) = tpucou(6,iel)*xunsro(iel)
+    enddo
+  endif
+
+  ! Associate pointers to pressure diffusion coefficient
+  viscap => xdtsro(:)
+  if (idften(ipr).eq.6)  vitenp => tpusro(:,:)
+
+endif
+
 !===============================================================================
 ! 2. Norm residual
 !===============================================================================
@@ -333,19 +386,19 @@ if(irnpnw.ne.1) then
   inc    = 1
   iflmb0 = 1
   if (iale.eq.1.or.imobil.eq.1) iflmb0 = 0
-  nswrgp  = 1
+  nswrgp = 1
   imligp = imligr(iu )
   iwarnp = iwarni(ipr)
   epsrgp = epsrgr(iu )
   climgp = climgr(iu )
   itypfl = 1
-  if (idilat.eq.4) itypfl = 0
+  if (idilat.eq.4.or.icavit.ge.0) itypfl = 0
 
   call inimav &
   !==========
- ( iu     , itypfl ,                                              &
+ ( f_id0  , itypfl ,                                              &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp ,                                              &
    crom, brom   ,                                                 &
    trav   ,                                                       &
@@ -353,8 +406,7 @@ if(irnpnw.ne.1) then
    iflux  , bflux  )
 
   init = 1
-  call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                &
-       ifacel,ifabor,iflux,bflux,res)
+  call divmas(init, iflux, bflux, res)
 
   ! --- Weakly compressible algorithm: semi analytic scheme
   if (idilat.eq.4) then
@@ -370,6 +422,13 @@ if(irnpnw.ne.1) then
     enddo
   endif
 
+  ! Cavitation source term
+  if (icavit.gt.0) then
+    do iel = 1, ncel
+      res(iel) = res(iel) -volume(iel)*gamcav(iel)*(1.d0/rov - 1.d0/rol)
+    enddo
+  endif
+
 ! ---> LAGRANGIEN : COUPLAGE RETOUR
 
   if (iilagr.eq.2 .and. ltsmas.eq.1) then
@@ -693,11 +752,18 @@ if (idiff(ipr).ge.1) then
 
   ! Scalar diffusivity
   if (idften(ipr).eq.1) then
+
+    if (icavit.ge.0) then
+      imvisp = imvisf
+    else
+      imvisp = 1  ! Cavitation: continuity of the flux across internal faces
+    endif
+
     call viscfa &
     !==========
- ( imvisf ,                                                       &
-   dt     ,                                                       &
-   viscf  , viscb  )
+   ( imvisp ,            &
+     viscap ,            &
+     viscf  , viscb  )
 
   ! Tensor diffusivity
   else if (idften(ipr).eq.6) then
@@ -710,7 +776,7 @@ if (idiff(ipr).ge.1) then
 
     call vitens &
     !==========
-   ( tpucou , iwarnp ,             &
+   ( vitenp , iwarnp ,             &
      weighf , weighb ,             &
      viscf  , viscb  )
 
@@ -733,11 +799,8 @@ imucpp = 0
 
 call matrix &
 !==========
- ( ncelet , ncel   , nfac   , nfabor ,                            &
-   iconvp , idiffp , ndircp ,                                     &
-   isym   , nfecra ,                                              &
+ ( iconvp , idiffp , ndircp , isym   ,                            &
    thetap , imucpp ,                                              &
-   ifacel , ifabor ,                                              &
    coefb_dp , coefbf_dp     , rovsdt ,                            &
    imasfl , bmasfl , viscf  , viscb  ,                            &
    rvoid  , dam    , xam    )
@@ -749,6 +812,13 @@ if (idilat.eq.3) then
   enddo
 endif
 
+! Implicit part of the cavitation source
+if (icavit.gt.0.and.itscvi.eq.1) then
+  do iel = 1, ncel
+    dam(iel) = dam(iel) - volume(iel)*dgdpca(iel)*(1.d0/rov - 1.d0/rol)
+  enddo
+endif
+
 ! Free memory
 deallocate(iflux, bflux)
 
@@ -764,17 +834,35 @@ allocate(gradp(3,ncelet))
 iccocg = 1
 iprev  = 1
 inc    = 1
-nswrgp = nswrgr(ipr)
-imligp = imligr(ipr)
-iwarnp = iwarni(ipr)
-epsrgp = epsrgr(ipr)
-climgp = climgr(ipr)
-extrap = extrag(ipr)
 
-call field_gradient_potential(ivarfl(ipr), iprev, imrgra, inc,    &
-                              iccocg, nswrgp, iphydr, iwarnp,     &
-                              imligp, epsrgp , extrap, climgp,    &
-                              frcxt, gradp)
+if (icavit.lt.0) then
+  call field_gradient_potential(ivarfl(ipr), iprev, imrgra, inc,    &
+                                iccocg, iphydr,                     &
+                                frcxt, gradp)
+else
+  ! Cavitating flows: continuity of the diffusive flux across internal faces
+  allocate(gradni(ncelet,3))
+
+  nswrgp = nswrgr(ipr)
+  imligp = imligr(ipr)
+  iwarnp = iwarni(ipr)
+  epsrgp = epsrgr(ipr)
+  climgp = climgr(ipr)
+  extrap = extrag(ipr)
+
+  call grdpre (ipr, imrgra, inc, iccocg, nswrgp, imligp,  &
+               iwarnp, epsrgp, climgp, extrap,            &
+               rtp(:,ipr), xunsro, coefa_p , coefb_p,     &
+               gradni )
+
+  do iel = 1, ncelet
+    do isou = 1, 3
+      gradp(isou,iel) = gradni(iel,isou)
+    enddo
+  enddo
+
+  deallocate(gradni)
+endif
 
 do iel = 1, ncelet
   do isou = 1, 3
@@ -878,12 +966,13 @@ iwarnp = iwarni(ipr)
 epsrgp = epsrgr(iu )
 climgp = climgr(iu )
 itypfl = 1
+if (icavit.ge.0) itypfl = 0
 
 call inimav &
 !==========
- ( iu     , itypfl ,                                              &
+ ( f_id0  , itypfl ,                                              &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp ,                                              &
    crom, brom   ,                                                 &
    trav   ,                                                       &
@@ -908,7 +997,7 @@ if (iphydr.eq.1) then
   if (idften(ipr).eq.1) then
     call projts &
     !==========
- ( init   , nswrgp , nfecra ,                                     &
+ ( init   , nswrgp ,                                              &
    dfrcxt ,                                                       &
    coefbf_p ,                                                     &
    imasfl , bmasfl ,                                              &
@@ -921,7 +1010,6 @@ if (iphydr.eq.1) then
     call projtv &
     !==========
   ( init   , nswrgp , ircflp ,                                     &
-    nfecra ,                                                       &
     dfrcxt ,                                                       &
     coefbf_p ,                                                     &
     viscf  , viscb  ,                                              &
@@ -962,7 +1050,7 @@ if (arak.gt.0.d0) then
   !-------------------
   if (idften(ipr).eq.1) then
     do iel = 1, ncel
-      dt(iel) = arak*dt(iel)
+      viscap(iel) = arak*viscap(iel)
     enddo
 
     nswrgp = nswrgr(ipr )
@@ -975,13 +1063,13 @@ if (arak.gt.0.d0) then
     call itrmas &
     !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydr , &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp , extrap ,                                     &
    frcxt  ,                                                       &
    rtpa(1,ipr)  ,                                                 &
    coefa_p , coefb_p , coefaf_p , coefbf_p ,                      &
    viscf  , viscb  ,                                              &
-   dt     , dt     , dt     ,                                     &
+   viscap , viscap , viscap ,                                     &
    imasfl , bmasfl )
 
     ! Projection du terme source pour oter la partie hydrostat de la pression
@@ -997,25 +1085,28 @@ if (arak.gt.0.d0) then
 
       ! A 0 boundary coefficient coefbf_dp is passed to projts
       ! to cancel boundary terms
+      allocate(cofbfp(ndimfb))
       do ifac = 1,nfabor
-        coefbf_dp(ifac) = 0.d0
+        cofbfp(ifac) = 0.d0
       enddo
 
       call projts &
       !==========
- ( init   , nswrgp , nfecra ,                                     &
+ ( init   , nswrgp ,                                              &
    frcxt  ,                                                       &
-   coefbf_dp       ,                                              &
+   cofbfp ,                                                       &
    imasfl , bmasfl ,                                              &
    viscf  , viscb  ,                                              &
    dt     , dt     , dt     )
 
+      deallocate(cofbfp)
+
     endif
 
     ! --- Correction du pas de temps
     unsara = 1.d0/arak
     do iel = 1, ncel
-      dt(iel) = dt(iel)*unsara
+      viscap(iel) = viscap(iel)*unsara
     enddo
 
   ! Tensor diffusivity
@@ -1023,12 +1114,12 @@ if (arak.gt.0.d0) then
   else if (idften(ipr).eq.6) then
 
     do iel = 1, ncel
-      tpucou(1,iel) = arak*tpucou(1,iel)
-      tpucou(2,iel) = arak*tpucou(2,iel)
-      tpucou(3,iel) = arak*tpucou(3,iel)
-      tpucou(4,iel) = arak*tpucou(4,iel)
-      tpucou(5,iel) = arak*tpucou(5,iel)
-      tpucou(6,iel) = arak*tpucou(6,iel)
+      vitenp(1,iel) = arak*vitenp(1,iel)
+      vitenp(2,iel) = arak*vitenp(2,iel)
+      vitenp(3,iel) = arak*vitenp(3,iel)
+      vitenp(4,iel) = arak*vitenp(4,iel)
+      vitenp(5,iel) = arak*vitenp(5,iel)
+      vitenp(6,iel) = arak*vitenp(6,iel)
     enddo
 
     nswrgp = nswrgr(ipr)
@@ -1042,53 +1133,56 @@ if (arak.gt.0.d0) then
     call itrmav &
     !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp , nfecra ,                                     &
+   iphydr , iwarnp ,                                              &
    epsrgp , climgp , extrap ,                                     &
    frcxt  ,                                                       &
    rtpa(1,ipr)  ,                                                 &
    coefa_p , coefb_p , coefaf_p , coefbf_p ,                      &
    viscf  , viscb  ,                                              &
-   tpucou ,                                                       &
+   vitenp ,                                                       &
    weighf , weighb ,                                              &
    imasfl , bmasfl )
 
-   ! Projection du terme source pour oter la partie hydrostat de la pression
-   if (iphydr.eq.1) then
-     init   = 0
-     inc    = 0
-     nswrgp = nswrgr(ipr)
-     imligp = imligr(ipr)
-     iwarnp = iwarni(ipr)
-     epsrgp = epsrgr(ipr)
-     climgp = climgr(ipr)
+    ! Projection du terme source pour oter la partie hydrostat de la pression
+    if (iphydr.eq.1) then
+      init   = 0
+      inc    = 0
+      nswrgp = nswrgr(ipr)
+      imligp = imligr(ipr)
+      iwarnp = iwarni(ipr)
+      epsrgp = epsrgr(ipr)
+      climgp = climgr(ipr)
 
-     ! A 0 boundary coefficient coefbf_dp is passed to projtv
-     ! to cancel boundary terms
-     do ifac = 1, nfabor
-       coefbf_dp(ifac) = 0.d0
-     enddo
+      ! A 0 boundary coefficient coefbf_dp is passed to projtv
+      ! to cancel boundary terms
+      allocate(cofbfp(ndimfb))
+      do ifac = 1, nfabor
+        cofbfp(ifac) = 0.d0
+      enddo
 
-     call projtv &
-     !==========
-   ( init   , nswrgp , ircflp , nfecra ,                            &
+      call projtv &
+      !==========
+   ( init   , nswrgp , ircflp ,                                     &
      frcxt  ,                                                       &
-     coefbf_dp       ,                                              &
+     cofbfp ,                                                       &
      viscf  , viscb  ,                                              &
      tpucou ,                                                       &
      weighf ,                                                       &
      imasfl, bmasfl )
 
-   endif
+      deallocate(cofbfp)
+
+    endif
 
     ! --- Correction du pas de temps
     unsara = 1.d0/arak
     do iel = 1, ncel
-      tpucou(1,iel) = unsara*tpucou(1,iel)
-      tpucou(2,iel) = unsara*tpucou(2,iel)
-      tpucou(3,iel) = unsara*tpucou(3,iel)
-      tpucou(4,iel) = unsara*tpucou(4,iel)
-      tpucou(5,iel) = unsara*tpucou(5,iel)
-      tpucou(6,iel) = unsara*tpucou(6,iel)
+      vitenp(1,iel) = unsara*vitenp(1,iel)
+      vitenp(2,iel) = unsara*vitenp(2,iel)
+      vitenp(3,iel) = unsara*vitenp(3,iel)
+      vitenp(4,iel) = unsara*vitenp(4,iel)
+      vitenp(5,iel) = unsara*vitenp(5,iel)
+      vitenp(6,iel) = unsara*vitenp(6,iel)
     enddo
 
   endif
@@ -1105,12 +1199,21 @@ if (arak.gt.0.d0) then
   ! the non-zero value
   if (nbrcpl.gt.0) then
     if (idiff(ipr).ge.1) then
+
+      !Scalar diffusivity
       if (idften(ipr).eq.1) then
+
+        if (icavit.lt.0) then
+          imvisp = imvisf
+        else
+          imvisp = 1
+        endif
+
         call viscfa &
         !==========
-     ( imvisf ,                                                       &
-       dt     ,                                                       &
-       viscf  , viscb  )
+      ( imvisp ,            &
+        viscap ,            &
+        viscf  , viscb  )
 
       ! Tensor diffusivity
       else if (idften(ipr).eq.6) then
@@ -1119,7 +1222,7 @@ if (arak.gt.0.d0) then
 
         call vitens &
         !==========
-       ( tpucou , iwarnp ,             &
+       ( vitenp , iwarnp ,             &
          weighf , weighb ,             &
          viscf  , viscb  )
 
@@ -1181,11 +1284,7 @@ relaxp = relaxv(ipr)
 ! --- Initial divergence
 init = 1
 
-call divmas &
-!==========
- ( ncelet , ncel   , nfac  , nfabor , init   , nfecra ,          &
-   ifacel , ifabor ,                                             &
-   imasfl , bmasfl , divu )
+call divmas(init, imasfl , bmasfl , divu)
 
 ! --- Weakly compressible algorithm: semi analytic scheme
 !     1. The RHS contains rho div(u*) and not div(rho u*)
@@ -1211,20 +1310,16 @@ if (idilat.eq.4) then
 
   call inimav &
   !==========
- ( iu     , itypfl ,                                              &
+ ( ivarfl(iu)      , itypfl ,                                     &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp ,                                              &
    crom, brom   ,                                                 &
    vel    ,                                                       &
    coefav , coefbv ,                                              &
    velflx , velflb )
 
-  call divmas &
-  !==========
- ( ncelet , ncel   , nfac  , nfabor , init   , nfecra ,           &
-   ifacel , ifabor ,                                              &
-   velflx , velflb , res )
+  call divmas(init, velflx , velflb , res)
 
   do iel = 1, ncel
     divu(iel) = divu(iel) + res(iel)*crom(iel)
@@ -1250,9 +1345,9 @@ if (idilat.eq.4) then
 
   call inimav &
   !==========
- ( iu     , itypfl ,                                              &
+ ( ivarfl(iu)      , itypfl ,                                     &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp ,                                              &
    crom, brom   ,                                                 &
    vel    ,                                                       &
@@ -1270,8 +1365,7 @@ if (ncesmp.gt.0) then
 endif
 
 ! --- Source term associated to the mass aggregation
-if ((idilat.eq.2.or.idilat.eq.3).and. &
-    (ntcabs.gt.1.or.isuite.gt.0)) then
+if (idilat.eq.2.or.idilat.eq.3) then
   do iel = 1, ncel
     drom = crom(iel) - croma(iel)
     divu(iel) = divu(iel) + drom*volume(iel)/dt(iel)
@@ -1285,6 +1379,13 @@ if (iilagr.eq.2 .and. ltsmas.eq.1) then
   enddo
 endif
 
+! --- Cavitation source term
+if (icavit.gt.0) then
+  do iel = 1, ncel
+    divu(iel) = divu(iel) - volume(iel)*gamcav(iel)*(1.d0/rov - 1.d0/rol)
+  enddo
+endif
+
 ! --- Initial right hand side
 do iel = 1, ncel
   rhs(iel) = - divu(iel)
@@ -1341,14 +1442,14 @@ if (iswdyp.ge.1) then
     call itrgrp &
     !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydr , &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp , extrap ,                                     &
    dfrcxt ,                                                       &
    drtp   ,                                                       &
    coefa_dp  , coefb_dp  ,                                        &
    coefaf_dp , coefbf_dp ,                                        &
    viscf  , viscb  ,                                              &
-   dt     , dt     , dt     ,                                     &
+   viscap , viscap , viscap ,                                     &
    rhs0   )
 
   else if (idften(ipr).eq.6) then
@@ -1356,14 +1457,14 @@ if (iswdyp.ge.1) then
     call itrgrv &
     !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp , nfecra ,                                     &
+   iphydr , iwarnp ,                                              &
    epsrgp , climgp , extrap ,                                     &
    dfrcxt ,                                                       &
    drtp   ,                                                       &
    coefa_dp  , coefb_dp  ,                                        &
    coefaf_dp , coefbf_dp ,                                        &
    viscf  , viscb  ,                                              &
-   tpucou ,                                                       &
+   vitenp ,                                                       &
    weighf , weighb ,                                              &
    rhs0   )
 
@@ -1440,14 +1541,14 @@ do while (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp)
       call itrgrp &
       !==========
    ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydr , &
-     iwarnp , nfecra ,                                              &
+     iwarnp ,                                                       &
      epsrgp , climgp , extrap ,                                     &
      dfrcxt ,                                                       &
      drtp   ,                                                       &
      coefa_dp  , coefb_dp  ,                                        &
      coefaf_dp , coefbf_dp ,                                        &
      viscf  , viscb  ,                                              &
-     dt     , dt     , dt     ,                                     &
+     viscap , viscap , viscap ,                                     &
      adxk   )
 
     else if (idften(ipr).eq.6) then
@@ -1455,14 +1556,14 @@ do while (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp)
       call itrgrv &
       !==========
    ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-     iphydr , iwarnp , nfecra ,                                     &
+     iphydr , iwarnp ,                                              &
      epsrgp , climgp , extrap ,                                     &
      dfrcxt ,                                                       &
      drtp   ,                                                       &
      coefa_dp  , coefb_dp  ,                                        &
      coefaf_dp , coefbf_dp ,                                        &
      viscf  , viscb  ,                                              &
-     tpucou ,                                                       &
+     vitenp ,                                                       &
      weighf , weighb ,                                              &
      adxk   )
 
@@ -1573,14 +1674,14 @@ do while (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp)
     call itrgrp &
     !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydr , &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp , extrap ,                                     &
    dfrcxt ,                                                       &
    rtp(1,ipr)      ,                                              &
    coefa_dp  , coefb_dp  ,                                        &
    coefaf_dp , coefbf_dp ,                                        &
    viscf  , viscb  ,                                              &
-   dt     , dt     , dt     ,                                     &
+   viscap , viscap , viscap ,                                     &
    rhs    )
 
   else if (idften(ipr).eq.6) then
@@ -1588,14 +1689,14 @@ do while (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp)
     call itrgrv &
     !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp , nfecra ,                                     &
+   iphydr , iwarnp ,                                              &
    epsrgp , climgp , extrap ,                                     &
    dfrcxt ,                                                       &
    rtp(1,ipr)      ,                                              &
    coefa_dp  , coefb_dp  ,                                        &
    coefaf_dp , coefbf_dp ,                                        &
    viscf  , viscb  ,                                              &
-   tpucou ,                                                       &
+   vitenp ,                                                       &
    weighf , weighb ,                                              &
    rhs    )
 
@@ -1613,6 +1714,14 @@ do while (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp)
     enddo
   endif
 
+  ! Add the implicit part of the cavitation source
+  if (icavit.gt.0.and.itscvi.eq.1) then
+    do iel = 1, ncel
+      rhs(iel) = rhs(iel) + volume(iel)*rtp(iel,ipr) &
+           *dgdpca(iel)*(1.d0/rov - 1.d0/rol)
+    enddo
+  endif
+
   ! --- Convergence test
   call prodsc(ncel,isqrt,rhs,rhs,residu)
 
@@ -1688,17 +1797,18 @@ climgp = climgr(ipr)
 extrap = extrag(ipr)
 
 if (idften(ipr).eq.1) then
+
   call itrmas &
   !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydr , &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp , extrap ,                                     &
    dfrcxt ,                                                       &
    presa  ,                                                       &
    coefa_dp  , coefb_dp  ,                                        &
    coefaf_dp , coefbf_dp ,                                        &
    viscf  , viscb  ,                                              &
-   dt     , dt     , dt     ,                                     &
+   viscap , viscap , viscap ,                                     &
    imasfl , bmasfl )
 
   ! The last increment is not reconstructed to fullfill exactly the continuity
@@ -1710,14 +1820,14 @@ if (idften(ipr).eq.1) then
   call itrmas &
   !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydr , &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp , extrap ,                                     &
    dfrcxt ,                                                       &
    drtp   ,                                                       &
    coefa_dp  , coefb_dp  ,                                        &
    coefaf_dp , coefbf_dp ,                                        &
    viscf  , viscb  ,                                              &
-   dt     , dt     , dt     ,                                     &
+   viscap , viscap , viscap ,                                     &
    imasfl , bmasfl )
 
 else if (idften(ipr).eq.6) then
@@ -1725,14 +1835,14 @@ else if (idften(ipr).eq.6) then
   call itrmav &
   !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp , nfecra ,                                     &
+   iphydr , iwarnp ,                                              &
    epsrgp , climgp , extrap ,                                     &
    dfrcxt ,                                                       &
    presa  ,                                                       &
    coefa_dp  , coefb_dp  ,                                        &
    coefaf_dp , coefbf_dp ,                                        &
    viscf  , viscb  ,                                              &
-   tpucou ,                                                       &
+   vitenp ,                                                       &
    weighf , weighb ,                                              &
    imasfl , bmasfl )
 
@@ -1746,14 +1856,14 @@ else if (idften(ipr).eq.6) then
   call itrmav &
   !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp , nfecra ,                                     &
+   iphydr , iwarnp ,                                              &
    epsrgp , climgp , extrap ,                                     &
    dfrcxt ,                                                       &
    drtp   ,                                                       &
    coefa_dp  , coefb_dp  ,                                        &
    coefaf_dp , coefbf_dp ,                                        &
    viscf  , viscb  ,                                              &
-   tpucou ,                                                       &
+   vitenp ,                                                       &
    weighf , weighb ,                                              &
    imasfl , bmasfl )
 
@@ -1909,9 +2019,9 @@ if (idilat.eq.4) then
 
   call inimav &
   !==========
- ( ipcrom , itypfl ,                                              &
+ ( f_id0  , itypfl ,                                              &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp ,                                              &
    crom, brom   ,                                                 &
    trav   ,                                                       &
@@ -1956,7 +2066,7 @@ if (idilat.eq.4) then
   !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp , idftnp ,                            &
+   iwarnp , imucpp , idftnp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    rtp(1,ipr)      , rtp(1,ipr)      ,                            &
    coefa_dp , coefb_p       , coefaf_dp       , coefbf_p ,        &
@@ -2050,7 +2160,7 @@ if (idilat.eq.4) then
     call itrmas &
     !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydr , &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp , extrap ,                                     &
    dfrcxt ,                                                       &
    drtp   ,                                                       &
@@ -2068,7 +2178,7 @@ if (idilat.eq.4) then
     call itrmas &
     !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydr , &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp , extrap ,                                     &
    dfrcxt ,                                                       &
    dpvar  ,                                                       &
@@ -2082,7 +2192,7 @@ if (idilat.eq.4) then
     call itrmav &
     !==========
    ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-     iphydr , iwarnp , nfecra ,                                     &
+     iphydr , iwarnp ,                                              &
      epsrgp , climgp , extrap ,                                     &
      dfrcxt ,                                                       &
      drtp   ,                                                       &
@@ -2101,7 +2211,7 @@ if (idilat.eq.4) then
     call itrmav &
     !==========
    ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-     iphydr , iwarnp , nfecra ,                                     &
+     iphydr , iwarnp ,                                              &
      epsrgp , climgp , extrap ,                                     &
      dfrcxt ,                                                       &
      dpvar  ,                                                       &
@@ -2144,6 +2254,11 @@ deallocate(rhs, rovsdt)
 if (allocated(weighf)) deallocate(weighf, weighb)
 if (iswdyp.ge.1) deallocate(adxk, adxkm1, dpvarm1, rhs0)
 if (icalhy.eq.1) deallocate(frchy, dfrchy)
+if (icavit.ge.0) then
+  deallocate(xdtsro)
+  if (allocated(xunsro)) deallocate(xunsro)
+  if (allocated(tpusro)) deallocate(tpusro)
+endif
 
 !--------
 ! Formats
