@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -42,8 +42,6 @@
 !> \param[in,out] rtp           calculated variables at cell centers
 !>                              (at current and previous time steps)
 !> \param[in,out] propce        physical properties at cell centers
-!> \param[in]     coefa         boundary conditions
-!> \param[in]     coefb         boundary conditions
 !> \param[in]     frcxt         external force generating hydrostatic pressure
 !> \param[in]     prhyd         predicted hydrostatic pressure
 !______________________________________________________________________________
@@ -53,7 +51,7 @@ subroutine tridim &
    nvar   , nscal  ,                                              &
    isostd ,                                                       &
    dt     , rtpa   , rtp    , propce ,                            &
-   coefa  , coefb  , frcxt  , prhyd  )
+   frcxt  , prhyd  )
 
 !===============================================================================
 ! Module files
@@ -106,14 +104,13 @@ integer          isostd(nfabor+1)
 
 double precision, pointer, dimension(:)   :: dt
 double precision, pointer, dimension(:,:) :: rtp, rtpa, propce
-double precision , dimension(nfabor,*) :: coefa, coefb
 double precision, pointer, dimension(:,:) :: frcxt
 double precision, pointer, dimension(:) :: prhyd
 
 ! Local variables
 
 integer          iel   , ifac  , inod  , ivar  , iscal , iappel
-integer          ncp   , ncv   , iok
+integer          ncp   , ncv   , iok   , ifld
 integer          iiptot
 integer          nbccou
 integer          ntrela
@@ -149,11 +146,12 @@ double precision, allocatable, dimension(:,:,:) :: rcodcl
 double precision, allocatable, dimension(:) :: hbord, theipb
 double precision, allocatable, dimension(:) :: visvdr
 double precision, allocatable, dimension(:) :: prdv2f
-double precision, dimension(:), pointer :: brom, crom, crom_prev
+double precision, dimension(:), pointer :: brom, crom, crom_prev, crom_prev2
 
 double precision, pointer, dimension(:,:) :: uvwk
 double precision, pointer, dimension(:,:) :: trava
 double precision, pointer, dimension(:,:,:) :: ximpav
+double precision, dimension(:,:), pointer :: vel
 
 !===============================================================================
 ! Interfaces
@@ -167,7 +165,7 @@ interface
   ( nvar   , nscal  , iterns , icvrge , itrale ,                   &
     isostd ,                                                       &
     dt     , rtp    , rtpa   , propce ,                            &
-    coefa  , coefb  , frcxt  , prhyd  ,                            &
+    frcxt  , prhyd  ,                                              &
     trava  , ximpa  , uvwk   )
 
     use dimens, only: ndimfb
@@ -181,7 +179,6 @@ interface
 
     double precision, pointer, dimension(:)   :: dt
     double precision, pointer, dimension(:,:) :: rtp, rtpa, propce
-    double precision, dimension(nfabor,*) :: coefa, coefb
     double precision, pointer, dimension(:,:) :: frcxt
     double precision, pointer, dimension(:) :: prhyd
     double precision, pointer, dimension(:,:) :: trava, uvwk
@@ -195,6 +192,9 @@ end interface
 
 !===============================================================================
 
+! Map field arrays
+call field_get_val_v(ivarfl(iu), vel)
+
 !===============================================================================
 ! 1.  INITIALISATION
 !===============================================================================
@@ -238,12 +238,6 @@ if(ipass.eq.1.and.ineedy.eq.1.and.abs(icdpar).eq.1.and.           &
   enddo
 endif
 
-!    Initialisation de pthera (pther est deja initialise ou lu dans
-!    un fichier suite pour l'algorithme a masse volumique variable
-
-if (idilat.eq.3) then
-  pthera = pther
-endif
 
 !===============================================================================
 ! 2.  AU DEBUT DU CALCUL ON REINITIALISE LA PRESSION
@@ -315,7 +309,9 @@ endif
 
 if (irangp.ge.0 .or. iperio.eq.1) then
 
-  do ivar = 1, nvar
+  call synvin(vel)
+
+  do ivar = nflown, nvar
     call synsce (rtp(1,ivar))
     !==========
   enddo
@@ -328,7 +324,7 @@ if (iperio.eq.1) then
 
   !  -- Vitesse
 
-  call perrve (rtp(1,iu), rtp(1,iv), rtp(1,iw))
+  call pervec (vel)
   !==========
 
   !  -- Reynolds stress tensor
@@ -395,14 +391,25 @@ endif
 !       pour eviter une nouvelle communication sur RTPA et les autres
 !       tableaux du pas de temps precedent
 
+ifld = -1
 do ivar = 1, nvar
-  do iel = 1, ncelet
-    rtpa (iel,ivar) = rtp (iel,ivar)
-  enddo
+  if (ivarfl(ivar) .ne. ifld) then
+    ifld = ivarfl(ivar)
+    call field_current_to_previous(ifld)
+  endif
 enddo
 
+! If required, the density at time step n-2 is updated
+if (icavit.ge.0) then
+  call field_get_val_prev_s(icrom, crom_prev)
+  call field_get_val_s(icroaa, crom_prev2)
+  do iel = 1, ncelet
+    crom_prev2(iel) = crom_prev(iel)
+  enddo
+endif
+
 ! If required, the density at time step n-1 is updated
-if (icalhy.eq.1.or.idilat.gt.1) then
+if (icalhy.eq.1.or.idilat.gt.1.or.icavit.ge.0) then
   call field_get_val_s(icrom, crom)
   call field_get_val_prev_s(icrom, crom_prev)
   do iel = 1, ncelet
@@ -522,7 +529,7 @@ if (ncpdct.gt.0) then
     call uikpdc &
     !==========
   ( iappel, ncelet, ncepdc,             &
-    icepdc, ckupdc, rtpa )
+    icepdc, ckupdc)
   endif
 
   call uskpdc &
@@ -530,7 +537,7 @@ if (ncpdct.gt.0) then
 ( nvar   , nscal  ,                                              &
   ncepdc , iappel ,                                              &
   icepdc , izcpdc ,                                              &
-  dt     , rtpa   , rtp    , propce ,                            &
+  dt     ,                                                       &
   ckupdc )
 
 endif
@@ -558,7 +565,7 @@ if(nctsmt.gt.0) then
   ncetsm , iappel ,                                              &
   icepdc ,                                                       &
   icetsm , itypsm , izctsm ,                                     &
-  dt     , rtpa   , propce ,                                     &
+  dt     ,                                                       &
   ckupdc , smacel )
 
 endif
@@ -646,8 +653,7 @@ if (ivrtex.eq.1) then
   !==========
  ( nvar   , nscal  ,                                              &
    iappel ,                                                       &
-   dt     , rtpa   ,                                              &
-   propce )
+   dt     )
 
 !     Verification des donnees entrees par l'utilisateur
 !       (au premier passage seulement)
@@ -764,16 +770,14 @@ do while (iterns.le.nterup)
   ( ntcabs, nfabor,                                                &
     nozppm, ncharm, ncharb, nclpch,                                &
     iindef, ientre, iesicf, isspcf, iephcf,                        &
-    isopcf, iparoi, iparug, isymet, isolib, isca  ,                &
-    ipr   , iscalt, itempk, ienerg,                                &
+    isopcf, iparoi, iparug, isymet, isolib,                        &
     iqimp,  icalke, ientat, ientcp, inmoxy, ientox,                &
     ientfu, ientgb, ientgf, iprofm,                                &
-    coejou, dpot,   rtpa,   ielcor,                                &
-    ipotr,  ipoti,  ipotva, ncelet,                                &
+    coejou, dpot,   ielcor, ipoti,                                 &
     itypfb, izfppp, icodcl,                                        &
     dtref,  ttcabs, surfbo, cdgfbo,                                &
     qimp,   qimpat, qimpcp, dh,     xintur,                        &
-    timpat, timpcp, tkent ,  fment, distch, rcodcl)
+    timpat, timpcp, tkent ,  fment, distch, nvarcl, rcodcl)
 
     if (ippmod(iphpar).eq.0) then
 
@@ -807,7 +811,7 @@ do while (iterns.le.nterup)
   !===============================
   ( nvar   , nscal  ,                                              &
     icodcl , itrifb , itypfb , izfppp ,                            &
-    dt     , rtp    , rtpa   , propce ,                            &
+    dt     ,                                                       &
     rcodcl )
 
   !     - Interface Code_Saturne
@@ -895,7 +899,7 @@ do while (iterns.le.nterup)
     nvar   , nscal  ,                                              &
     icodcl , itypfb , ialtyb ,                                     &
     impale ,                                                       &
-    dt     , rtp    , rtpa   , propce ,                            &
+    dt     ,                                                       &
     rcodcl , xyzno0 , depale )
 
     !     Au cas ou l'utilisateur aurait touche DEPALE sans mettre IMPALE=1, on
@@ -968,8 +972,7 @@ do while (iterns.le.nterup)
   icodcl , isostd ,                                              &
   dt     , rtp    , rtpa   , propce ,                            &
   rcodcl ,                                                       &
-  coefa  , coefb  , visvdr ,                                     &
-  hbord  , theipb ,                                              &
+  visvdr , hbord  , theipb ,                                     &
   frcxt  )
 
 !     ==============================================
@@ -1043,7 +1046,7 @@ do while (iterns.le.nterup)
 
     call coupbo &
     !==========
-  ( nvar   , ncp    , ncv    , ientha ,                            &
+  ( ncp    , ncv    , ientha ,                                     &
     rtp    ,                                                       &
     cpcst  , propce(:,ippcp) , cvcst  , propce(:,ippcv),           &
     hbord  , theipb )
@@ -1230,7 +1233,7 @@ do while (iterns.le.nterup)
   ( nvar   , nscal  , iterns , icvrge , itrale ,                   &
     isostd ,                                                       &
     dt     , rtp    , rtpa   , propce ,                            &
-    coefa  , coefb  , frcxt  , prhyd  ,                            &
+    frcxt  , prhyd  ,                                              &
     trava  , ximpav , uvwk   )
 
 
