@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -108,6 +108,7 @@ subroutine cs_coal_physprop1 &
 use paramx
 use numvar
 use optcal
+use dimens, only: nvar
 use cstphy
 use cstnum
 use entsor
@@ -133,7 +134,7 @@ double precision f4m(ncelet), f5m(ncelet) , f6m(ncelet)
 double precision f7m(ncelet), f8m(ncelet) , f9m(ncelet)
 double precision fvp2m(ncelet)
 double precision enth(ncelet),enthox(ncelet)
-double precision rtp(ncelet,*), propce(ncelet,*)
+double precision rtp(ncelet,nflown:nvar), propce(ncelet,*)
 double precision rom1(ncelet)
 
 ! Local variables
@@ -226,9 +227,9 @@ ipass = ipass + 1
 
 if (i_coal_drift.eq.1) then
   ! Mass weighted age of the gas phase
-  call field_get_val_s_by_name('X_Age_Gas',xagepg)
+  call field_get_val_s_by_name('x_age_gas_',xagepg)
   ! Age of the gas phase
-  call field_get_val_s_by_name('Age_Gas',agepgc)
+  call field_get_val_s_by_name('age_gas_',agepgc)
 endif
 
 !===============================================================================
