@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -59,6 +59,7 @@ subroutine cs_coal_physprop2  &
 use paramx
 use numvar
 use optcal
+use dimens, only: nvar
 use cstphy
 use entsor
 use cstnum
@@ -78,7 +79,7 @@ implicit none
 
 integer          ncelet , ncel
 
-double precision rtp(ncelet,*) , propce(ncelet,*)
+double precision rtp(ncelet,nflown:nvar) , propce(ncelet,*)
 
 ! Local variables
 character*80     name
@@ -135,14 +136,14 @@ do icla = 1, nclacp
   romax  = -grand
 
   if (i_coal_drift.eq.1) then
-    write(name,'(a8,i2.2)')'X_Age_CP' ,icla
+    write(name,'(a,i2.2)') 'x_age_coal_', icla
     call field_get_val_s_by_name(name,xagcpi)
 
-    write(name,'(a6,i2.2)')'Age_CP' ,icla
+    write(name,'(a,i2.2)') 'age_coal_', icla
     call field_get_val_s_by_name(name,agecpi)
   endif
 
-  write(name,'(a6,i2.2)')'Frm_CP' ,icla
+  write(name,'(a,i2.2)') 'w_solid_coal_', icla
   call field_get_val_s_by_name(name,frmcpi)
 
   do iel = 1, ncel
