@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -55,30 +55,6 @@ void CS_PROCF (uiray1, UIRAY1) (int *const iirayo,
                                 int *const iimlum);
 
 
-/*----------------------------------------------------------------------------
- *
- *----------------------------------------------------------------------------*/
-
-void CS_PROCF(fcnmra, FCNMRA)
-(
- const char      *const fstr,    /* --> Fortran string */
- int             *const len,     /* --> String Length  */
- int             *const var_id   /* --> Variable Id (1 to n) */
- CS_ARGF_SUPP_CHAINE
-);
-
-/*----------------------------------------------------------------------------
- *
- *----------------------------------------------------------------------------*/
-
-void CS_PROCF(cfnmra, CFNMRA)
-(
- char          *const fstr,    /* --> Fortran string */
- int           *const len,     /* --> String Length  */
- int           *const var_id   /* --> Variable Id (1 to n) */
- CS_ARGF_SUPP_CHAINE
-);
-
 /*----------------------------------------------------------------------------
  *
  *----------------------------------------------------------------------------*/
@@ -117,28 +93,8 @@ void CS_PROCF (uiray3, UIRAY3) (      double *const ck,
  *
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF (uiray4, UIRAY4) (int *const nbrayf,
-                                int *const iirayo,
-                                int *const irayvf);
+void CS_PROCF (uiray4, UIRAY4) (int *const iirayo);
 
-/*-----------------------------------------------------------------------------
- * Indirection between the solver numbering and the XML one
- * for physical properties of radiative transfer
- *----------------------------------------------------------------------------*/
-
-void CS_PROCF (uirapr, UIRAPR) (const int *const nprayc,
-                                const int *const nrphas,
-                                const int *const ipppro,
-                                const int *const ipproc,
-                                const int *const ilumin,
-                                const int *const iqx,
-                                const int *const iqy,
-                                const int *const iqz,
-                                const int *const itsre,
-                                const int *const itsri,
-                                const int *const iabs,
-                                const int *const iemi,
-                                const int *const icak);
 
 /*-----------------------------------------------------------------------------
  * Free memory: clean global private variables.
