@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -107,8 +107,7 @@ cs_lagr_get_n_particles(void)
 {
   cs_lnum_t retval = 0;
 
-  cs_lagr_particle_set_t  *p_set = NULL;
-  cs_lagr_get_particle_sets(&p_set, NULL);
+  const cs_lagr_particle_set_t  *p_set = cs_lagr_get_particle_set();
   if (p_set != NULL)
     retval = p_set->n_particles;
 
@@ -144,24 +143,27 @@ cs_lagr_get_particle_list(cs_lnum_t         n_cells,
   ptrdiff_t  displ = 0;
 
   cs_lnum_t p_count = 0;
-  cs_lagr_particle_set_t  *p_set = NULL;
 
   bool *cell_flag = NULL;
 
   const cs_mesh_t *mesh = cs_glob_mesh;
 
-  cs_lagr_get_particle_sets(&p_set, NULL);
+  const cs_lagr_particle_set_t  *p_set = cs_lagr_get_particle_set();
 
   assert(p_set != NULL);
 
+  size_t extents = p_set->p_am->extents;
+
   if (density < 1) {
 
-    size_t  extents, size;
+    size_t  _extents, size;
     cs_datatype_t  datatype;
     int  count;
 
-    cs_lagr_get_attr_info(CS_LAGR_RANDOM_VALUE,
-                          &extents, &size, &displ,
+    cs_lagr_get_attr_info(p_set,
+                          0,
+                          CS_LAGR_RANDOM_VALUE,
+                          &_extents, &size, &displ,
                           &datatype, &count);
 
     assert(   (displ > 0 && count == 1 && datatype == CS_REAL_TYPE)
@@ -205,7 +207,7 @@ cs_lagr_get_particle_list(cs_lnum_t         n_cells,
         r = (double)rand() / RAND_MAX;
       else {
         const unsigned char
-          *p = (const unsigned char *)(p_set->particles + i) + displ;
+          *p = (const unsigned char *)(p_set->p_buffer + i*extents) + displ;
         r = *(const cs_real_t *)p;
       }
       if (r > density)
@@ -215,7 +217,9 @@ cs_lagr_get_particle_list(cs_lnum_t         n_cells,
     /* Check for filter cell */
 
     if (cell_flag != NULL) {
-      cs_lnum_t  cell_id = CS_ABS(p_set->particles[i].cur_cell_num) - 1;
+      cs_lnum_t cur_cell_num
+        = cs_lagr_particles_get_lnum(p_set, i, CS_LAGR_CELL_NUM);
+      cs_lnum_t  cell_id = CS_ABS(cur_cell_num) - 1;
       if (cell_flag[cell_id] == false)
         continue;
     }
@@ -275,7 +279,8 @@ cs_lagr_get_particle_values(const cs_lagr_particle_set_t  *particles,
 
   assert(particles != NULL);
 
-  cs_lagr_get_attr_info(attr, &extents, &size, &displ, &_datatype, &_count);
+  cs_lagr_get_attr_info(particles, 0, attr,
+                        &extents, &size, &displ, &_datatype, &_count);
 
   if (_count == 0)
     return 1;
@@ -338,9 +343,9 @@ cs_lagr_get_particle_values(const cs_lagr_particle_set_t  *particles,
     for (i = 0; i < n_particles; i++) {
       unsigned char *dest = _values + i*_length;
       const unsigned char
-        *src = (const unsigned char *)(particles->particles + i)
+        *src = (const unsigned char *)(particles->p_buffer + i*extents)
                + displ
-               + component_id * _length ;
+               + component_id * _length;
       for (j = 0; j < _length; j++)
         dest[j] = src[j];
     }
@@ -352,9 +357,9 @@ cs_lagr_get_particle_values(const cs_lagr_particle_set_t  *particles,
       cs_lnum_t p_id = particle_list[i] - 1;
       unsigned char *dest = _values + i*_length;
       const unsigned char
-        *src = (const unsigned char *)(particles->particles + p_id)
+        *src = (const unsigned char *)(particles->p_buffer + p_id*extents)
                + displ
-               + component_id * _length ;
+               + component_id * _length;
       for (j = 0; j < _length; j++)
         dest[j] = src[j];
     }
@@ -365,7 +370,7 @@ cs_lagr_get_particle_values(const cs_lagr_particle_set_t  *particles,
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief Extract trajectory values joining 2 sets of particles.
+ * \brief Extract trajectory values for a set of particles.
  *
  * Trajectories are defined as a mesh of segments, whose start and end
  * points are copied in an interleaved manner in the segment_values array
@@ -374,16 +379,15 @@ cs_lagr_get_particle_values(const cs_lagr_particle_set_t  *particles,
  * The output array must have been allocated by the caller and be of
  * sufficient size.
  *
- * \param[in]   particles             associated particle set
- * \param[in]   particles_prev        associated previous particle set
- * \param[in]   attr                  attribute whose values are required
- * \param[in]   datatype              associated value type
- * \param[in]   stride                number of values per particle
- * \param[in]   component_id          if -1 : extract the whole attribute
- *                                    if >0 : id of the component to extract
- * \param[in]   n_particles           number of particles in filter
- * \param[in]   particle_list         particle_list (1 to n numbering), or NULL
- * \param[out]  segment_values        particle segment values
+ * \param[in]   particles        associated particle set
+ * \param[in]   attr             attribute whose values are required
+ * \param[in]   datatype         associated value type
+ * \param[in]   stride           number of values per particle
+ * \param[in]   component_id     if -1 : extract the whole attribute
+ *                               if >0 : id of the component to extract
+ * \param[in]   n_particles      number of particles in filter
+ * \param[in]   particle_list    particle_list (1 to n numbering), or NULL
+ * \param[out]  segment_values   particle segment values
  *
  * \return 0 in case of success, 1 if attribute is not present
  */
@@ -391,7 +395,6 @@ cs_lagr_get_particle_values(const cs_lagr_particle_set_t  *particles,
 
 int
 cs_lagr_get_trajectory_values(const cs_lagr_particle_set_t  *particles,
-                              const cs_lagr_particle_set_t  *particles_prev,
                               cs_lagr_attribute_t            attr,
                               cs_datatype_t                  datatype,
                               int                            stride,
@@ -404,14 +407,17 @@ cs_lagr_get_trajectory_values(const cs_lagr_particle_set_t  *particles,
   cs_lnum_t i;
 
   size_t  extents, size, _length;
-  ptrdiff_t  displ;
+  ptrdiff_t  displ, displ_p;
   cs_datatype_t _datatype;
   int  _count;
   unsigned char *_values = segment_values;
 
+  const unsigned char *p_buffer = particles->p_buffer;
+
   assert(particles != NULL);
 
-  cs_lagr_get_attr_info(attr, &extents, &size, &displ, &_datatype, &_count);
+  cs_lagr_get_attr_info(particles, 0, attr,
+                        &extents, &size, &displ, &_datatype, &_count);
 
   if (_count == 0)
     return 1;
@@ -422,6 +428,10 @@ cs_lagr_get_trajectory_values(const cs_lagr_particle_set_t  *particles,
       _length = size/_count;
   }
 
+  if (particles->p_am->count[1][attr] > 0)
+    cs_lagr_get_attr_info(particles, 1, attr,
+                          &extents, NULL, &displ_p, NULL, NULL);
+
   /* Check consistency */
 
   if (datatype != _datatype || stride != _count) {
@@ -467,45 +477,89 @@ cs_lagr_get_trajectory_values(const cs_lagr_particle_set_t  *particles,
   if (component_id == -1)
     component_id = 0;
 
-
   /* Case where we have no filter */
 
   if (particle_list == NULL) {
-    for (i = 0; i < n_particles; i++) {
-      unsigned char *dest = _values + i*_length*2;
-      const unsigned char
-        *src = (const unsigned char *)(particles->particles + i)
-               + displ
-               + component_id * _length ;
-      const unsigned char
-        *srcp = (const unsigned char *)(particles_prev->particles + i)
-                + displ
-                + component_id * _length ;
-      for (j = 0; j < _length; j++) {
-        dest[j] = src[j];
-        dest[j + _length] = srcp[j];
+
+    if (particles->p_am->count[1][attr] > 0) {
+
+      for (i = 0; i < n_particles; i++) {
+        unsigned char *dest = _values + i*_length*2;
+        const unsigned char
+          *src = (const unsigned char *)(p_buffer + i*extents)
+                  + displ
+                  + component_id * _length;
+        const unsigned char
+          *srcp = (const unsigned char *)(p_buffer + i*extents)
+                   + displ_p
+                   + component_id * _length;
+        for (j = 0; j < _length; j++) {
+          dest[j] = src[j];
+          dest[j + _length] = srcp[j];
+        }
+
       }
+
+    }
+    else { /* With no previous value available; copy current value */
+
+      for (i = 0; i < n_particles; i++) {
+        unsigned char *dest = _values + i*_length*2;
+        const unsigned char
+          *src = (const unsigned char *)(p_buffer + i*extents)
+                  + displ
+                  + component_id * _length;
+        for (j = 0; j < _length; j++) {
+          dest[j] = src[j];
+          dest[j + _length] = src[j];
+        }
+
+      }
+
     }
   }
 
   /* Case where we have a filter list */
   else {
-    for (i = 0; i < n_particles; i++) {
-      cs_lnum_t p_id = particle_list[i] - 1;
-      unsigned char *dest = _values + i*_length*2;
-      const unsigned char
-        *src = (const unsigned char *)(particles->particles + p_id)
-               + displ
-               + component_id * _length ;
-      const unsigned char
-        *srcp = (const unsigned char *)(particles_prev->particles + p_id)
-                + displ
-                + component_id * _length ;
-      for (j = 0; j < _length; j++) {
-        dest[j] = src[j];
-        dest[j + _length] = srcp[j];
+
+    if (particles->p_am->count[1][attr] > 0) {
+
+      for (i = 0; i < n_particles; i++) {
+        cs_lnum_t p_id = particle_list[i] - 1;
+        unsigned char *dest = _values + i*_length*2;
+        const unsigned char
+          *src = (const unsigned char *)(p_buffer + p_id*extents)
+                  + displ
+                  + component_id * _length;
+        const unsigned char
+          *srcp = (const unsigned char *)(p_buffer + p_id*extents)
+                   + displ_p
+                   + component_id * _length;
+        for (j = 0; j < _length; j++) {
+          dest[j] = src[j];
+          dest[j + _length] = srcp[j];
+        }
       }
+
     }
+
+    else { /* With no previous value available; copy current value */
+
+      for (i = 0; i < n_particles; i++) {
+        cs_lnum_t p_id = particle_list[i] - 1;
+        unsigned char *dest = _values + i*_length*2;
+        const unsigned char
+          *src = (const unsigned char *)(p_buffer + p_id*extents)
+                  + displ
+                  + component_id * _length;
+        for (j = 0; j < _length; j++) {
+          dest[j] = src[j];
+          dest[j + _length] = src[j];
+        }
+      }
+
+    }
+
   }
 
   return 0;
