@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -236,10 +236,10 @@ typedef struct {
   cs_gnum_t   *per_v_couples;
 
   /*
-     Single elements (Only possible in parallel). It appears
+     Single elements (Only possible in parallel). Appear mainly
      when the domain splitting has a poor quality and elements
-     on the joining interface are prisms or tetraedrals
-     s = single / c = coupled
+     on the joining interface are prisms or tetrahedra
+     s = single (receiver) / c = coupled (owner).
   */
 
   bool         do_single_sync;
