@@ -9,7 +9,7 @@
   This file is part of the Code_Saturne Kernel, element of the
   Code_Saturne CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A., France
+  Copyright (C) 1998-2014 EDF S.A., France
 
   contact: saturne-support@edf.fr
 
@@ -85,7 +85,7 @@ typedef struct _cs_mesh_location_t cs_mesh_location_t;
  *   m           <-- pointer to associated mesh structure.
  *   location_id <-- id of associated location.
  *   n_elts      --> number of selected elements
- *   elt_list    --> list of selected elements.
+ *   elt_list    --> list of selected elements (0 to n-1 numbering).
  *----------------------------------------------------------------------------*/
 
 typedef void
@@ -94,6 +94,14 @@ typedef void
                              cs_lnum_t         *n_elts,
                              cs_lnum_t        **elt_list);
 
+/*=============================================================================
+ * Global variables
+ *============================================================================*/
+
+/* Names associated with location types */
+
+extern const char  *cs_mesh_location_type_name[];
+
 /*=============================================================================
  * Public function prototypes
  *============================================================================*/
@@ -245,7 +253,7 @@ cs_mesh_location_get_n_elts(int id);
  *   id <-- id of mesh location
  *
  * returns:
- *   pointer to elements list.
+ *   pointer to elements list (0 to n-1 numbering).
  *----------------------------------------------------------------------------*/
 
 const cs_lnum_t *
