@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -240,7 +240,7 @@ idtva0 = 0
 cnom = ' '
 write(cnom,'(A)') 'Rayon P1'
 inum = 1
-nomvar(inum) = cnom
+nomva0 = cnom
 
 call codits &
 !==========
