@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -54,10 +54,12 @@ subroutine tsepls &
 use paramx
 use numvar
 use optcal
+use dimens, only: nvar
 use cstphy
 use entsor
-use pointe, only: coefau, coefbu
 use mesh
+use field
+use field_operator
 
 !===============================================================================
 
@@ -65,14 +67,14 @@ implicit none
 
 ! Arguments
 
-double precision rtpa(ncelet,*)
+double precision rtpa(ncelet,nflown:nvar)
 double precision w1(ncelet)
 
 ! Local variables
 
-integer          iel, ifac, inc, iccocg, iphydp
+integer          iel, ifac, inc, iprev
 integer          isou, ii, jj, nswrgp, imligp, iwarnp
-logical          ilved
+
 double precision climgp, extrap
 double precision w1f, w2f, w3f
 double precision pnd, flux, somsur, epsrgp
@@ -80,6 +82,9 @@ double precision pnd, flux, somsur, epsrgp
 double precision, allocatable, dimension(:) :: w7
 double precision, allocatable, dimension(:,:,:) :: gradv
 
+double precision, dimension(:,:), pointer :: coefau
+double precision, dimension(:,:,:), pointer :: coefbu
+
 !===============================================================================
 
 !===============================================================================
@@ -92,6 +97,9 @@ allocate(gradv(3, 3, ncelet))
 ! Allocate work arrays
 allocate(w7(ncelet))
 
+call field_get_coefa_v(ivarfl(iu), coefau)
+call field_get_coefb_v(ivarfl(iu), coefbu)
+
 !===============================================================================
 ! 2. Calculation of the term d2Ui/dxkdxj*d2Ui/dxkdxj
 !===============================================================================
@@ -101,27 +109,10 @@ do iel = 1, ncel
 enddo
 
 inc = 1
-iccocg = 1
+iprev = 1
 
-nswrgp = nswrgr(iu)
-epsrgp = epsrgr(iu)
-imligp = imligr(iu)
-iwarnp = iwarni(iu)
-climgp = climgr(iu)
-extrap = extrag(iu)
-
-iphydp = 0
-
-ilved = .false.
-
-! WARNING: gradv(xyz, uvw, iel)
-call grdvec &
-!==========
-( iu     , imrgra , inc    , nswrgp , imligp ,                   &
-  iwarnp , epsrgp , climgp ,                                     &
-  ilved  ,                                                       &
-  rtpa(1,iu) ,  coefau , coefbu,                                 &
-  gradv  )
+call field_gradient_vector(ivarfl(iu), iprev, imrgra, inc,    &
+                           gradv)
 
 ! Loop over u, v, w components
 do isou = 1, 3
