@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -76,9 +76,9 @@ use cstphy
 use optcal
 use lagran
 use ppincl
-use pointe, only: coefau, coefbu
 use mesh
 use field
+use field_operator
 
 !===============================================================================
 
@@ -92,7 +92,7 @@ integer          ncepdp , ncesmp
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision tslagr(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
@@ -112,7 +112,7 @@ integer          ipcvst, ipcvis, iflmas, iflmab
 integer          iwarnp, ipp
 integer          iptsta
 integer          ipcvto, ipcvlo
-integer          iphydp
+integer          iphydp, iprev
 integer          imucpp, idftnp, iswdyp
 
 integer          icvflb
@@ -130,8 +130,6 @@ double precision tuexpk, tuexpe
 double precision cmueta, sqrcmu, xs
 double precision hint
 
-logical          ilved
-
 double precision rvoid(1)
 
 double precision, allocatable, dimension(:) :: viscf, viscb
@@ -150,6 +148,8 @@ double precision, dimension(:,:,:), allocatable :: gradv
 double precision, allocatable, dimension(:) :: dpvar
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer :: brom, crom, bromo, cromo
+double precision, dimension(:,:), pointer :: coefau
+double precision, dimension(:,:,:), pointer :: coefbu
 double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
 
 !===============================================================================
@@ -178,6 +178,10 @@ if (iturb.eq.51) then
   allocate(w10(ncelet),w11(ncelet))
 endif
 
+! Map field arrays
+call field_get_coefa_v(ivarfl(iu), coefau)
+call field_get_coefb_v(ivarfl(iu), coefbu)
+
 call field_get_val_s(icrom, crom)
 ipcvst = ipproc(ivisct)
 ipcvis = ipproc(iviscl)
@@ -241,26 +245,11 @@ d1s3 = 1.d0/3.d0
 ! Allocate temporary arrays for gradients calculation
 allocate(gradv(3, 3, ncelet))
 
-iccocg = 1
 inc = 1
+iprev = 1
 
-nswrgp = nswrgr(iu)
-imligp = imligr(iu)
-iwarnp = iwarni(ik)
-epsrgp = epsrgr(iu)
-climgp = climgr(iu)
-extrap = extrag(iu)
-
-ilved = .false.
-
-! WARNING: gradv(xyz, uvw, iel)
-call grdvec &
-!==========
-( iu     , imrgra , inc    , nswrgp , imligp ,                   &
-  iwarnp , epsrgp , climgp ,                                     &
-  ilved  ,                                                       &
-  rtpa(1,iu) ,  coefau , coefbu,                                 &
-  gradv  )
+call field_gradient_vector(ivarfl(iu), iprev, imrgra, inc,    &
+                           gradv)
 
 ! strain = Stain rate of the deviatoric part of the strain tensor
 !        = 2 (Sij^D).(Sij^D)
@@ -509,7 +498,7 @@ if (iturb.eq.51) then
   call itrgrp &
   !==========
 ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydp , &
-  iwarnp , nfecra ,                                              &
+  iwarnp ,                                                       &
   epsrgp , climgp , extrap ,                                     &
   rvoid  ,                                                       &
   rtpa(1,ivar)    ,                                              &
@@ -720,13 +709,21 @@ do iel = 1, ncel
   w8(iel) = 0.d0
 enddo
 
-call ustske &
-!==========
+call cs_user_turbulence_source_terms &
+!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
+   ivarfl(ik)      ,                                              &
    icepdc , icetsm , itypsm ,                                     &
-   dt     , rtpa   , propce ,                                     &
-   ckupdc , smacel , strain , divu   ,                            &
-   w7     , w8     , usimpk , usimpe )
+   ckupdc , smacel ,                                              &
+   w7     , usimpk )
+
+call cs_user_turbulence_source_terms &
+!===================================
+ ( nvar   , nscal  , ncepdp , ncesmp ,                            &
+   ivarfl(iep)     ,                                              &
+   icepdc , icetsm , itypsm ,                                     &
+   ckupdc , smacel ,                                              &
+   w8     , usimpe )
 
 ! If source terms are extrapolated over time
 if (isto2t.gt.0) then
@@ -877,8 +874,7 @@ if (ikecou.eq.1) then
 
   ! ---> Traitement de k
   ivar   = ik
-  ipp    = ipprtp(ivar)
-  chaine = nomvar(ipp)
+  call field_get_label(ivarfl(ivar), chaine)
 
   call field_get_coefa_s(ivarfl(ivar), coefap)
   call field_get_coefb_s(ivarfl(ivar), coefbp)
@@ -934,7 +930,7 @@ if (ikecou.eq.1) then
   !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp , idftnp ,                            &
+   iwarnp , imucpp , idftnp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
    coefap , coefbp , cofafp , cofbfp ,                            &
@@ -953,8 +949,7 @@ if (ikecou.eq.1) then
 
   ! ---> Traitement de epsilon
   ivar   = iep
-  ipp    = ipprtp(ivar)
-  chaine = nomvar(ipp)
+  call field_get_label(ivarfl(ivar), chaine)
 
   call field_get_coefa_s(ivarfl(ivar), coefap)
   call field_get_coefb_s(ivarfl(ivar), coefbp)
@@ -1009,7 +1004,7 @@ if (ikecou.eq.1) then
   !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp , idftnp ,                            &
+   iwarnp , imucpp , idftnp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
    coefap , coefbp , cofafp , cofbfp ,                            &
